Class: FlatApi::AssignmentCapabilities

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/assignment_capabilities.rb

Overview

Capabilities the current user has on this assignment. Each capability corresponds to a fine-grained action that a user may take.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AssignmentCapabilities

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/flat_api/models/assignment_capabilities.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::AssignmentCapabilities` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::AssignmentCapabilities`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'can_edit')
    self.can_edit = attributes[:'can_edit']
  else
    self.can_edit = nil
  end

  if attributes.key?(:'can_publish_in_class')
    self.can_publish_in_class = attributes[:'can_publish_in_class']
  else
    self.can_publish_in_class = nil
  end

  if attributes.key?(:'can_publish_in_class_error')
    self.can_publish_in_class_error = attributes[:'can_publish_in_class_error']
  end

  if attributes.key?(:'can_archive')
    self.can_archive = attributes[:'can_archive']
  else
    self.can_archive = nil
  end

  if attributes.key?(:'can_unarchive')
    self.can_unarchive = attributes[:'can_unarchive']
  else
    self.can_unarchive = nil
  end
end

Instance Attribute Details

#can_archiveObject

Whether the current user can archive the assignment



28
29
30
# File 'lib/flat_api/models/assignment_capabilities.rb', line 28

def can_archive
  @can_archive
end

#can_editObject

Whether the current user can edit the assignment



20
21
22
# File 'lib/flat_api/models/assignment_capabilities.rb', line 20

def can_edit
  @can_edit
end

#can_publish_in_classObject

Whether this assignment can be published in a class



23
24
25
# File 'lib/flat_api/models/assignment_capabilities.rb', line 23

def can_publish_in_class
  @can_publish_in_class
end

#can_publish_in_class_errorObject

Returns the value of attribute can_publish_in_class_error.



25
26
27
# File 'lib/flat_api/models/assignment_capabilities.rb', line 25

def can_publish_in_class_error
  @can_publish_in_class_error
end

#can_unarchiveObject

Whether the current user can unarchive the assignment



31
32
33
# File 'lib/flat_api/models/assignment_capabilities.rb', line 31

def can_unarchive
  @can_unarchive
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/flat_api/models/assignment_capabilities.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/flat_api/models/assignment_capabilities.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/flat_api/models/assignment_capabilities.rb', line 34

def self.attribute_map
  {
    :'can_edit' => :'canEdit',
    :'can_publish_in_class' => :'canPublishInClass',
    :'can_publish_in_class_error' => :'canPublishInClassError',
    :'can_archive' => :'canArchive',
    :'can_unarchive' => :'canUnarchive'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/flat_api/models/assignment_capabilities.rb', line 218

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/flat_api/models/assignment_capabilities.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/flat_api/models/assignment_capabilities.rb', line 55

def self.openapi_types
  {
    :'can_edit' => :'Boolean',
    :'can_publish_in_class' => :'Boolean',
    :'can_publish_in_class_error' => :'AssignmentCapabilitiesCanPublishInClassError',
    :'can_archive' => :'Boolean',
    :'can_unarchive' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
# File 'lib/flat_api/models/assignment_capabilities.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      can_edit == o.can_edit &&
      can_publish_in_class == o.can_publish_in_class &&
      can_publish_in_class_error == o.can_publish_in_class_error &&
      can_archive == o.can_archive &&
      can_unarchive == o.can_unarchive
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


205
206
207
# File 'lib/flat_api/models/assignment_capabilities.rb', line 205

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



211
212
213
# File 'lib/flat_api/models/assignment_capabilities.rb', line 211

def hash
  [can_edit, can_publish_in_class, can_publish_in_class_error, can_archive, can_unarchive].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/flat_api/models/assignment_capabilities.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @can_edit.nil?
    invalid_properties.push('invalid value for "can_edit", can_edit cannot be nil.')
  end

  if @can_publish_in_class.nil?
    invalid_properties.push('invalid value for "can_publish_in_class", can_publish_in_class cannot be nil.')
  end

  if @can_archive.nil?
    invalid_properties.push('invalid value for "can_archive", can_archive cannot be nil.')
  end

  if @can_unarchive.nil?
    invalid_properties.push('invalid value for "can_unarchive", can_unarchive cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/flat_api/models/assignment_capabilities.rb', line 240

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
148
149
# File 'lib/flat_api/models/assignment_capabilities.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @can_edit.nil?
  return false if @can_publish_in_class.nil?
  return false if @can_archive.nil?
  return false if @can_unarchive.nil?
  true
end