Class: FlatApi::AssignmentCopyToClass
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::AssignmentCopyToClass
- Defined in:
- lib/flat_api/models/assignment_copy_to_class.rb
Overview
Copy the assignment to a class
Instance Attribute Summary collapse
-
#assignment ⇒ Object
An optional destination assignment where the original assignement will be copied.
-
#classroom ⇒ Object
The destination classroom where the assignment will be copied.
-
#scheduled_date ⇒ Object
The publication (scheduled) date of the assignment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AssignmentCopyToClass
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AssignmentCopyToClass
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::AssignmentCopyToClass` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::AssignmentCopyToClass`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'classroom') self.classroom = attributes[:'classroom'] else self.classroom = nil end if attributes.key?(:'assignment') self.assignment = attributes[:'assignment'] end if attributes.key?(:'scheduled_date') self.scheduled_date = attributes[:'scheduled_date'] end end |
Instance Attribute Details
#assignment ⇒ Object
An optional destination assignment where the original assignement will be copied. Must be a draft.
23 24 25 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 23 def assignment @assignment end |
#classroom ⇒ Object
The destination classroom where the assignment will be copied
20 21 22 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 20 def classroom @classroom end |
#scheduled_date ⇒ Object
The publication (scheduled) date of the assignment. If this one is specified, the assignment will only be listed to the teachers of the class. Alternatively the existing scheduledDate from the copied assignment will be used.
26 27 28 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 26 def scheduled_date @scheduled_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 29 def self.attribute_map { :'classroom' => :'classroom', :'assignment' => :'assignment', :'scheduled_date' => :'scheduledDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 148 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 57 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 48 def self.openapi_types { :'classroom' => :'String', :'assignment' => :'String', :'scheduled_date' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 125 def ==(o) return true if self.equal?(o) self.class == o.class && classroom == o.classroom && assignment == o.assignment && scheduled_date == o.scheduled_date end |
#eql?(o) ⇒ Boolean
135 136 137 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 135 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
141 142 143 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 141 def hash [classroom, assignment, scheduled_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
95 96 97 98 99 100 101 102 103 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 95 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @classroom.nil? invalid_properties.push('invalid value for "classroom", classroom cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
107 108 109 110 111 |
# File 'lib/flat_api/models/assignment_copy_to_class.rb', line 107 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @classroom.nil? true end |