Class: FlatApi::AssignmentSubmissionHistory

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/assignment_submission_history.rb

Overview

History item of the submission

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AssignmentSubmissionHistory

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/flat_api/models/assignment_submission_history.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::AssignmentSubmissionHistory` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::AssignmentSubmissionHistory`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'classroom')
    self.classroom = attributes[:'classroom']
  end

  if attributes.key?(:'assignment')
    self.assignment = attributes[:'assignment']
  end

  if attributes.key?(:'submission')
    self.submission = attributes[:'submission']
  end

  if attributes.key?(:'users')
    if (value = attributes[:'users']).is_a?(Array)
      self.users = value
    end
  else
    self.users = nil
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'draft_grade')
    self.draft_grade = attributes[:'draft_grade']
  end

  if attributes.key?(:'grade')
    self.grade = attributes[:'grade']
  end

  if attributes.key?(:'max_points')
    self.max_points = attributes[:'max_points']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'due_date')
    self.due_date = attributes[:'due_date']
  end

  if attributes.key?(:'attachment')
    self.attachment = attributes[:'attachment']
  end
end

Instance Attribute Details

#assignmentObject

The assignment unique identifier where the submission was changed



26
27
28
# File 'lib/flat_api/models/assignment_submission_history.rb', line 26

def assignment
  @assignment
end

#attachmentObject

Returns the value of attribute attachment.



54
55
56
# File 'lib/flat_api/models/assignment_submission_history.rb', line 54

def attachment
  @attachment
end

#classroomObject

The classroom unique identifier where the submission was changed



23
24
25
# File 'lib/flat_api/models/assignment_submission_history.rb', line 23

def classroom
  @classroom
end

#commentObject

The comment that is made to this submission



49
50
51
# File 'lib/flat_api/models/assignment_submission_history.rb', line 49

def comment
  @comment
end

#dateObject

The date when the submission was changed



20
21
22
# File 'lib/flat_api/models/assignment_submission_history.rb', line 20

def date
  @date
end

#draft_gradeObject

The numerator of the grade at this time in the submission grade history



40
41
42
# File 'lib/flat_api/models/assignment_submission_history.rb', line 40

def draft_grade
  @draft_grade
end

#due_dateObject

The due date of this assignment



52
53
54
# File 'lib/flat_api/models/assignment_submission_history.rb', line 52

def due_date
  @due_date
end

#gradeObject

The numerator of the grade at this time in the submission grade history



43
44
45
# File 'lib/flat_api/models/assignment_submission_history.rb', line 43

def grade
  @grade
end

#max_pointsObject

The denominator of the grade at this time in the submission grade history



46
47
48
# File 'lib/flat_api/models/assignment_submission_history.rb', line 46

def max_points
  @max_points
end

#sourceObject

The source of the change if the change was made by a third-party software



35
36
37
# File 'lib/flat_api/models/assignment_submission_history.rb', line 35

def source
  @source
end

#stateObject

Returns the value of attribute state.



37
38
39
# File 'lib/flat_api/models/assignment_submission_history.rb', line 37

def state
  @state
end

#submissionObject

The submission unique identifier



29
30
31
# File 'lib/flat_api/models/assignment_submission_history.rb', line 29

def submission
  @submission
end

#usersObject

The user(s) unique identifier(s) who made the change



32
33
34
# File 'lib/flat_api/models/assignment_submission_history.rb', line 32

def users
  @users
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



98
99
100
# File 'lib/flat_api/models/assignment_submission_history.rb', line 98

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



103
104
105
# File 'lib/flat_api/models/assignment_submission_history.rb', line 103

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/flat_api/models/assignment_submission_history.rb', line 79

def self.attribute_map
  {
    :'date' => :'date',
    :'classroom' => :'classroom',
    :'assignment' => :'assignment',
    :'submission' => :'submission',
    :'users' => :'users',
    :'source' => :'source',
    :'state' => :'state',
    :'draft_grade' => :'draftGrade',
    :'grade' => :'grade',
    :'max_points' => :'maxPoints',
    :'comment' => :'comment',
    :'due_date' => :'dueDate',
    :'attachment' => :'attachment'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/flat_api/models/assignment_submission_history.rb', line 299

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/flat_api/models/assignment_submission_history.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/flat_api/models/assignment_submission_history.rb', line 108

def self.openapi_types
  {
    :'date' => :'Time',
    :'classroom' => :'String',
    :'assignment' => :'String',
    :'submission' => :'String',
    :'users' => :'Array<String>',
    :'source' => :'String',
    :'state' => :'AssignmentSubmissionHistoryState',
    :'draft_grade' => :'Float',
    :'grade' => :'Float',
    :'max_points' => :'Float',
    :'comment' => :'String',
    :'due_date' => :'Time',
    :'attachment' => :'AssignmentSubmissionHistoryAttachment'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/flat_api/models/assignment_submission_history.rb', line 266

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      date == o.date &&
      classroom == o.classroom &&
      assignment == o.assignment &&
      submission == o.submission &&
      users == o.users &&
      source == o.source &&
      state == o.state &&
      draft_grade == o.draft_grade &&
      grade == o.grade &&
      max_points == o.max_points &&
      comment == o.comment &&
      due_date == o.due_date &&
      attachment == o.attachment
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/flat_api/models/assignment_submission_history.rb', line 286

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



292
293
294
# File 'lib/flat_api/models/assignment_submission_history.rb', line 292

def hash
  [date, classroom, assignment, submission, users, source, state, draft_grade, grade, max_points, comment, due_date, attachment].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/flat_api/models/assignment_submission_history.rb', line 209

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @users.nil?
    invalid_properties.push('invalid value for "users", users cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/flat_api/models/assignment_submission_history.rb', line 321

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



225
226
227
228
229
230
231
232
# File 'lib/flat_api/models/assignment_submission_history.rb', line 225

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @date.nil?
  return false if @users.nil?
  source_validator = EnumAttributeValidator.new('String', ["lti", "googleClassroom", "microsoftGraph"])
  return false unless source_validator.valid?(@source)
  true
end