Class: FlatApi::ClassAttachmentCreation

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/class_attachment_creation.rb

Overview

Attachment creation for an assignment or stream post. This attachment must contain a score or an url, all the details of this one will be resolved and returned as ClassAttachment once the assignment or stream post is created.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClassAttachmentCreation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/flat_api/models/class_attachment_creation.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ClassAttachmentCreation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ClassAttachmentCreation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  end

  if attributes.key?(:'worksheet')
    self.worksheet = attributes[:'worksheet']
  end

  if attributes.key?(:'revision')
    self.revision = attributes[:'revision']
  end

  if attributes.key?(:'part_uuid')
    self.part_uuid = attributes[:'part_uuid']
  end

  if attributes.key?(:'sharing_mode')
    self.sharing_mode = attributes[:'sharing_mode']
  else
    self.sharing_mode = 'read'
  end

  if attributes.key?(:'lock_score_template')
    self.lock_score_template = attributes[:'lock_score_template']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'google_drive_file_id')
    self.google_drive_file_id = attributes[:'google_drive_file_id']
  end

  if attributes.key?(:'teacher_only')
    self.teacher_only = attributes[:'teacher_only']
  else
    self.teacher_only = false
  end
end

Instance Attribute Details

#google_drive_file_idObject

The ID of the Google Drive File



43
44
45
# File 'lib/flat_api/models/class_attachment_creation.rb', line 43

def google_drive_file_id
  @google_drive_file_id
end

#lock_score_templateObject

To be used with a score attached in sharingMode copy (score used as template). If true, students won't be able to change the original notes of the template.



37
38
39
# File 'lib/flat_api/models/class_attachment_creation.rb', line 37

def lock_score_template
  @lock_score_template
end

#part_uuidObject

The UUID of the instrument part selected for this attachment (for performance submissions)



32
33
34
# File 'lib/flat_api/models/class_attachment_creation.rb', line 32

def part_uuid
  @part_uuid
end

#revisionObject

An unique revision identifier of a score



29
30
31
# File 'lib/flat_api/models/class_attachment_creation.rb', line 29

def revision
  @revision
end

#scoreObject

A unique Flat score identifier. The user creating the assignment must at least have read access to the document. If the user has admin rights, new group permissions will be automatically added for the teachers and students of the class.



23
24
25
# File 'lib/flat_api/models/class_attachment_creation.rb', line 23

def score
  @score
end

#sharing_modeObject

Returns the value of attribute sharing_mode.



34
35
36
# File 'lib/flat_api/models/class_attachment_creation.rb', line 34

def sharing_mode
  @sharing_mode
end

#teacher_onlyObject

Flag indicating if this attachment should only be visible to teachers



46
47
48
# File 'lib/flat_api/models/class_attachment_creation.rb', line 46

def teacher_only
  @teacher_only
end

#typeObject

The type of the attachment posted: * rich, photo, video are attachment types that are automatically resolved from a link attachment. * A flat attachment is a score document where the unique identifier will be specified in the score property. Its sharing mode will be provided in the sharingMode property.



20
21
22
# File 'lib/flat_api/models/class_attachment_creation.rb', line 20

def type
  @type
end

#urlObject

The URL of the attachment.



40
41
42
# File 'lib/flat_api/models/class_attachment_creation.rb', line 40

def url
  @url
end

#worksheetObject

An unique worksheet identifier



26
27
28
# File 'lib/flat_api/models/class_attachment_creation.rb', line 26

def worksheet
  @worksheet
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/flat_api/models/class_attachment_creation.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/flat_api/models/class_attachment_creation.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/flat_api/models/class_attachment_creation.rb', line 71

def self.attribute_map
  {
    :'type' => :'type',
    :'score' => :'score',
    :'worksheet' => :'worksheet',
    :'revision' => :'revision',
    :'part_uuid' => :'partUuid',
    :'sharing_mode' => :'sharingMode',
    :'lock_score_template' => :'lockScoreTemplate',
    :'url' => :'url',
    :'google_drive_file_id' => :'googleDriveFileId',
    :'teacher_only' => :'teacherOnly'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/flat_api/models/class_attachment_creation.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
# File 'lib/flat_api/models/class_attachment_creation.rb', line 113

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/flat_api/models/class_attachment_creation.rb', line 97

def self.openapi_types
  {
    :'type' => :'String',
    :'score' => :'String',
    :'worksheet' => :'String',
    :'revision' => :'String',
    :'part_uuid' => :'String',
    :'sharing_mode' => :'MediaScoreSharingMode',
    :'lock_score_template' => :'Boolean',
    :'url' => :'String',
    :'google_drive_file_id' => :'String',
    :'teacher_only' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/flat_api/models/class_attachment_creation.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      score == o.score &&
      worksheet == o.worksheet &&
      revision == o.revision &&
      part_uuid == o.part_uuid &&
      sharing_mode == o.sharing_mode &&
      lock_score_template == o.lock_score_template &&
      url == o.url &&
      google_drive_file_id == o.google_drive_file_id &&
      teacher_only == o.teacher_only
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/flat_api/models/class_attachment_creation.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/flat_api/models/class_attachment_creation.rb', line 231

def hash
  [type, score, worksheet, revision, part_uuid, sharing_mode, lock_score_template, url, google_drive_file_id, teacher_only].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
# File 'lib/flat_api/models/class_attachment_creation.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/flat_api/models/class_attachment_creation.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
194
# File 'lib/flat_api/models/class_attachment_creation.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  type_validator = EnumAttributeValidator.new('String', ["rich", "photo", "video", "link", "flat", "googleDrive", "worksheet"])
  return false unless type_validator.valid?(@type)
  true
end