Method: FlatApi::ClassCreation#list_invalid_properties
- Defined in:
- lib/flat_api/models/class_creation.rb
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/flat_api/models/class_creation.rb', line 131 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if !@section.nil? && @section.to_s.length > 255 invalid_properties.push('invalid value for "section", the character length must be smaller than or equal to 255.') end if !@size.nil? && @size < 0 invalid_properties.push('invalid value for "size", must be greater than or equal to 0.') end invalid_properties end |