Class: FlatApi::CollectionApi

Inherits:
Object
  • Object
show all
Defined in:
lib/flat_api/api/collection_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ CollectionApi

Returns a new instance of CollectionApi.



19
20
21
# File 'lib/flat_api/api/collection_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/flat_api/api/collection_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_score_to_collection(collection, score, opts = {}) ⇒ ScoreDetails

Add a score to the collection This operation will add a score to a collection. The default behavior will make the score available across multiple collections. You must have the capability canAddScores on the provided collection to perform the action.

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted

  • score (String)

    Unique identifier of the score document. This can be a Flat Score unique identifier (i.e. `ScoreDetails.id`) or, if the score is also a Google Drive file, the Drive file unique identifier prefixed with `drive-` (e.g. `drive-0B000000000`).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :sharing_key (String)

    This sharing key must be specified to access to a score or collection with a `privacy` mode set to `privateLink` and the current user is not a collaborator of the document.

Returns:



29
30
31
32
# File 'lib/flat_api/api/collection_api.rb', line 29

def add_score_to_collection(collection, score, opts = {})
  data, _status_code, _headers = add_score_to_collection_with_http_info(collection, score, opts)
  data
end

#add_score_to_collection_with_http_info(collection, score, opts = {}) ⇒ Array<(ScoreDetails, Integer, Hash)>

Add a score to the collection This operation will add a score to a collection. The default behavior will make the score available across multiple collections. You must have the capability `canAddScores` on the provided `collection` to perform the action.

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted

  • score (String)

    Unique identifier of the score document. This can be a Flat Score unique identifier (i.e. `ScoreDetails.id`) or, if the score is also a Google Drive file, the Drive file unique identifier prefixed with `drive-` (e.g. `drive-0B000000000`).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :sharing_key (String)

    This sharing key must be specified to access to a score or collection with a `privacy` mode set to `privateLink` and the current user is not a collaborator of the document.

Returns:

  • (Array<(ScoreDetails, Integer, Hash)>)

    ScoreDetails data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/flat_api/api/collection_api.rb', line 41

def add_score_to_collection_with_http_info(collection, score, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CollectionApi.add_score_to_collection ...'
  end
  # verify the required parameter 'collection' is set
  if @api_client.config.client_side_validation && collection.nil?
    fail ArgumentError, "Missing the required parameter 'collection' when calling CollectionApi.add_score_to_collection"
  end
  # verify the required parameter 'score' is set
  if @api_client.config.client_side_validation && score.nil?
    fail ArgumentError, "Missing the required parameter 'score' when calling CollectionApi.add_score_to_collection"
  end
  # resource path
  local_var_path = '/collections/{collection}/scores/{score}'.sub('{collection}', CGI.escape(collection.to_s)).sub('{score}', CGI.escape(score.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'sharingKey'] = opts[:'sharing_key'] if !opts[:'sharing_key'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ScoreDetails'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"CollectionApi.add_score_to_collection",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CollectionApi#add_score_to_collection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_collection(body, opts = {}) ⇒ Collection

Create a new collection This method will create a new collection in your account.

Parameters:

Returns:



104
105
106
107
# File 'lib/flat_api/api/collection_api.rb', line 104

def create_collection(body, opts = {})
  data, _status_code, _headers = create_collection_with_http_info(body, opts)
  data
end

#create_collection_with_http_info(body, opts = {}) ⇒ Array<(Collection, Integer, Hash)>

Create a new collection This method will create a new collection in your account.

Parameters:

Returns:

  • (Array<(Collection, Integer, Hash)>)

    Collection data, response status code and response headers



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/flat_api/api/collection_api.rb', line 114

def create_collection_with_http_info(body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CollectionApi.create_collection ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CollectionApi.create_collection"
  end
  # resource path
  local_var_path = '/collections'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'Collection'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"CollectionApi.create_collection",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CollectionApi#create_collection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_collection(collection, opts = {}) ⇒ nil

Delete the collection This method will schedule the deletion of the collection. Until deleted, the collection will be available in the trash.

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted The following virtual collections are supported: - `allScores`: All the scores contained in the user account - `collaborations`: All shared scores by the user or someone else - `likes`: Liked scores

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


172
173
174
175
# File 'lib/flat_api/api/collection_api.rb', line 172

def delete_collection(collection, opts = {})
  delete_collection_with_http_info(collection, opts)
  nil
end

#delete_collection_with_http_info(collection, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete the collection This method will schedule the deletion of the collection. Until deleted, the collection will be available in the `trash`.

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted The following virtual collections are supported: - `allScores`: All the scores contained in the user account - `collaborations`: All shared scores by the user or someone else - `likes`: Liked scores

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/flat_api/api/collection_api.rb', line 182

def delete_collection_with_http_info(collection, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CollectionApi.delete_collection ...'
  end
  # verify the required parameter 'collection' is set
  if @api_client.config.client_side_validation && collection.nil?
    fail ArgumentError, "Missing the required parameter 'collection' when calling CollectionApi.delete_collection"
  end
  # resource path
  local_var_path = '/collections/{collection}'.sub('{collection}', CGI.escape(collection.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"CollectionApi.delete_collection",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CollectionApi#delete_collection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_score_from_collection(collection, score, opts = {}) ⇒ nil

Delete a score from the collection This method will delete a score from the collection. Unlike DELETE /scores/{score}, this score will not remove the score from your account, but only from the collection. This can be used to move a score from one collection to another, or simply remove a score from one collection when this one is contained in multiple collections.

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted

  • score (String)

    Unique identifier of the score document. This can be a Flat Score unique identifier (i.e. `ScoreDetails.id`) or, if the score is also a Google Drive file, the Drive file unique identifier prefixed with `drive-` (e.g. `drive-0B000000000`).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :event_properties (String)

    Optional analytics properties merged into XP tracking for this request. JSON-encoded string representing event properties. Example: - `?eventProperties=\"context\":\"discover\",\"screenLevel0\":\"home\"`

  • :sharing_key (String)

    This sharing key must be specified to access to a score or collection with a `privacy` mode set to `privateLink` and the current user is not a collaborator of the document.

Returns:

  • (nil)


238
239
240
241
# File 'lib/flat_api/api/collection_api.rb', line 238

def delete_score_from_collection(collection, score, opts = {})
  delete_score_from_collection_with_http_info(collection, score, opts)
  nil
end

#delete_score_from_collection_with_http_info(collection, score, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a score from the collection This method will delete a score from the collection. Unlike `DELETE /scores/score`, this score will not remove the score from your account, but only from the collection. This can be used to move a score from one collection to another, or simply remove a score from one collection when this one is contained in multiple collections.

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted

  • score (String)

    Unique identifier of the score document. This can be a Flat Score unique identifier (i.e. `ScoreDetails.id`) or, if the score is also a Google Drive file, the Drive file unique identifier prefixed with `drive-` (e.g. `drive-0B000000000`).

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :event_properties (String)

    Optional analytics properties merged into XP tracking for this request. JSON-encoded string representing event properties. Example: - `?eventProperties=\"context\":\"discover\",\"screenLevel0\":\"home\"`

  • :sharing_key (String)

    This sharing key must be specified to access to a score or collection with a `privacy` mode set to `privateLink` and the current user is not a collaborator of the document.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/flat_api/api/collection_api.rb', line 251

def delete_score_from_collection_with_http_info(collection, score, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CollectionApi.delete_score_from_collection ...'
  end
  # verify the required parameter 'collection' is set
  if @api_client.config.client_side_validation && collection.nil?
    fail ArgumentError, "Missing the required parameter 'collection' when calling CollectionApi.delete_score_from_collection"
  end
  # verify the required parameter 'score' is set
  if @api_client.config.client_side_validation && score.nil?
    fail ArgumentError, "Missing the required parameter 'score' when calling CollectionApi.delete_score_from_collection"
  end
  # resource path
  local_var_path = '/collections/{collection}/scores/{score}'.sub('{collection}', CGI.escape(collection.to_s)).sub('{score}', CGI.escape(score.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'eventProperties'] = opts[:'event_properties'] if !opts[:'event_properties'].nil?
  query_params[:'sharingKey'] = opts[:'sharing_key'] if !opts[:'sharing_key'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"CollectionApi.delete_score_from_collection",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CollectionApi#delete_score_from_collection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#edit_collection(collection, body, opts = {}) ⇒ Collection

Update a collection's metadata

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted The following virtual collections are supported: - `allScores`: All the scores contained in the user account - `collaborations`: All shared scores by the user or someone else - `likes`: Liked scores

  • body (CollectionModification)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



315
316
317
318
# File 'lib/flat_api/api/collection_api.rb', line 315

def edit_collection(collection, body, opts = {})
  data, _status_code, _headers = edit_collection_with_http_info(collection, body, opts)
  data
end

#edit_collection_with_http_info(collection, body, opts = {}) ⇒ Array<(Collection, Integer, Hash)>

Update a collection's metadata

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted The following virtual collections are supported: - `allScores`: All the scores contained in the user account - `collaborations`: All shared scores by the user or someone else - `likes`: Liked scores

  • body (CollectionModification)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Collection, Integer, Hash)>)

    Collection data, response status code and response headers



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/flat_api/api/collection_api.rb', line 325

def edit_collection_with_http_info(collection, body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CollectionApi.edit_collection ...'
  end
  # verify the required parameter 'collection' is set
  if @api_client.config.client_side_validation && collection.nil?
    fail ArgumentError, "Missing the required parameter 'collection' when calling CollectionApi.edit_collection"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CollectionApi.edit_collection"
  end
  # resource path
  local_var_path = '/collections/{collection}'.sub('{collection}', CGI.escape(collection.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'Collection'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"CollectionApi.edit_collection",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CollectionApi#edit_collection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_collection(collection, opts = {}) ⇒ Collection

Get collection details

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted The following virtual collections are supported: - `allScores`: All the scores contained in the user account - `collaborations`: All shared scores by the user or someone else - `likes`: Liked scores

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :sharing_key (String)

    This sharing key must be specified to access to a score or collection with a `privacy` mode set to `privateLink` and the current user is not a collaborator of the document.

Returns:



387
388
389
390
# File 'lib/flat_api/api/collection_api.rb', line 387

def get_collection(collection, opts = {})
  data, _status_code, _headers = get_collection_with_http_info(collection, opts)
  data
end

#get_collection_with_http_info(collection, opts = {}) ⇒ Array<(Collection, Integer, Hash)>

Get collection details

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted The following virtual collections are supported: - `allScores`: All the scores contained in the user account - `collaborations`: All shared scores by the user or someone else - `likes`: Liked scores

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :sharing_key (String)

    This sharing key must be specified to access to a score or collection with a `privacy` mode set to `privateLink` and the current user is not a collaborator of the document.

Returns:

  • (Array<(Collection, Integer, Hash)>)

    Collection data, response status code and response headers



397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/flat_api/api/collection_api.rb', line 397

def get_collection_with_http_info(collection, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CollectionApi.get_collection ...'
  end
  # verify the required parameter 'collection' is set
  if @api_client.config.client_side_validation && collection.nil?
    fail ArgumentError, "Missing the required parameter 'collection' when calling CollectionApi.get_collection"
  end
  # resource path
  local_var_path = '/collections/{collection}'.sub('{collection}', CGI.escape(collection.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'sharingKey'] = opts[:'sharing_key'] if !opts[:'sharing_key'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Collection'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"CollectionApi.get_collection",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CollectionApi#get_collection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_collection_scores(collection, opts = {}) ⇒ Array<ScoreDetails>

List the scores contained in a collection Use this method to list the scores contained in a collection. If no sort option is provided, the scores are sorted by modificationDate desc. For example, to list the scores contained in your app collection, you can use GET /v2/collections/app/scores.

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted The following virtual collections are supported: - `allScores`: All the scores contained in the user account - `collaborations`: All shared scores by the user or someone else - `likes`: Liked scores

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :sort (String)

    Sort

  • :direction (String)

    Sort direction

  • :limit (Integer)

    This is the maximum number of objects that may be returned (default to 25)

  • :_next (String)

    An opaque string cursor to fetch the next page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :previous (String)

    An opaque string cursor to fetch the previous page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :sharing_key (String)

    This sharing key must be specified to access to a score or collection with a `privacy` mode set to `privateLink` and the current user is not a collaborator of the document.

Returns:



457
458
459
460
# File 'lib/flat_api/api/collection_api.rb', line 457

def list_collection_scores(collection, opts = {})
  data, _status_code, _headers = list_collection_scores_with_http_info(collection, opts)
  data
end

#list_collection_scores_with_http_info(collection, opts = {}) ⇒ Array<(Array<ScoreDetails>, Integer, Hash)>

List the scores contained in a collection Use this method to list the scores contained in a collection. If no sort option is provided, the scores are sorted by `modificationDate` `desc`. For example, to list the scores contained in your app collection, you can use `GET /v2/collections/app/scores`.

Parameters:

  • collection (String)

    Unique identifier of the collection. The following collection aliases are supported: - `root`: Deprecated. The root collection of the account - `app`: Alias for the current app collection - `trash`: Automatically contains resources that have been deleted The following virtual collections are supported: - `allScores`: All the scores contained in the user account - `collaborations`: All shared scores by the user or someone else - `likes`: Liked scores

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :sort (String)

    Sort

  • :direction (String)

    Sort direction

  • :limit (Integer)

    This is the maximum number of objects that may be returned (default to 25)

  • :_next (String)

    An opaque string cursor to fetch the next page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :previous (String)

    An opaque string cursor to fetch the previous page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :sharing_key (String)

    This sharing key must be specified to access to a score or collection with a `privacy` mode set to `privateLink` and the current user is not a collaborator of the document.

Returns:

  • (Array<(Array<ScoreDetails>, Integer, Hash)>)

    Array data, response status code and response headers



473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
# File 'lib/flat_api/api/collection_api.rb', line 473

def list_collection_scores_with_http_info(collection, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CollectionApi.list_collection_scores ...'
  end
  # verify the required parameter 'collection' is set
  if @api_client.config.client_side_validation && collection.nil?
    fail ArgumentError, "Missing the required parameter 'collection' when calling CollectionApi.list_collection_scores"
  end
  allowable_values = ["creationDate", "modificationDate", "title"]
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  allowable_values = ["asc", "desc"]
  if @api_client.config.client_side_validation && opts[:'direction'] && !allowable_values.include?(opts[:'direction'])
    fail ArgumentError, "invalid value for \"direction\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CollectionApi.list_collection_scores, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CollectionApi.list_collection_scores, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/collections/{collection}/scores'.sub('{collection}', CGI.escape(collection.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'direction'] = opts[:'direction'] if !opts[:'direction'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil?
  query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil?
  query_params[:'sharingKey'] = opts[:'sharing_key'] if !opts[:'sharing_key'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<ScoreDetails>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"CollectionApi.list_collection_scores",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CollectionApi#list_collection_scores\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_collections(opts = {}) ⇒ Array<Collection>

List the collections Use this method to list the user's collections. If no sort option is provided, the collections are sorted by creationDate desc. By default (parent=user), this returns all user account collections with virtual collections on the first page. To fetch your app collection details, you can use GET /v2/collections/app.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :parent (String)

    List the collections contained in this `parent` collection. When set to `user` (default), returns the user's own collections as well as collections shared with the user. Using `root` or `sharedWithMe` is deprecated and will be treated as `user`. (default to 'user')

  • :sort (String)

    Sort

  • :direction (String)

    Sort direction

  • :limit (Integer)

    This is the maximum number of objects that may be returned (default to 25)

  • :_next (String)

    An opaque string cursor to fetch the next page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :previous (String)

    An opaque string cursor to fetch the previous page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

Returns:



553
554
555
556
# File 'lib/flat_api/api/collection_api.rb', line 553

def list_collections(opts = {})
  data, _status_code, _headers = list_collections_with_http_info(opts)
  data
end

#list_collections_with_http_info(opts = {}) ⇒ Array<(Array<Collection>, Integer, Hash)>

List the collections Use this method to list the user's collections. If no sort option is provided, the collections are sorted by `creationDate` `desc`. By default (`parent=user`), this returns all user account collections with virtual collections on the first page. To fetch your app collection details, you can use `GET /v2/collections/app`.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :parent (String)

    List the collections contained in this `parent` collection. When set to `user` (default), returns the user's own collections as well as collections shared with the user. Using `root` or `sharedWithMe` is deprecated and will be treated as `user`. (default to 'user')

  • :sort (String)

    Sort

  • :direction (String)

    Sort direction

  • :limit (Integer)

    This is the maximum number of objects that may be returned (default to 25)

  • :_next (String)

    An opaque string cursor to fetch the next page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :previous (String)

    An opaque string cursor to fetch the previous page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

Returns:

  • (Array<(Array<Collection>, Integer, Hash)>)

    Array data, response status code and response headers



568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
# File 'lib/flat_api/api/collection_api.rb', line 568

def list_collections_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CollectionApi.list_collections ...'
  end
  allowable_values = ["creationDate", "modificationDate", "title"]
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  allowable_values = ["asc", "desc"]
  if @api_client.config.client_side_validation && opts[:'direction'] && !allowable_values.include?(opts[:'direction'])
    fail ArgumentError, "invalid value for \"direction\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CollectionApi.list_collections, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling CollectionApi.list_collections, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/collections'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'parent'] = opts[:'parent'] if !opts[:'parent'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'direction'] = opts[:'direction'] if !opts[:'direction'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil?
  query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<Collection>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"CollectionApi.list_collections",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CollectionApi#list_collections\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#untrash_collection(collection, opts = {}) ⇒ FlatErrorResponse

Untrash a collection DEPRECATED This method will restore the collection by removing it from the trash and add it back to the root collection.

Parameters:

  • collection (String)

    Unique identifier of the collection.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



639
640
641
642
# File 'lib/flat_api/api/collection_api.rb', line 639

def untrash_collection(collection, opts = {})
  data, _status_code, _headers = untrash_collection_with_http_info(collection, opts)
  data
end

#untrash_collection_with_http_info(collection, opts = {}) ⇒ Array<(FlatErrorResponse, Integer, Hash)>

Untrash a collection DEPRECATED This method will restore the collection by removing it from the `trash` and add it back to the `root` collection.

Parameters:

  • collection (String)

    Unique identifier of the collection.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(FlatErrorResponse, Integer, Hash)>)

    FlatErrorResponse data, response status code and response headers



649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
# File 'lib/flat_api/api/collection_api.rb', line 649

def untrash_collection_with_http_info(collection, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CollectionApi.untrash_collection ...'
  end
  # verify the required parameter 'collection' is set
  if @api_client.config.client_side_validation && collection.nil?
    fail ArgumentError, "Missing the required parameter 'collection' when calling CollectionApi.untrash_collection"
  end
  # resource path
  local_var_path = '/collections/{collection}/untrash'.sub('{collection}', CGI.escape(collection.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'FlatErrorResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"CollectionApi.untrash_collection",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CollectionApi#untrash_collection\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end