Class: FlatApi::EduResourceCreation

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/edu_resource_creation.rb

Overview

Creation of an education resource

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EduResourceCreation

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/flat_api/models/edu_resource_creation.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::EduResourceCreation` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::EduResourceCreation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'parent')
    self.parent = attributes[:'parent']
  else
    self.parent = 'root'
  end

  if attributes.key?(:'sharing_description')
    self.sharing_description = attributes[:'sharing_description']
  end

  if attributes.key?(:'sharing_description_html')
    self.sharing_description_html = attributes[:'sharing_description_html']
  end

  if attributes.key?(:'resource')
    self.resource = attributes[:'resource']
  end
end

Instance Attribute Details

#parentObject

Identifier of the parent resource where the new one will created, e.g. a folder id or root



25
26
27
# File 'lib/flat_api/models/edu_resource_creation.rb', line 25

def parent
  @parent
end

#resourceObject

Returns the value of attribute resource.



33
34
35
# File 'lib/flat_api/models/edu_resource_creation.rb', line 33

def resource
  @resource
end

#sharing_descriptionObject

Sharing description of the resource



28
29
30
# File 'lib/flat_api/models/edu_resource_creation.rb', line 28

def sharing_description
  @sharing_description
end

#sharing_description_htmlObject

HTML version of sharing description with rich text formatting. Supports safe HTML tags: p, br, strong, b, em, i, u, a.



31
32
33
# File 'lib/flat_api/models/edu_resource_creation.rb', line 31

def sharing_description_html
  @sharing_description_html
end

#titleObject

Title of the resource



22
23
24
# File 'lib/flat_api/models/edu_resource_creation.rb', line 22

def title
  @title
end

#typeObject

Returns the value of attribute type.



19
20
21
# File 'lib/flat_api/models/edu_resource_creation.rb', line 19

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/flat_api/models/edu_resource_creation.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/flat_api/models/edu_resource_creation.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/flat_api/models/edu_resource_creation.rb', line 58

def self.attribute_map
  {
    :'type' => :'type',
    :'title' => :'title',
    :'parent' => :'parent',
    :'sharing_description' => :'sharingDescription',
    :'sharing_description_html' => :'sharingDescriptionHtml',
    :'resource' => :'resource'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/flat_api/models/edu_resource_creation.rb', line 273

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/flat_api/models/edu_resource_creation.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/flat_api/models/edu_resource_creation.rb', line 80

def self.openapi_types
  {
    :'type' => :'EduResourceType',
    :'title' => :'String',
    :'parent' => :'String',
    :'sharing_description' => :'String',
    :'sharing_description_html' => :'String',
    :'resource' => :'EduResourceAssignmentCreation'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



247
248
249
250
251
252
253
254
255
256
# File 'lib/flat_api/models/edu_resource_creation.rb', line 247

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      title == o.title &&
      parent == o.parent &&
      sharing_description == o.sharing_description &&
      sharing_description_html == o.sharing_description_html &&
      resource == o.resource
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/flat_api/models/edu_resource_creation.rb', line 260

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



266
267
268
# File 'lib/flat_api/models/edu_resource_creation.rb', line 266

def hash
  [type, title, parent, sharing_description, sharing_description_html, resource].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/flat_api/models/edu_resource_creation.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @title.to_s.length > 1000
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 1000.')
  end

  if @title.to_s.length < 1
    invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.')
  end

  if !@sharing_description.nil? && @sharing_description.to_s.length > 400
    invalid_properties.push('invalid value for "sharing_description", the character length must be smaller than or equal to 400.')
  end

  if !@sharing_description_html.nil? && @sharing_description_html.to_s.length > 10000
    invalid_properties.push('invalid value for "sharing_description_html", the character length must be smaller than or equal to 10000.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/flat_api/models/edu_resource_creation.rb', line 295

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
185
186
187
# File 'lib/flat_api/models/edu_resource_creation.rb', line 178

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  return false if @title.nil?
  return false if @title.to_s.length > 1000
  return false if @title.to_s.length < 1
  return false if !@sharing_description.nil? && @sharing_description.to_s.length > 400
  return false if !@sharing_description_html.nil? && @sharing_description_html.to_s.length > 10000
  true
end