Class: FlatApi::EduResourceUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::EduResourceUpdate
- Defined in:
- lib/flat_api/models/edu_resource_update.rb
Overview
Update of an education resource
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#grades ⇒ Object
The grades of this resource, or the grades of the resources included in the folder.
-
#privacy ⇒ Object
Returns the value of attribute privacy.
-
#sharing_description ⇒ Object
Sharing description of the resource.
-
#sharing_description_html ⇒ Object
HTML version of sharing description with rich text formatting.
-
#subjects ⇒ Object
The subjects of this resource, or the subjects of the resources included in the folder.
-
#title ⇒ Object
Title of the resource.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EduResourceUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EduResourceUpdate
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::EduResourceUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::EduResourceUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'sharing_description') self.sharing_description = attributes[:'sharing_description'] end if attributes.key?(:'sharing_description_html') self.sharing_description_html = attributes[:'sharing_description_html'] end if attributes.key?(:'privacy') self.privacy = attributes[:'privacy'] else self.privacy = 'private' end if attributes.key?(:'subjects') if (value = attributes[:'subjects']).is_a?(Array) self.subjects = value end end if attributes.key?(:'grades') if (value = attributes[:'grades']).is_a?(Array) self.grades = value end end end |
Instance Attribute Details
#grades ⇒ Object
The grades of this resource, or the grades of the resources included in the folder.
34 35 36 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 34 def grades @grades end |
#privacy ⇒ Object
Returns the value of attribute privacy.
28 29 30 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 28 def privacy @privacy end |
#sharing_description ⇒ Object
Sharing description of the resource
23 24 25 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 23 def sharing_description @sharing_description end |
#sharing_description_html ⇒ Object
HTML version of sharing description with rich text formatting. Supports safe HTML tags: p, br, strong, b, em, i, u, a.
26 27 28 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 26 def sharing_description_html @sharing_description_html end |
#subjects ⇒ Object
The subjects of this resource, or the subjects of the resources included in the folder
31 32 33 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 31 def subjects @subjects end |
#title ⇒ Object
Title of the resource
20 21 22 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 20 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 59 def self.attribute_map { :'title' => :'title', :'sharing_description' => :'sharingDescription', :'sharing_description_html' => :'sharingDescriptionHtml', :'privacy' => :'privacy', :'subjects' => :'subjects', :'grades' => :'grades' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 254 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 81 def self.openapi_types { :'title' => :'String', :'sharing_description' => :'String', :'sharing_description_html' => :'String', :'privacy' => :'EduResourcePrivacy', :'subjects' => :'Array<TeachingTheme>', :'grades' => :'Array<Grade>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 228 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && sharing_description == o.sharing_description && sharing_description_html == o.sharing_description_html && privacy == o.privacy && subjects == o.subjects && grades == o.grades end |
#eql?(o) ⇒ Boolean
241 242 243 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 241 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
247 248 249 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 247 def hash [title, sharing_description, sharing_description_html, privacy, subjects, grades].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@title.nil? && @title.to_s.length > 1000 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 1000.') end if !@title.nil? && @title.to_s.length < 1 invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.') end if !@sharing_description.nil? && @sharing_description.to_s.length > 400 invalid_properties.push('invalid value for "sharing_description", the character length must be smaller than or equal to 400.') end if !@sharing_description_html.nil? && @sharing_description_html.to_s.length > 10000 invalid_properties.push('invalid value for "sharing_description_html", the character length must be smaller than or equal to 10000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 276 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 178 |
# File 'lib/flat_api/models/edu_resource_update.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@title.nil? && @title.to_s.length > 1000 return false if !@title.nil? && @title.to_s.length < 1 return false if !@sharing_description.nil? && @sharing_description.to_s.length > 400 return false if !@sharing_description_html.nil? && @sharing_description_html.to_s.length > 10000 true end |