Class: FlatApi::Group
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::Group
- Defined in:
- lib/flat_api/models/group.rb
Overview
A group of users
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#creation_date ⇒ Object
The creation date of the group.
-
#id ⇒ Object
The unique identifier of the group.
-
#name ⇒ Object
The display name of the group.
-
#organization ⇒ Object
If the group is related to an organization, this field will contain the unique identifier of the organization.
-
#read_only ⇒ Object
Trueif the group is set in read-only. -
#type ⇒ Object
Returns the value of attribute type.
-
#users_count ⇒ Object
The number of users in this group.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Group
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Group
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/flat_api/models/group.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::Group` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::Group`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'users_count') self.users_count = attributes[:'users_count'] end if attributes.key?(:'read_only') self.read_only = attributes[:'read_only'] end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end end |
Instance Attribute Details
#creation_date ⇒ Object
The creation date of the group
37 38 39 |
# File 'lib/flat_api/models/group.rb', line 37 def creation_date @creation_date end |
#id ⇒ Object
The unique identifier of the group
20 21 22 |
# File 'lib/flat_api/models/group.rb', line 20 def id @id end |
#name ⇒ Object
The display name of the group
23 24 25 |
# File 'lib/flat_api/models/group.rb', line 23 def name @name end |
#organization ⇒ Object
If the group is related to an organization, this field will contain the unique identifier of the organization
34 35 36 |
# File 'lib/flat_api/models/group.rb', line 34 def organization @organization end |
#read_only ⇒ Object
True if the group is set in read-only
31 32 33 |
# File 'lib/flat_api/models/group.rb', line 31 def read_only @read_only end |
#type ⇒ Object
Returns the value of attribute type.
25 26 27 |
# File 'lib/flat_api/models/group.rb', line 25 def type @type end |
#users_count ⇒ Object
The number of users in this group
28 29 30 |
# File 'lib/flat_api/models/group.rb', line 28 def users_count @users_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/flat_api/models/group.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/flat_api/models/group.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/flat_api/models/group.rb', line 62 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'type' => :'type', :'users_count' => :'usersCount', :'read_only' => :'readOnly', :'organization' => :'organization', :'creation_date' => :'creationDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/flat_api/models/group.rb', line 192 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/flat_api/models/group.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/flat_api/models/group.rb', line 85 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'type' => :'GroupType', :'users_count' => :'Float', :'read_only' => :'Boolean', :'organization' => :'String', :'creation_date' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/flat_api/models/group.rb', line 165 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && type == o.type && users_count == o.users_count && read_only == o.read_only && organization == o.organization && creation_date == o.creation_date end |
#eql?(o) ⇒ Boolean
179 180 181 |
# File 'lib/flat_api/models/group.rb', line 179 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
185 186 187 |
# File 'lib/flat_api/models/group.rb', line 185 def hash [id, name, type, users_count, read_only, organization, creation_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 |
# File 'lib/flat_api/models/group.rb', line 150 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/flat_api/models/group.rb', line 214 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
158 159 160 161 |
# File 'lib/flat_api/models/group.rb', line 158 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |