Class: FlatApi::GroupApi
- Inherits:
-
Object
- Object
- FlatApi::GroupApi
- Defined in:
- lib/flat_api/api/group_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#add_group_user(group, add_group_user_request, opts = {}) ⇒ AddGroupUser200Response
Add a student to a group Add a student to the specified group (must be in the same class).
-
#add_group_user_with_http_info(group, add_group_user_request, opts = {}) ⇒ Array<(AddGroupUser200Response, Integer, Hash)>
Add a student to a group Add a student to the specified group (must be in the same class).
-
#create_group(group_creation, opts = {}) ⇒ GroupDetails
Create a new group Create a group of the given type, tied to a classroom, optionally with initial members.
-
#create_group_with_http_info(group_creation, opts = {}) ⇒ Array<(GroupDetails, Integer, Hash)>
Create a new group Create a group of the given type, tied to a classroom, optionally with initial members.
-
#delete_group(group, opts = {}) ⇒ nil
Delete a group Delete a group.
-
#delete_group_with_http_info(group, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a group Delete a group.
-
#get_group_details(group, opts = {}) ⇒ GroupDetails
Get group information.
-
#get_group_details_with_http_info(group, opts = {}) ⇒ Array<(GroupDetails, Integer, Hash)>
Get group information.
-
#get_group_scores(group, opts = {}) ⇒ Array<ScoreDetails>
List group's scores Get the list of scores shared with a group.
-
#get_group_scores_with_http_info(group, opts = {}) ⇒ Array<(Array<ScoreDetails>, Integer, Hash)>
List group's scores Get the list of scores shared with a group.
-
#initialize(api_client = ApiClient.default) ⇒ GroupApi
constructor
A new instance of GroupApi.
-
#list_group_users(group, opts = {}) ⇒ Array<UserPublic>
List group's users.
-
#list_group_users_with_http_info(group, opts = {}) ⇒ Array<(Array<UserPublic>, Integer, Hash)>
List group's users.
-
#list_groups(type, opts = {}) ⇒ Array<GroupDetails>
List groups List all groups of a given type, filtered by either a classroom or an assignment.
-
#list_groups_with_http_info(type, opts = {}) ⇒ Array<(Array<GroupDetails>, Integer, Hash)>
List groups List all groups of a given type, filtered by either a classroom or an assignment.
-
#remove_group_user(group, user, opts = {}) ⇒ nil
Remove a student from a class group Remove a student from a class group.
-
#remove_group_user_with_http_info(group, user, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove a student from a class group Remove a student from a class group.
-
#rename_group(group, rename_group_request, opts = {}) ⇒ GroupDetails
Rename a group Rename a sub-group.
-
#rename_group_with_http_info(group, rename_group_request, opts = {}) ⇒ Array<(GroupDetails, Integer, Hash)>
Rename a group Rename a sub-group.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/flat_api/api/group_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#add_group_user(group, add_group_user_request, opts = {}) ⇒ AddGroupUser200Response
Add a student to a group Add a student to the specified group (must be in the same class)
28 29 30 31 |
# File 'lib/flat_api/api/group_api.rb', line 28 def add_group_user(group, add_group_user_request, opts = {}) data, _status_code, _headers = add_group_user_with_http_info(group, add_group_user_request, opts) data end |
#add_group_user_with_http_info(group, add_group_user_request, opts = {}) ⇒ Array<(AddGroupUser200Response, Integer, Hash)>
Add a student to a group Add a student to the specified group (must be in the same class)
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/flat_api/api/group_api.rb', line 39 def add_group_user_with_http_info(group, add_group_user_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupApi.add_group_user ...' end # verify the required parameter 'group' is set if @api_client.config.client_side_validation && group.nil? fail ArgumentError, "Missing the required parameter 'group' when calling GroupApi.add_group_user" end # verify the required parameter 'add_group_user_request' is set if @api_client.config.client_side_validation && add_group_user_request.nil? fail ArgumentError, "Missing the required parameter 'add_group_user_request' when calling GroupApi.add_group_user" end # resource path local_var_path = '/groups/{group}/users'.sub('{group}', CGI.escape(group.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(add_group_user_request) # return_type return_type = opts[:debug_return_type] || 'AddGroupUser200Response' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"GroupApi.add_group_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupApi#add_group_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_group(group_creation, opts = {}) ⇒ GroupDetails
Create a new group Create a group of the given type, tied to a classroom, optionally with initial members.
101 102 103 104 |
# File 'lib/flat_api/api/group_api.rb', line 101 def create_group(group_creation, opts = {}) data, _status_code, _headers = create_group_with_http_info(group_creation, opts) data end |
#create_group_with_http_info(group_creation, opts = {}) ⇒ Array<(GroupDetails, Integer, Hash)>
Create a new group Create a group of the given type, tied to a classroom, optionally with initial members.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/flat_api/api/group_api.rb', line 111 def create_group_with_http_info(group_creation, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupApi.create_group ...' end # verify the required parameter 'group_creation' is set if @api_client.config.client_side_validation && group_creation.nil? fail ArgumentError, "Missing the required parameter 'group_creation' when calling GroupApi.create_group" end # resource path local_var_path = '/groups' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(group_creation) # return_type return_type = opts[:debug_return_type] || 'GroupDetails' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"GroupApi.create_group", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupApi#create_group\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_group(group, opts = {}) ⇒ nil
Delete a group Delete a group. Only available to teachers of the classroom.
169 170 171 172 |
# File 'lib/flat_api/api/group_api.rb', line 169 def delete_group(group, opts = {}) delete_group_with_http_info(group, opts) nil end |
#delete_group_with_http_info(group, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a group Delete a group. Only available to teachers of the classroom.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/flat_api/api/group_api.rb', line 179 def delete_group_with_http_info(group, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupApi.delete_group ...' end # verify the required parameter 'group' is set if @api_client.config.client_side_validation && group.nil? fail ArgumentError, "Missing the required parameter 'group' when calling GroupApi.delete_group" end # resource path local_var_path = '/groups/{group}'.sub('{group}', CGI.escape(group.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"GroupApi.delete_group", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupApi#delete_group\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_group_details(group, opts = {}) ⇒ GroupDetails
Get group information
231 232 233 234 |
# File 'lib/flat_api/api/group_api.rb', line 231 def get_group_details(group, opts = {}) data, _status_code, _headers = get_group_details_with_http_info(group, opts) data end |
#get_group_details_with_http_info(group, opts = {}) ⇒ Array<(GroupDetails, Integer, Hash)>
Get group information
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/flat_api/api/group_api.rb', line 240 def get_group_details_with_http_info(group, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupApi.get_group_details ...' end # verify the required parameter 'group' is set if @api_client.config.client_side_validation && group.nil? fail ArgumentError, "Missing the required parameter 'group' when calling GroupApi.get_group_details" end # resource path local_var_path = '/groups/{group}'.sub('{group}', CGI.escape(group.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GroupDetails' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"GroupApi.get_group_details", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupApi#get_group_details\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_group_scores(group, opts = {}) ⇒ Array<ScoreDetails>
List group's scores Get the list of scores shared with a group.
294 295 296 297 |
# File 'lib/flat_api/api/group_api.rb', line 294 def get_group_scores(group, opts = {}) data, _status_code, _headers = get_group_scores_with_http_info(group, opts) data end |
#get_group_scores_with_http_info(group, opts = {}) ⇒ Array<(Array<ScoreDetails>, Integer, Hash)>
List group's scores Get the list of scores shared with a group.
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/flat_api/api/group_api.rb', line 305 def get_group_scores_with_http_info(group, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupApi.get_group_scores ...' end # verify the required parameter 'group' is set if @api_client.config.client_side_validation && group.nil? fail ArgumentError, "Missing the required parameter 'group' when calling GroupApi.get_group_scores" end # resource path local_var_path = '/groups/{group}/scores'.sub('{group}', CGI.escape(group.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'parent'] = opts[:'parent'] if !opts[:'parent'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<ScoreDetails>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"GroupApi.get_group_scores", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupApi#get_group_scores\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_group_users(group, opts = {}) ⇒ Array<UserPublic>
List group's users
359 360 361 362 |
# File 'lib/flat_api/api/group_api.rb', line 359 def list_group_users(group, opts = {}) data, _status_code, _headers = list_group_users_with_http_info(group, opts) data end |
#list_group_users_with_http_info(group, opts = {}) ⇒ Array<(Array<UserPublic>, Integer, Hash)>
List group's users
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/flat_api/api/group_api.rb', line 369 def list_group_users_with_http_info(group, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupApi.list_group_users ...' end # verify the required parameter 'group' is set if @api_client.config.client_side_validation && group.nil? fail ArgumentError, "Missing the required parameter 'group' when calling GroupApi.list_group_users" end allowable_values = ["googleClassroom", "microsoftGraph", "clever"] if @api_client.config.client_side_validation && opts[:'source'] && !allowable_values.include?(opts[:'source']) fail ArgumentError, "invalid value for \"source\", must be one of #{allowable_values}" end # resource path local_var_path = '/groups/{group}/users'.sub('{group}', CGI.escape(group.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'source'] = opts[:'source'] if !opts[:'source'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<UserPublic>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"GroupApi.list_group_users", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupApi#list_group_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_groups(type, opts = {}) ⇒ Array<GroupDetails>
List groups List all groups of a given type, filtered by either a classroom or an assignment.
429 430 431 432 |
# File 'lib/flat_api/api/group_api.rb', line 429 def list_groups(type, opts = {}) data, _status_code, _headers = list_groups_with_http_info(type, opts) data end |
#list_groups_with_http_info(type, opts = {}) ⇒ Array<(Array<GroupDetails>, Integer, Hash)>
List groups List all groups of a given type, filtered by either a classroom or an assignment.
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/flat_api/api/group_api.rb', line 441 def list_groups_with_http_info(type, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupApi.list_groups ...' end # verify the required parameter 'type' is set if @api_client.config.client_side_validation && type.nil? fail ArgumentError, "Missing the required parameter 'type' when calling GroupApi.list_groups" end # verify enum value allowable_values = ["classStudentsSubGroup", "assignmentStudentsSubGroup"] if @api_client.config.client_side_validation && !allowable_values.include?(type) fail ArgumentError, "invalid value for \"type\", must be one of #{allowable_values}" end # resource path local_var_path = '/groups' # query parameters query_params = opts[:query_params] || {} query_params[:'type'] = type query_params[:'classroom'] = opts[:'classroom'] if !opts[:'classroom'].nil? query_params[:'assignment'] = opts[:'assignment'] if !opts[:'assignment'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<GroupDetails>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"GroupApi.list_groups", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupApi#list_groups\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_group_user(group, user, opts = {}) ⇒ nil
Remove a student from a class group Remove a student from a class group
503 504 505 506 |
# File 'lib/flat_api/api/group_api.rb', line 503 def remove_group_user(group, user, opts = {}) remove_group_user_with_http_info(group, user, opts) nil end |
#remove_group_user_with_http_info(group, user, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove a student from a class group Remove a student from a class group
514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 |
# File 'lib/flat_api/api/group_api.rb', line 514 def remove_group_user_with_http_info(group, user, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupApi.remove_group_user ...' end # verify the required parameter 'group' is set if @api_client.config.client_side_validation && group.nil? fail ArgumentError, "Missing the required parameter 'group' when calling GroupApi.remove_group_user" end # verify the required parameter 'user' is set if @api_client.config.client_side_validation && user.nil? fail ArgumentError, "Missing the required parameter 'user' when calling GroupApi.remove_group_user" end # resource path local_var_path = '/groups/{group}/users/{user}'.sub('{group}', CGI.escape(group.to_s)).sub('{user}', CGI.escape(user.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"GroupApi.remove_group_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupApi#remove_group_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#rename_group(group, rename_group_request, opts = {}) ⇒ GroupDetails
Rename a group Rename a sub-group. Only available for class student groups.
572 573 574 575 |
# File 'lib/flat_api/api/group_api.rb', line 572 def rename_group(group, rename_group_request, opts = {}) data, _status_code, _headers = rename_group_with_http_info(group, rename_group_request, opts) data end |
#rename_group_with_http_info(group, rename_group_request, opts = {}) ⇒ Array<(GroupDetails, Integer, Hash)>
Rename a group Rename a sub-group. Only available for class student groups.
583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 |
# File 'lib/flat_api/api/group_api.rb', line 583 def rename_group_with_http_info(group, rename_group_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GroupApi.rename_group ...' end # verify the required parameter 'group' is set if @api_client.config.client_side_validation && group.nil? fail ArgumentError, "Missing the required parameter 'group' when calling GroupApi.rename_group" end # verify the required parameter 'rename_group_request' is set if @api_client.config.client_side_validation && rename_group_request.nil? fail ArgumentError, "Missing the required parameter 'rename_group_request' when calling GroupApi.rename_group" end # resource path local_var_path = '/groups/{group}'.sub('{group}', CGI.escape(group.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(rename_group_request) # return_type return_type = opts[:debug_return_type] || 'GroupDetails' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"GroupApi.rename_group", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GroupApi#rename_group\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |