Class: FlatApi::LtiConfiguration1p1

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/lti_configuration1p1.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LtiConfiguration1p1

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 141

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::LtiConfiguration1p1` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::LtiConfiguration1p1`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'lti_version')
    self.lti_version = attributes[:'lti_version']
  else
    self.lti_version = nil
  end

  if attributes.key?(:'organization_id')
    self.organization_id = attributes[:'organization_id']
  end

  if attributes.key?(:'organization_name')
    self.organization_name = attributes[:'organization_name']
  end

  if attributes.key?(:'creator_id')
    self.creator_id = attributes[:'creator_id']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'last_used_date')
    self.last_used_date = attributes[:'last_used_date']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'consumer_key')
    self.consumer_key = attributes[:'consumer_key']
  end

  if attributes.key?(:'consumer_secret')
    self.consumer_secret = attributes[:'consumer_secret']
  end

  if attributes.key?(:'lms')
    self.lms = attributes[:'lms']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'tool')
    self.tool = attributes[:'tool']
  end
end

Instance Attribute Details

#consumer_keyObject

LTI 1.1 consumer key



43
44
45
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 43

def consumer_key
  @consumer_key
end

#consumer_secretObject

LTI 1.1 consumer secret (only included for admins)



46
47
48
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 46

def consumer_secret
  @consumer_secret
end

#creation_dateObject

Configuration creation date



34
35
36
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 34

def creation_date
  @creation_date
end

#creator_idObject

ID of the user who created this configuration



31
32
33
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 31

def creator_id
  @creator_id
end

#idObject

Configuration ID



19
20
21
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 19

def id
  @id
end

#last_used_dateObject

Last time this configuration was used



37
38
39
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 37

def last_used_date
  @last_used_date
end

#lmsObject

LMS type



49
50
51
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 49

def lms
  @lms
end

#lti_versionObject

LTI version (1.1)



22
23
24
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 22

def lti_version
  @lti_version
end

#nameObject

Configuration name



52
53
54
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 52

def name
  @name
end

#organization_idObject

Organization ID



25
26
27
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 25

def organization_id
  @organization_id
end

#organization_nameObject

Organization name



28
29
30
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 28

def organization_name
  @organization_name
end

#statusObject

Configuration status indicator



40
41
42
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 40

def status
  @status
end

#toolObject

Returns the value of attribute tool.



54
55
56
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 54

def tool
  @tool
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



98
99
100
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 98

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



103
104
105
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 103

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 79

def self.attribute_map
  {
    :'id' => :'id',
    :'lti_version' => :'ltiVersion',
    :'organization_id' => :'organizationId',
    :'organization_name' => :'organizationName',
    :'creator_id' => :'creatorId',
    :'creation_date' => :'creationDate',
    :'last_used_date' => :'lastUsedDate',
    :'status' => :'status',
    :'consumer_key' => :'consumerKey',
    :'consumer_secret' => :'consumerSecret',
    :'lms' => :'lms',
    :'name' => :'name',
    :'tool' => :'tool'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 323

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



133
134
135
136
137
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 133

def self.openapi_all_of
  [
  :'LtiConfigurationBase'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 108

def self.openapi_types
  {
    :'id' => :'String',
    :'lti_version' => :'String',
    :'organization_id' => :'String',
    :'organization_name' => :'String',
    :'creator_id' => :'String',
    :'creation_date' => :'Time',
    :'last_used_date' => :'Time',
    :'status' => :'String',
    :'consumer_key' => :'String',
    :'consumer_secret' => :'String',
    :'lms' => :'String',
    :'name' => :'String',
    :'tool' => :'LtiConfiguration1p1AllOfTool'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 290

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      lti_version == o.lti_version &&
      organization_id == o.organization_id &&
      organization_name == o.organization_name &&
      creator_id == o.creator_id &&
      creation_date == o.creation_date &&
      last_used_date == o.last_used_date &&
      status == o.status &&
      consumer_key == o.consumer_key &&
      consumer_secret == o.consumer_secret &&
      lms == o.lms &&
      name == o.name &&
      tool == o.tool
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 310

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



316
317
318
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 316

def hash
  [id, lti_version, organization_id, organization_name, creator_id, creation_date, last_used_date, status, consumer_key, consumer_secret, lms, name, tool].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 216

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @lti_version.nil?
    invalid_properties.push('invalid value for "lti_version", lti_version cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 345

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



236
237
238
239
240
241
242
243
244
245
246
# File 'lib/flat_api/models/lti_configuration1p1.rb', line 236

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @lti_version.nil?
  lti_version_validator = EnumAttributeValidator.new('String', ["1p1"])
  return false unless lti_version_validator.valid?(@lti_version)
  return false if @creation_date.nil?
  status_validator = EnumAttributeValidator.new('String', ["ready-to-use", "in-use", "incomplete-setup"])
  return false unless status_validator.valid?(@status)
  true
end