Class: FlatApi::LtiConfigurationCreate1p3Manual

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/flat_api/models/lti_configuration_create1p3_manual.rb

Overview

LTI 1.3 manual configuration creation

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LtiConfigurationCreate1p3Manual

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::LtiConfigurationCreate1p3Manual` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::LtiConfigurationCreate1p3Manual`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = nil
  end

  if attributes.key?(:'platform_iss')
    self.platform_iss = attributes[:'platform_iss']
  end

  if attributes.key?(:'platform_name')
    self.platform_name = attributes[:'platform_name']
  end

  if attributes.key?(:'client_id')
    self.client_id = attributes[:'client_id']
  end

  if attributes.key?(:'deployment_id')
    self.deployment_id = attributes[:'deployment_id']
  end

  if attributes.key?(:'access_token_url')
    self.access_token_url = attributes[:'access_token_url']
  end

  if attributes.key?(:'authorization_url')
    self.authorization_url = attributes[:'authorization_url']
  end

  if attributes.key?(:'jwks_url')
    self.jwks_url = attributes[:'jwks_url']
  end

  if attributes.key?(:'enable_email_matching')
    self.enable_email_matching = attributes[:'enable_email_matching']
  end
end

Instance Attribute Details

#access_token_urlObject

Platform access token endpoint URL



35
36
37
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 35

def access_token_url
  @access_token_url
end

#authorization_urlObject

Platform OIDC authorization endpoint URL



38
39
40
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 38

def authorization_url
  @authorization_url
end

#client_idObject

OAuth2 client_id allocated by the platform



29
30
31
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 29

def client_id
  @client_id
end

#deployment_idObject

Deployment identifier provided by the platform



32
33
34
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 32

def deployment_id
  @deployment_id
end

#enable_email_matchingObject

Enable email-based user matching during LTI authentication



44
45
46
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 44

def enable_email_matching
  @enable_email_matching
end

#jwks_urlObject

Platform JWKS endpoint URL for public keys



41
42
43
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 41

def jwks_url
  @jwks_url
end

#modeObject

LTI 1.3 manual creation mode



20
21
22
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 20

def mode
  @mode
end

#platform_issObject

Platform issuer URL



23
24
25
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 23

def platform_iss
  @platform_iss
end

#platform_nameObject

Platform display name



26
27
28
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 26

def platform_name
  @platform_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



84
85
86
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 84

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 89

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 69

def self.attribute_map
  {
    :'mode' => :'mode',
    :'platform_iss' => :'platformIss',
    :'platform_name' => :'platformName',
    :'client_id' => :'clientId',
    :'deployment_id' => :'deploymentId',
    :'access_token_url' => :'accessTokenUrl',
    :'authorization_url' => :'authorizationUrl',
    :'jwks_url' => :'jwksUrl',
    :'enable_email_matching' => :'enableEmailMatching'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 232

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 109

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 94

def self.openapi_types
  {
    :'mode' => :'String',
    :'platform_iss' => :'String',
    :'platform_name' => :'String',
    :'client_id' => :'String',
    :'deployment_id' => :'String',
    :'access_token_url' => :'String',
    :'authorization_url' => :'String',
    :'jwks_url' => :'String',
    :'enable_email_matching' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      mode == o.mode &&
      platform_iss == o.platform_iss &&
      platform_name == o.platform_name &&
      client_id == o.client_id &&
      deployment_id == o.deployment_id &&
      access_token_url == o.access_token_url &&
      authorization_url == o.authorization_url &&
      jwks_url == o.jwks_url &&
      enable_email_matching == o.enable_email_matching
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


219
220
221
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 219

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



225
226
227
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 225

def hash
  [mode, platform_iss, platform_name, client_id, deployment_id, access_token_url, authorization_url, jwks_url, enable_email_matching].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



171
172
173
174
175
176
177
178
179
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 171

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @mode.nil?
    invalid_properties.push('invalid value for "mode", mode cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 254

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
# File 'lib/flat_api/models/lti_configuration_create1p3_manual.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @mode.nil?
  mode_validator = EnumAttributeValidator.new('String', ["1p3-manual"])
  return false unless mode_validator.valid?(@mode)
  true
end