Class: FlatApi::LtiConfigurationUpdateStandalone
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::LtiConfigurationUpdateStandalone
- Defined in:
- lib/flat_api/models/lti_configuration_update_standalone.rb
Overview
Update fields allowed for standalone (manual/dynamic) configurations
Instance Attribute Summary collapse
-
#access_token_url ⇒ Object
Platform access token endpoint URL.
-
#authorization_url ⇒ Object
Platform OIDC authorization endpoint URL.
-
#client_id ⇒ Object
OAuth2 client_id allocated by the platform.
-
#deployment_id ⇒ Object
Deployment identifier provided by the platform.
-
#enable_email_matching ⇒ Object
Enable email-based user matching during LTI authentication.
-
#jwks_url ⇒ Object
Platform JWKS endpoint URL for public keys.
-
#platform_iss ⇒ Object
Platform issuer URL.
-
#platform_name ⇒ Object
Platform display name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LtiConfigurationUpdateStandalone
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LtiConfigurationUpdateStandalone
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::LtiConfigurationUpdateStandalone` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::LtiConfigurationUpdateStandalone`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'deployment_id') self.deployment_id = attributes[:'deployment_id'] end if attributes.key?(:'platform_iss') self.platform_iss = attributes[:'platform_iss'] end if attributes.key?(:'platform_name') self.platform_name = attributes[:'platform_name'] end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'access_token_url') self.access_token_url = attributes[:'access_token_url'] end if attributes.key?(:'authorization_url') self. = attributes[:'authorization_url'] end if attributes.key?(:'jwks_url') self.jwks_url = attributes[:'jwks_url'] end if attributes.key?(:'enable_email_matching') self.enable_email_matching = attributes[:'enable_email_matching'] end end |
Instance Attribute Details
#access_token_url ⇒ Object
Platform access token endpoint URL
32 33 34 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 32 def access_token_url @access_token_url end |
#authorization_url ⇒ Object
Platform OIDC authorization endpoint URL
35 36 37 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 35 def @authorization_url end |
#client_id ⇒ Object
OAuth2 client_id allocated by the platform
29 30 31 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 29 def client_id @client_id end |
#deployment_id ⇒ Object
Deployment identifier provided by the platform
20 21 22 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 20 def deployment_id @deployment_id end |
#enable_email_matching ⇒ Object
Enable email-based user matching during LTI authentication
41 42 43 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 41 def enable_email_matching @enable_email_matching end |
#jwks_url ⇒ Object
Platform JWKS endpoint URL for public keys
38 39 40 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 38 def jwks_url @jwks_url end |
#platform_iss ⇒ Object
Platform issuer URL
23 24 25 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 23 def platform_iss @platform_iss end |
#platform_name ⇒ Object
Platform display name
26 27 28 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 26 def platform_name @platform_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 44 def self.attribute_map { :'deployment_id' => :'deploymentId', :'platform_iss' => :'platformIss', :'platform_name' => :'platformName', :'client_id' => :'clientId', :'access_token_url' => :'accessTokenUrl', :'authorization_url' => :'authorizationUrl', :'jwks_url' => :'jwksUrl', :'enable_email_matching' => :'enableEmailMatching' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 181 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 82 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 68 def self.openapi_types { :'deployment_id' => :'String', :'platform_iss' => :'String', :'platform_name' => :'String', :'client_id' => :'String', :'access_token_url' => :'String', :'authorization_url' => :'String', :'jwks_url' => :'String', :'enable_email_matching' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && deployment_id == o.deployment_id && platform_iss == o.platform_iss && platform_name == o.platform_name && client_id == o.client_id && access_token_url == o.access_token_url && == o. && jwks_url == o.jwks_url && enable_email_matching == o.enable_email_matching end |
#eql?(o) ⇒ Boolean
168 169 170 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 168 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
174 175 176 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 174 def hash [deployment_id, platform_iss, platform_name, client_id, access_token_url, , jwks_url, enable_email_matching].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 203 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
146 147 148 149 |
# File 'lib/flat_api/models/lti_configuration_update_standalone.rb', line 146 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |