Class: FlatApi::LtiCredentials

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/lti_credentials.rb

Overview

A couple of LTI 1.x OAuth credentials

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LtiCredentials

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/flat_api/models/lti_credentials.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::LtiCredentials` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::LtiCredentials`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'lms')
    self.lms = attributes[:'lms']
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.key?(:'creator')
    self.creator = attributes[:'creator']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'last_usage')
    self.last_usage = attributes[:'last_usage']
  end

  if attributes.key?(:'consumer_key')
    self.consumer_key = attributes[:'consumer_key']
  end

  if attributes.key?(:'consumer_secret')
    self.consumer_secret = attributes[:'consumer_secret']
  end

  if attributes.key?(:'enable_email_matching')
    self.enable_email_matching = attributes[:'enable_email_matching']
  else
    self.enable_email_matching = true
  end
end

Instance Attribute Details

#consumer_keyObject

OAuth 1 Consumer Key



40
41
42
# File 'lib/flat_api/models/lti_credentials.rb', line 40

def consumer_key
  @consumer_key
end

#consumer_secretObject

OAuth 1 Consumer Secret



43
44
45
# File 'lib/flat_api/models/lti_credentials.rb', line 43

def consumer_secret
  @consumer_secret
end

#creation_dateObject

The creation date of thse credentials



34
35
36
# File 'lib/flat_api/models/lti_credentials.rb', line 34

def creation_date
  @creation_date
end

#creatorObject

Unique identifier of the user who created these credentials



31
32
33
# File 'lib/flat_api/models/lti_credentials.rb', line 31

def creator
  @creator
end

#enable_email_matchingObject

Enable email-based user matching during LTI authentication. When true (default): If a user with the same email exists in the organization, they will be matched and logged in instead of creating a new account. When false: Email matching is disabled. Only LTI ID matching is used, which means multiple LTI users can share the same email address and have separate Flat accounts. This is useful for cases like siblings sharing a parent email in the LMS.



46
47
48
# File 'lib/flat_api/models/lti_credentials.rb', line 46

def enable_email_matching
  @enable_email_matching
end

#idObject

The unique identifier of this couple of credentials



20
21
22
# File 'lib/flat_api/models/lti_credentials.rb', line 20

def id
  @id
end

#last_usageObject

The last time these credentials were used



37
38
39
# File 'lib/flat_api/models/lti_credentials.rb', line 37

def last_usage
  @last_usage
end

#lmsObject

Returns the value of attribute lms.



25
26
27
# File 'lib/flat_api/models/lti_credentials.rb', line 25

def lms
  @lms
end

#nameObject

Name of the couple of credentials



23
24
25
# File 'lib/flat_api/models/lti_credentials.rb', line 23

def name
  @name
end

#organizationObject

The unique identifier of the Organization associated to these credentials



28
29
30
# File 'lib/flat_api/models/lti_credentials.rb', line 28

def organization
  @organization
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



87
88
89
# File 'lib/flat_api/models/lti_credentials.rb', line 87

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



92
93
94
# File 'lib/flat_api/models/lti_credentials.rb', line 92

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/flat_api/models/lti_credentials.rb', line 71

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'lms' => :'lms',
    :'organization' => :'organization',
    :'creator' => :'creator',
    :'creation_date' => :'creationDate',
    :'last_usage' => :'lastUsage',
    :'consumer_key' => :'consumerKey',
    :'consumer_secret' => :'consumerSecret',
    :'enable_email_matching' => :'enableEmailMatching'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/flat_api/models/lti_credentials.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
# File 'lib/flat_api/models/lti_credentials.rb', line 113

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/flat_api/models/lti_credentials.rb', line 97

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'lms' => :'LmsName',
    :'organization' => :'String',
    :'creator' => :'String',
    :'creation_date' => :'Time',
    :'last_usage' => :'Time',
    :'consumer_key' => :'String',
    :'consumer_secret' => :'String',
    :'enable_email_matching' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/flat_api/models/lti_credentials.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      lms == o.lms &&
      organization == o.organization &&
      creator == o.creator &&
      creation_date == o.creation_date &&
      last_usage == o.last_usage &&
      consumer_key == o.consumer_key &&
      consumer_secret == o.consumer_secret &&
      enable_email_matching == o.enable_email_matching
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/flat_api/models/lti_credentials.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/flat_api/models/lti_credentials.rb', line 217

def hash
  [id, name, lms, organization, creator, creation_date, last_usage, consumer_key, consumer_secret, enable_email_matching].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
# File 'lib/flat_api/models/lti_credentials.rb', line 179

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/flat_api/models/lti_credentials.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



187
188
189
190
# File 'lib/flat_api/models/lti_credentials.rb', line 187

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end