Class: FlatApi::MicrosoftGraphAssignment

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/microsoft_graph_assignment.rb

Overview

A Microsoft Teams assignment

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MicrosoftGraphAssignment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::MicrosoftGraphAssignment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::MicrosoftGraphAssignment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'alternate_link')
    self.alternate_link = attributes[:'alternate_link']
  end

  if attributes.key?(:'assign_date_time')
    self.assign_date_time = attributes[:'assign_date_time']
  end

  if attributes.key?(:'categories')
    if (value = attributes[:'categories']).is_a?(Array)
      self.categories = value
    end
  end

  if attributes.key?(:'assign_to_type')
    self.assign_to_type = attributes[:'assign_to_type']
  end

  if attributes.key?(:'assigned_students_ms_ids')
    if (value = attributes[:'assigned_students_ms_ids']).is_a?(Array)
      self.assigned_students_ms_ids = value
    end
  end
end

Instance Attribute Details

Absolute link to this assignment in the Microsoft Teams web UI



26
27
28
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 26

def alternate_link
  @alternate_link
end

#assign_date_timeObject

The date when the assignment will become active on Microsoft Teams. If set to a future date, the assignment will have status scheduled and won't be visible to students until this date.



29
30
31
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 29

def assign_date_time
  @assign_date_time
end

#assign_to_typeObject

Recipient configuration for this assignment on Microsoft Teams. * class: Assignment is visible to all students in the class * individual: Assignment is visible only to specific assigned students



35
36
37
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 35

def assign_to_type
  @assign_to_type
end

#assigned_students_ms_idsObject

When assignToType is 'individual', array of Microsoft Azure user IDs of students assigned to this assignment. These are the students who can see and submit to this assignment on Teams.



38
39
40
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 38

def assigned_students_ms_ids
  @assigned_students_ms_ids
end

#categoriesObject

List of categories where this assignment is published under



32
33
34
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 32

def categories
  @categories
end

#idObject

Identifier of the assignment assigned by Microsoft Teams



20
21
22
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 20

def id
  @id
end

#stateObject

State of the assignment on Microsoft Teams. * draft: Assignment is in draft mode * scheduled: Assignment is scheduled to be published at a future date * published: Assignment has been published to students * assigned: Assignment has been assigned (legacy status) * inactive: Assignment is inactive



23
24
25
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 23

def state
  @state
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 63

def self.attribute_map
  {
    :'id' => :'id',
    :'state' => :'state',
    :'alternate_link' => :'alternateLink',
    :'assign_date_time' => :'assignDateTime',
    :'categories' => :'categories',
    :'assign_to_type' => :'assignToType',
    :'assigned_students_ms_ids' => :'assignedStudentsMsIds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 99

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 86

def self.openapi_types
  {
    :'id' => :'String',
    :'state' => :'String',
    :'alternate_link' => :'String',
    :'assign_date_time' => :'Time',
    :'categories' => :'Array<String>',
    :'assign_to_type' => :'String',
    :'assigned_students_ms_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



194
195
196
197
198
199
200
201
202
203
204
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      state == o.state &&
      alternate_link == o.alternate_link &&
      assign_date_time == o.assign_date_time &&
      categories == o.categories &&
      assign_to_type == o.assign_to_type &&
      assigned_students_ms_ids == o.assigned_students_ms_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 214

def hash
  [id, state, alternate_link, assign_date_time, categories, assign_to_type, assigned_students_ms_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
167
168
169
170
# File 'lib/flat_api/models/microsoft_graph_assignment.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  state_validator = EnumAttributeValidator.new('String', ["draft", "scheduled", "published", "assigned", "inactive"])
  return false unless state_validator.valid?(@state)
  assign_to_type_validator = EnumAttributeValidator.new('String', ["class", "individual"])
  return false unless assign_to_type_validator.valid?(@assign_to_type)
  true
end