Class: FlatApi::OmrDetailsSubmission

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/omr_details_submission.rb

Overview

Overrides for the details step. Omitted fields keep the server's detected values.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OmrDetailsSubmission

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/flat_api/models/omr_details_submission.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::OmrDetailsSubmission` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::OmrDetailsSubmission`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'step')
    self.step = attributes[:'step']
  else
    self.step = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'main_language')
    self.main_language = attributes[:'main_language']
  end

  if attributes.key?(:'instruments')
    if (value = attributes[:'instruments']).is_a?(Array)
      self.instruments = value
    end
  end
end

Instance Attribute Details

#instrumentsObject

Per-part overrides, each matched to a detected part by index.



29
30
31
# File 'lib/flat_api/models/omr_details_submission.rb', line 29

def instruments
  @instruments
end

#main_languageObject

Override the main language (BCP 47) used for lyric and text reading on resume. Defaults to the job locale (locales); set this to correct it on the review screen.



26
27
28
# File 'lib/flat_api/models/omr_details_submission.rb', line 26

def main_language
  @main_language
end

#stepObject

Discriminator for OmrStepSubmission; always details for this submission.



20
21
22
# File 'lib/flat_api/models/omr_details_submission.rb', line 20

def step
  @step
end

#titleObject

Override the detected work title.



23
24
25
# File 'lib/flat_api/models/omr_details_submission.rb', line 23

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/flat_api/models/omr_details_submission.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/flat_api/models/omr_details_submission.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
# File 'lib/flat_api/models/omr_details_submission.rb', line 54

def self.attribute_map
  {
    :'step' => :'step',
    :'title' => :'title',
    :'main_language' => :'mainLanguage',
    :'instruments' => :'instruments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/flat_api/models/omr_details_submission.rb', line 250

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



84
85
86
87
# File 'lib/flat_api/models/omr_details_submission.rb', line 84

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
# File 'lib/flat_api/models/omr_details_submission.rb', line 74

def self.openapi_types
  {
    :'step' => :'String',
    :'title' => :'String',
    :'main_language' => :'String',
    :'instruments' => :'Array<OmrInstrumentOverride>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
# File 'lib/flat_api/models/omr_details_submission.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      step == o.step &&
      title == o.title &&
      main_language == o.main_language &&
      instruments == o.instruments
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


237
238
239
# File 'lib/flat_api/models/omr_details_submission.rb', line 237

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



243
244
245
# File 'lib/flat_api/models/omr_details_submission.rb', line 243

def hash
  [step, title, main_language, instruments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/flat_api/models/omr_details_submission.rb', line 128

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @step.nil?
    invalid_properties.push('invalid value for "step", step cannot be nil.')
  end

  if !@title.nil? && @title.to_s.length > 500
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 500.')
  end

  if !@main_language.nil? && @main_language.to_s.length > 35
    invalid_properties.push('invalid value for "main_language", the character length must be smaller than or equal to 35.')
  end

  if !@main_language.nil? && @main_language.to_s.length < 1
    invalid_properties.push('invalid value for "main_language", the character length must be greater than or equal to 1.')
  end

  if !@instruments.nil? && @instruments.length > 200
    invalid_properties.push('invalid value for "instruments", number of items must be less than or equal to 200.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/flat_api/models/omr_details_submission.rb', line 272

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
161
162
163
164
165
166
# File 'lib/flat_api/models/omr_details_submission.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @step.nil?
  step_validator = EnumAttributeValidator.new('String', ["details"])
  return false unless step_validator.valid?(@step)
  return false if !@title.nil? && @title.to_s.length > 500
  return false if !@main_language.nil? && @main_language.to_s.length > 35
  return false if !@main_language.nil? && @main_language.to_s.length < 1
  return false if !@instruments.nil? && @instruments.length > 200
  true
end