Class: FlatApi::OrganizationApi
- Inherits:
-
Object
- Object
- FlatApi::OrganizationApi
- Defined in:
- lib/flat_api/api/organization_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#count_orga_users(opts = {}) ⇒ Integer
Count the organization users using the provided filters.
-
#count_orga_users_with_http_info(opts = {}) ⇒ Array<(Integer, Integer, Hash)>
Count the organization users using the provided filters.
-
#create_lti_configuration(lti_configuration_create, opts = {}) ⇒ LtiConfiguration
Create a new LTI configuration (1.1 or 1.3).
-
#create_lti_configuration_with_http_info(lti_configuration_create, opts = {}) ⇒ Array<(LtiConfiguration, Integer, Hash)>
Create a new LTI configuration (1.1 or 1.3).
-
#create_lti_credentials(body, opts = {}) ⇒ LtiCredentials
Create a new couple of LTI 1.x credentials DEPRECATED.
-
#create_lti_credentials_with_http_info(body, opts = {}) ⇒ Array<(LtiCredentials, Integer, Hash)>
Create a new couple of LTI 1.x credentials DEPRECATED.
-
#create_organization_invitation(body, opts = {}) ⇒ OrganizationInvitation
Create a new invitation to join the organization This method creates and sends invitation for teachers and admins.
-
#create_organization_invitation_with_http_info(body, opts = {}) ⇒ Array<(OrganizationInvitation, Integer, Hash)>
Create a new invitation to join the organization This method creates and sends invitation for teachers and admins.
-
#create_organization_user(body, opts = {}) ⇒ UserDetailsAdmin
Create a new user account.
-
#create_organization_user_access_token(user, organization_user_access_token_creation, opts = {}) ⇒ ApiAccessToken
Create a delegated API access token for an organization user This operation will create an API access token for a chosen organization user.
-
#create_organization_user_access_token_with_http_info(user, organization_user_access_token_creation, opts = {}) ⇒ Array<(ApiAccessToken, Integer, Hash)>
Create a delegated API access token for an organization user This operation will create an API access token for a chosen organization user.
-
#create_organization_user_signin_link(user, user_signin_link_creation, opts = {}) ⇒ UserSigninLink
Create a sign in link for an organization user.
-
#create_organization_user_signin_link_with_http_info(user, user_signin_link_creation, opts = {}) ⇒ Array<(UserSigninLink, Integer, Hash)>
Create a sign in link for an organization user.
-
#create_organization_user_with_http_info(body, opts = {}) ⇒ Array<(UserDetailsAdmin, Integer, Hash)>
Create a new user account.
-
#delete_lti_configuration(configuration, opts = {}) ⇒ nil
Delete an LTI configuration.
-
#delete_lti_configuration_with_http_info(configuration, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an LTI configuration.
-
#initialize(api_client = ApiClient.default) ⇒ OrganizationApi
constructor
A new instance of OrganizationApi.
-
#list_lti_configurations(opts = {}) ⇒ Array<LtiConfiguration>
List LTI configurations (1.1 and 1.3).
-
#list_lti_configurations_with_http_info(opts = {}) ⇒ Array<(Array<LtiConfiguration>, Integer, Hash)>
List LTI configurations (1.1 and 1.3).
-
#list_lti_credentials(opts = {}) ⇒ Array<LtiCredentials>
List LTI 1.x credentials DEPRECATED.
-
#list_lti_credentials_with_http_info(opts = {}) ⇒ Array<(Array<LtiCredentials>, Integer, Hash)>
List LTI 1.x credentials DEPRECATED.
-
#list_organization_invitations(opts = {}) ⇒ Array<OrganizationInvitation>
List the organization invitations.
-
#list_organization_invitations_with_http_info(opts = {}) ⇒ Array<(Array<OrganizationInvitation>, Integer, Hash)>
List the organization invitations.
-
#list_organization_users(opts = {}) ⇒ Array<UserDetailsAdmin>
List the organization users.
-
#list_organization_users_with_http_info(opts = {}) ⇒ Array<(Array<UserDetailsAdmin>, Integer, Hash)>
List the organization users.
-
#remove_organization_invitation(invitation, opts = {}) ⇒ nil
Remove an organization invitation.
-
#remove_organization_invitation_with_http_info(invitation, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove an organization invitation.
-
#remove_organization_user(user, opts = {}) ⇒ nil
Remove an account from Flat This operation removes an account from Flat and its data, including: * The music scores created by this user (documents, history, comments, collaboration information) * Education related data (assignments and classroom information).
-
#remove_organization_user_with_http_info(user, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove an account from Flat This operation removes an account from Flat and its data, including: * The music scores created by this user (documents, history, comments, collaboration information) * Education related data (assignments and classroom information).
-
#revoke_lti_credentials(credentials, opts = {}) ⇒ nil
Revoke LTI 1.x credentials DEPRECATED.
-
#revoke_lti_credentials_with_http_info(credentials, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke LTI 1.x credentials DEPRECATED.
-
#update_lti_configuration(configuration, lti_configuration_update, opts = {}) ⇒ LtiConfiguration
Update an existing LTI configuration (edit 1.3; 1.1 not editable).
-
#update_lti_configuration_with_http_info(configuration, lti_configuration_update, opts = {}) ⇒ Array<(LtiConfiguration, Integer, Hash)>
Update an existing LTI configuration (edit 1.3; 1.1 not editable).
-
#update_organization_user(user, body, opts = {}) ⇒ UserDetailsAdmin
Update account information.
-
#update_organization_user_with_http_info(user, body, opts = {}) ⇒ Array<(UserDetailsAdmin, Integer, Hash)>
Update account information.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ OrganizationApi
Returns a new instance of OrganizationApi.
19 20 21 |
# File 'lib/flat_api/api/organization_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/flat_api/api/organization_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#count_orga_users(opts = {}) ⇒ Integer
Count the organization users using the provided filters
30 31 32 33 |
# File 'lib/flat_api/api/organization_api.rb', line 30 def count_orga_users(opts = {}) data, _status_code, _headers = count_orga_users_with_http_info(opts) data end |
#count_orga_users_with_http_info(opts = {}) ⇒ Array<(Integer, Integer, Hash)>
Count the organization users using the provided filters
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/flat_api/api/organization_api.rb', line 43 def count_orga_users_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.count_orga_users ...' end allowable_values = ["user", "teacher", "admin", "accountAdmin"] if @api_client.config.client_side_validation && opts[:'role'] && !opts[:'role'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"role\", must include one of #{allowable_values}" end allowable_values = ["exclude", "only"] if @api_client.config.client_side_validation && opts[:'test_accounts'] && !allowable_values.include?(opts[:'test_accounts']) fail ArgumentError, "invalid value for \"test_accounts\", must be one of #{allowable_values}" end # resource path local_var_path = '/organizations/users/count' # query parameters query_params = opts[:query_params] || {} query_params[:'role'] = @api_client.build_collection_param(opts[:'role'], :multi) if !opts[:'role'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'group'] = @api_client.build_collection_param(opts[:'group'], :multi) if !opts[:'group'].nil? query_params[:'noActiveLicense'] = opts[:'no_active_license'] if !opts[:'no_active_license'].nil? query_params[:'testAccounts'] = opts[:'test_accounts'] if !opts[:'test_accounts'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Integer' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.count_orga_users", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#count_orga_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_lti_configuration(lti_configuration_create, opts = {}) ⇒ LtiConfiguration
Create a new LTI configuration (1.1 or 1.3)
104 105 106 107 |
# File 'lib/flat_api/api/organization_api.rb', line 104 def create_lti_configuration(lti_configuration_create, opts = {}) data, _status_code, _headers = create_lti_configuration_with_http_info(lti_configuration_create, opts) data end |
#create_lti_configuration_with_http_info(lti_configuration_create, opts = {}) ⇒ Array<(LtiConfiguration, Integer, Hash)>
Create a new LTI configuration (1.1 or 1.3)
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/flat_api/api/organization_api.rb', line 113 def create_lti_configuration_with_http_info(lti_configuration_create, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.create_lti_configuration ...' end # verify the required parameter 'lti_configuration_create' is set if @api_client.config.client_side_validation && lti_configuration_create.nil? fail ArgumentError, "Missing the required parameter 'lti_configuration_create' when calling OrganizationApi.create_lti_configuration" end # resource path local_var_path = '/organizations/lti/configurations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(lti_configuration_create) # return_type return_type = opts[:debug_return_type] || 'LtiConfiguration' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.create_lti_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#create_lti_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_lti_credentials(body, opts = {}) ⇒ LtiCredentials
Create a new couple of LTI 1.x credentials
DEPRECATED. Use the unified endpoints under /organizations/lti/configurations. Note: Teachers may be restricted by the organization privacy setting lti1p1AllowTeachersCredentials. Flat for Education is a Certified LTI Provider. You can use these API methods to automate the creation of LTI credentials. You can read more about our LTI implementation, supported components and LTI Endpoints in our Developer Documentation.
171 172 173 174 |
# File 'lib/flat_api/api/organization_api.rb', line 171 def create_lti_credentials(body, opts = {}) data, _status_code, _headers = create_lti_credentials_with_http_info(body, opts) data end |
#create_lti_credentials_with_http_info(body, opts = {}) ⇒ Array<(LtiCredentials, Integer, Hash)>
Create a new couple of LTI 1.x credentials DEPRECATED. Use the unified endpoints under `/organizations/lti/configurations`. Note: Teachers may be restricted by the organization privacy setting `lti1p1AllowTeachersCredentials`. Flat for Education is a Certified LTI Provider. You can use these API methods to automate the creation of LTI credentials. You can read more about our LTI implementation, supported components and LTI Endpoints in our Developer Documentation.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/flat_api/api/organization_api.rb', line 181 def create_lti_credentials_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.create_lti_credentials ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationApi.create_lti_credentials" end # resource path local_var_path = '/organizations/lti/credentials' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'LtiCredentials' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.create_lti_credentials", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#create_lti_credentials\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_organization_invitation(body, opts = {}) ⇒ OrganizationInvitation
Create a new invitation to join the organization
This method creates and sends invitation for teachers and admins. Invitations can only be used by new Flat users or users who are not part of the organization yet. If the email of the user is already associated to a user of your organization, the API will simply update the role of the existing user and won't send an invitation. In this case, the property usedBy will be directly filled with the uniquer identifier of the corresponding user.
239 240 241 242 |
# File 'lib/flat_api/api/organization_api.rb', line 239 def create_organization_invitation(body, opts = {}) data, _status_code, _headers = create_organization_invitation_with_http_info(body, opts) data end |
#create_organization_invitation_with_http_info(body, opts = {}) ⇒ Array<(OrganizationInvitation, Integer, Hash)>
Create a new invitation to join the organization This method creates and sends invitation for teachers and admins. Invitations can only be used by new Flat users or users who are not part of the organization yet. If the email of the user is already associated to a user of your organization, the API will simply update the role of the existing user and won't send an invitation. In this case, the property `usedBy` will be directly filled with the uniquer identifier of the corresponding user.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/flat_api/api/organization_api.rb', line 249 def create_organization_invitation_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.create_organization_invitation ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationApi.create_organization_invitation" end # resource path local_var_path = '/organizations/invitations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'OrganizationInvitation' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.create_organization_invitation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#create_organization_invitation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_organization_user(body, opts = {}) ⇒ UserDetailsAdmin
Create a new user account
306 307 308 309 |
# File 'lib/flat_api/api/organization_api.rb', line 306 def create_organization_user(body, opts = {}) data, _status_code, _headers = create_organization_user_with_http_info(body, opts) data end |
#create_organization_user_access_token(user, organization_user_access_token_creation, opts = {}) ⇒ ApiAccessToken
Create a delegated API access token for an organization user This operation will create an API access token for a chosen organization user. This token will be valid for a limited time and can be used to access the API as the organization user.
374 375 376 377 |
# File 'lib/flat_api/api/organization_api.rb', line 374 def create_organization_user_access_token(user, organization_user_access_token_creation, opts = {}) data, _status_code, _headers = create_organization_user_access_token_with_http_info(user, organization_user_access_token_creation, opts) data end |
#create_organization_user_access_token_with_http_info(user, organization_user_access_token_creation, opts = {}) ⇒ Array<(ApiAccessToken, Integer, Hash)>
Create a delegated API access token for an organization user This operation will create an API access token for a chosen organization user. This token will be valid for a limited time and can be used to access the API as the organization user.
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/flat_api/api/organization_api.rb', line 385 def create_organization_user_access_token_with_http_info(user, organization_user_access_token_creation, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.create_organization_user_access_token ...' end # verify the required parameter 'user' is set if @api_client.config.client_side_validation && user.nil? fail ArgumentError, "Missing the required parameter 'user' when calling OrganizationApi.create_organization_user_access_token" end # verify the required parameter 'organization_user_access_token_creation' is set if @api_client.config.client_side_validation && organization_user_access_token_creation.nil? fail ArgumentError, "Missing the required parameter 'organization_user_access_token_creation' when calling OrganizationApi.create_organization_user_access_token" end # resource path local_var_path = '/organizations/users/{user}/accessToken'.sub('{user}', CGI.escape(user.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(organization_user_access_token_creation) # return_type return_type = opts[:debug_return_type] || 'ApiAccessToken' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.create_organization_user_access_token", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#create_organization_user_access_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_organization_user_signin_link(user, user_signin_link_creation, opts = {}) ⇒ UserSigninLink
Create a sign in link for an organization user
447 448 449 450 |
# File 'lib/flat_api/api/organization_api.rb', line 447 def create_organization_user_signin_link(user, user_signin_link_creation, opts = {}) data, _status_code, _headers = create_organization_user_signin_link_with_http_info(user, user_signin_link_creation, opts) data end |
#create_organization_user_signin_link_with_http_info(user, user_signin_link_creation, opts = {}) ⇒ Array<(UserSigninLink, Integer, Hash)>
Create a sign in link for an organization user
457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/flat_api/api/organization_api.rb', line 457 def create_organization_user_signin_link_with_http_info(user, user_signin_link_creation, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.create_organization_user_signin_link ...' end # verify the required parameter 'user' is set if @api_client.config.client_side_validation && user.nil? fail ArgumentError, "Missing the required parameter 'user' when calling OrganizationApi.create_organization_user_signin_link" end # verify the required parameter 'user_signin_link_creation' is set if @api_client.config.client_side_validation && user_signin_link_creation.nil? fail ArgumentError, "Missing the required parameter 'user_signin_link_creation' when calling OrganizationApi.create_organization_user_signin_link" end # resource path local_var_path = '/organizations/users/{user}/signinLink'.sub('{user}', CGI.escape(user.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(user_signin_link_creation) # return_type return_type = opts[:debug_return_type] || 'UserSigninLink' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.create_organization_user_signin_link", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#create_organization_user_signin_link\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_organization_user_with_http_info(body, opts = {}) ⇒ Array<(UserDetailsAdmin, Integer, Hash)>
Create a new user account
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/flat_api/api/organization_api.rb', line 315 def create_organization_user_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.create_organization_user ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationApi.create_organization_user" end # resource path local_var_path = '/organizations/users' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'UserDetailsAdmin' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.create_organization_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#create_organization_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_lti_configuration(configuration, opts = {}) ⇒ nil
Delete an LTI configuration
518 519 520 521 |
# File 'lib/flat_api/api/organization_api.rb', line 518 def delete_lti_configuration(configuration, opts = {}) delete_lti_configuration_with_http_info(configuration, opts) nil end |
#delete_lti_configuration_with_http_info(configuration, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an LTI configuration
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/flat_api/api/organization_api.rb', line 527 def delete_lti_configuration_with_http_info(configuration, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.delete_lti_configuration ...' end # verify the required parameter 'configuration' is set if @api_client.config.client_side_validation && configuration.nil? fail ArgumentError, "Missing the required parameter 'configuration' when calling OrganizationApi.delete_lti_configuration" end # resource path local_var_path = '/organizations/lti/configurations/{configuration}'.sub('{configuration}', CGI.escape(configuration.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.delete_lti_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#delete_lti_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_lti_configurations(opts = {}) ⇒ Array<LtiConfiguration>
List LTI configurations (1.1 and 1.3)
578 579 580 581 |
# File 'lib/flat_api/api/organization_api.rb', line 578 def list_lti_configurations(opts = {}) data, _status_code, _headers = list_lti_configurations_with_http_info(opts) data end |
#list_lti_configurations_with_http_info(opts = {}) ⇒ Array<(Array<LtiConfiguration>, Integer, Hash)>
List LTI configurations (1.1 and 1.3)
586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 |
# File 'lib/flat_api/api/organization_api.rb', line 586 def list_lti_configurations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.list_lti_configurations ...' end # resource path local_var_path = '/organizations/lti/configurations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<LtiConfiguration>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.list_lti_configurations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#list_lti_configurations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_lti_credentials(opts = {}) ⇒ Array<LtiCredentials>
List LTI 1.x credentials
DEPRECATED. Use the unified endpoints under /organizations/lti/configurations. Note: Teachers may be restricted by the organization privacy setting lti1p1AllowTeachersCredentials.
634 635 636 637 |
# File 'lib/flat_api/api/organization_api.rb', line 634 def list_lti_credentials(opts = {}) data, _status_code, _headers = list_lti_credentials_with_http_info(opts) data end |
#list_lti_credentials_with_http_info(opts = {}) ⇒ Array<(Array<LtiCredentials>, Integer, Hash)>
List LTI 1.x credentials DEPRECATED. Use the unified endpoints under `/organizations/lti/configurations`. Note: Teachers may be restricted by the organization privacy setting `lti1p1AllowTeachersCredentials`.
643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/flat_api/api/organization_api.rb', line 643 def list_lti_credentials_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.list_lti_credentials ...' end # resource path local_var_path = '/organizations/lti/credentials' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<LtiCredentials>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.list_lti_credentials", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#list_lti_credentials\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_organization_invitations(opts = {}) ⇒ Array<OrganizationInvitation>
List the organization invitations
694 695 696 697 |
# File 'lib/flat_api/api/organization_api.rb', line 694 def list_organization_invitations(opts = {}) data, _status_code, _headers = list_organization_invitations_with_http_info(opts) data end |
#list_organization_invitations_with_http_info(opts = {}) ⇒ Array<(Array<OrganizationInvitation>, Integer, Hash)>
List the organization invitations
706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 |
# File 'lib/flat_api/api/organization_api.rb', line 706 def list_organization_invitations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.list_organization_invitations ...' end allowable_values = ["user", "teacher", "admin"] if @api_client.config.client_side_validation && opts[:'role'] && !allowable_values.include?(opts[:'role']) fail ArgumentError, "invalid value for \"role\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling OrganizationApi.list_organization_invitations, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling OrganizationApi.list_organization_invitations, must be greater than or equal to 1.' end # resource path local_var_path = '/organizations/invitations' # query parameters query_params = opts[:query_params] || {} query_params[:'role'] = opts[:'role'] if !opts[:'role'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil? query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<OrganizationInvitation>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.list_organization_invitations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#list_organization_invitations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_organization_users(opts = {}) ⇒ Array<UserDetailsAdmin>
List the organization users
781 782 783 784 |
# File 'lib/flat_api/api/organization_api.rb', line 781 def list_organization_users(opts = {}) data, _status_code, _headers = list_organization_users_with_http_info(opts) data end |
#list_organization_users_with_http_info(opts = {}) ⇒ Array<(Array<UserDetailsAdmin>, Integer, Hash)>
List the organization users
801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 |
# File 'lib/flat_api/api/organization_api.rb', line 801 def list_organization_users_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.list_organization_users ...' end allowable_values = ["creationDate", "firstname", "lastname", "username", "lastActivityDate", "licenseExpirationDate"] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end allowable_values = ["asc", "desc"] if @api_client.config.client_side_validation && opts[:'direction'] && !allowable_values.include?(opts[:'direction']) fail ArgumentError, "invalid value for \"direction\", must be one of #{allowable_values}" end allowable_values = ["user", "teacher", "admin", "accountAdmin"] if @api_client.config.client_side_validation && opts[:'role'] && !opts[:'role'].all? { |item| allowable_values.include?(item) } fail ArgumentError, "invalid value for \"role\", must include one of #{allowable_values}" end allowable_values = ["exclude", "only"] if @api_client.config.client_side_validation && opts[:'test_accounts'] && !allowable_values.include?(opts[:'test_accounts']) fail ArgumentError, "invalid value for \"test_accounts\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling OrganizationApi.list_organization_users, must be smaller than or equal to 1000.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling OrganizationApi.list_organization_users, must be greater than or equal to 1.' end # resource path local_var_path = '/organizations/users' # query parameters query_params = opts[:query_params] || {} query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'direction'] = opts[:'direction'] if !opts[:'direction'].nil? query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil? query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil? query_params[:'role'] = @api_client.build_collection_param(opts[:'role'], :multi) if !opts[:'role'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'group'] = @api_client.build_collection_param(opts[:'group'], :multi) if !opts[:'group'].nil? query_params[:'noActiveLicense'] = opts[:'no_active_license'] if !opts[:'no_active_license'].nil? query_params[:'testAccounts'] = opts[:'test_accounts'] if !opts[:'test_accounts'].nil? query_params[:'licenseExpirationDate'] = @api_client.build_collection_param(opts[:'license_expiration_date'], :multi) if !opts[:'license_expiration_date'].nil? query_params[:'onlyIds'] = opts[:'only_ids'] if !opts[:'only_ids'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<UserDetailsAdmin>' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.list_organization_users", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#list_organization_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_organization_invitation(invitation, opts = {}) ⇒ nil
Remove an organization invitation
885 886 887 888 |
# File 'lib/flat_api/api/organization_api.rb', line 885 def remove_organization_invitation(invitation, opts = {}) remove_organization_invitation_with_http_info(invitation, opts) nil end |
#remove_organization_invitation_with_http_info(invitation, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove an organization invitation
894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 |
# File 'lib/flat_api/api/organization_api.rb', line 894 def remove_organization_invitation_with_http_info(invitation, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.remove_organization_invitation ...' end # verify the required parameter 'invitation' is set if @api_client.config.client_side_validation && invitation.nil? fail ArgumentError, "Missing the required parameter 'invitation' when calling OrganizationApi.remove_organization_invitation" end # resource path local_var_path = '/organizations/invitations/{invitation}'.sub('{invitation}', CGI.escape(invitation.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.remove_organization_invitation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#remove_organization_invitation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#remove_organization_user(user, opts = {}) ⇒ nil
Remove an account from Flat This operation removes an account from Flat and its data, including: * The music scores created by this user (documents, history, comments, collaboration information) * Education related data (assignments and classroom information)
948 949 950 951 |
# File 'lib/flat_api/api/organization_api.rb', line 948 def remove_organization_user(user, opts = {}) remove_organization_user_with_http_info(user, opts) nil end |
#remove_organization_user_with_http_info(user, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove an account from Flat This operation removes an account from Flat and its data, including: * The music scores created by this user (documents, history, comments, collaboration information) * Education related data (assignments and classroom information)
959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 |
# File 'lib/flat_api/api/organization_api.rb', line 959 def remove_organization_user_with_http_info(user, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.remove_organization_user ...' end # verify the required parameter 'user' is set if @api_client.config.client_side_validation && user.nil? fail ArgumentError, "Missing the required parameter 'user' when calling OrganizationApi.remove_organization_user" end # resource path local_var_path = '/organizations/users/{user}'.sub('{user}', CGI.escape(user.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'convertToIndividual'] = opts[:'convert_to_individual'] if !opts[:'convert_to_individual'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.remove_organization_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#remove_organization_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#revoke_lti_credentials(credentials, opts = {}) ⇒ nil
Revoke LTI 1.x credentials
DEPRECATED. Use the unified endpoints under /organizations/lti/configurations. Note: Teachers may be restricted by the organization privacy setting lti1p1AllowTeachersCredentials.
1013 1014 1015 1016 |
# File 'lib/flat_api/api/organization_api.rb', line 1013 def revoke_lti_credentials(credentials, opts = {}) revoke_lti_credentials_with_http_info(credentials, opts) nil end |
#revoke_lti_credentials_with_http_info(credentials, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke LTI 1.x credentials DEPRECATED. Use the unified endpoints under `/organizations/lti/configurations`. Note: Teachers may be restricted by the organization privacy setting `lti1p1AllowTeachersCredentials`.
1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 |
# File 'lib/flat_api/api/organization_api.rb', line 1023 def revoke_lti_credentials_with_http_info(credentials, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.revoke_lti_credentials ...' end # verify the required parameter 'credentials' is set if @api_client.config.client_side_validation && credentials.nil? fail ArgumentError, "Missing the required parameter 'credentials' when calling OrganizationApi.revoke_lti_credentials" end # resource path local_var_path = '/organizations/lti/credentials/{credentials}'.sub('{credentials}', CGI.escape(credentials.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.revoke_lti_credentials", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#revoke_lti_credentials\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_lti_configuration(configuration, lti_configuration_update, opts = {}) ⇒ LtiConfiguration
Update an existing LTI configuration (edit 1.3; 1.1 not editable)
1076 1077 1078 1079 |
# File 'lib/flat_api/api/organization_api.rb', line 1076 def update_lti_configuration(configuration, lti_configuration_update, opts = {}) data, _status_code, _headers = update_lti_configuration_with_http_info(configuration, lti_configuration_update, opts) data end |
#update_lti_configuration_with_http_info(configuration, lti_configuration_update, opts = {}) ⇒ Array<(LtiConfiguration, Integer, Hash)>
Update an existing LTI configuration (edit 1.3; 1.1 not editable)
1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/flat_api/api/organization_api.rb', line 1086 def update_lti_configuration_with_http_info(configuration, lti_configuration_update, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.update_lti_configuration ...' end # verify the required parameter 'configuration' is set if @api_client.config.client_side_validation && configuration.nil? fail ArgumentError, "Missing the required parameter 'configuration' when calling OrganizationApi.update_lti_configuration" end # verify the required parameter 'lti_configuration_update' is set if @api_client.config.client_side_validation && lti_configuration_update.nil? fail ArgumentError, "Missing the required parameter 'lti_configuration_update' when calling OrganizationApi.update_lti_configuration" end # resource path local_var_path = '/organizations/lti/configurations/{configuration}'.sub('{configuration}', CGI.escape(configuration.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(lti_configuration_update) # return_type return_type = opts[:debug_return_type] || 'LtiConfiguration' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.update_lti_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#update_lti_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_organization_user(user, body, opts = {}) ⇒ UserDetailsAdmin
Update account information
1148 1149 1150 1151 |
# File 'lib/flat_api/api/organization_api.rb', line 1148 def update_organization_user(user, body, opts = {}) data, _status_code, _headers = update_organization_user_with_http_info(user, body, opts) data end |
#update_organization_user_with_http_info(user, body, opts = {}) ⇒ Array<(UserDetailsAdmin, Integer, Hash)>
Update account information
1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 |
# File 'lib/flat_api/api/organization_api.rb', line 1158 def update_organization_user_with_http_info(user, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationApi.update_organization_user ...' end # verify the required parameter 'user' is set if @api_client.config.client_side_validation && user.nil? fail ArgumentError, "Missing the required parameter 'user' when calling OrganizationApi.update_organization_user" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationApi.update_organization_user" end # resource path local_var_path = '/organizations/users/{user}'.sub('{user}', CGI.escape(user.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'UserDetailsAdmin' # auth_names auth_names = opts[:debug_auth_names] || ['OAuth2'] = opts.merge( :operation => :"OrganizationApi.update_organization_user", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationApi#update_organization_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |