Class: FlatApi::ScoreComment

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/score_comment.rb

Overview

Comment added on a sheet music

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ScoreComment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/flat_api/models/score_comment.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreComment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreComment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  else
    self.user = nil
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  else
    self.score = nil
  end

  if attributes.key?(:'revision')
    self.revision = attributes[:'revision']
  end

  if attributes.key?(:'reply_to')
    self.reply_to = attributes[:'reply_to']
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'modification_date')
    self.modification_date = attributes[:'modification_date']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  else
    self.comment = nil
  end

  if attributes.key?(:'raw_comment')
    self.raw_comment = attributes[:'raw_comment']
  else
    self.raw_comment = nil
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  end

  if attributes.key?(:'mentions')
    if (value = attributes[:'mentions']).is_a?(Array)
      self.mentions = value
    end
  end

  if attributes.key?(:'resolved')
    self.resolved = attributes[:'resolved']
  end

  if attributes.key?(:'resolved_by')
    self.resolved_by = attributes[:'resolved_by']
  end

  if attributes.key?(:'moderation')
    self.moderation = attributes[:'moderation']
  end

  if attributes.key?(:'spam')
    self.spam = attributes[:'spam']
  end
end

Instance Attribute Details

#commentObject

The comment text that can includes mentions using the following format: @[id:username].



44
45
46
# File 'lib/flat_api/models/score_comment.rb', line 44

def comment
  @comment
end

#contextObject

Returns the value of attribute context.



49
50
51
# File 'lib/flat_api/models/score_comment.rb', line 49

def context
  @context
end

#dateObject

The date when the comment was posted



38
39
40
# File 'lib/flat_api/models/score_comment.rb', line 38

def date
  @date
end

#idObject

The comment unique identifier



20
21
22
# File 'lib/flat_api/models/score_comment.rb', line 20

def id
  @id
end

#mentionsObject

The list of user identifier mentioned on the score



52
53
54
# File 'lib/flat_api/models/score_comment.rb', line 52

def mentions
  @mentions
end

#moderationObject

Returns the value of attribute moderation.



60
61
62
# File 'lib/flat_api/models/score_comment.rb', line 60

def moderation
  @moderation
end

#modification_dateObject

The date of the last comment modification



41
42
43
# File 'lib/flat_api/models/score_comment.rb', line 41

def modification_date
  @modification_date
end

#raw_commentObject

A raw version of the comment, that can be displayed without parsing the mentions.



47
48
49
# File 'lib/flat_api/models/score_comment.rb', line 47

def raw_comment
  @raw_comment
end

#reply_toObject

When the comment is a reply to another comment, the unique identifier of the parent comment



35
36
37
# File 'lib/flat_api/models/score_comment.rb', line 35

def reply_to
  @reply_to
end

#resolvedObject

For inline comments, the comment can be marked as resolved and will be hidden in the future responses



55
56
57
# File 'lib/flat_api/models/score_comment.rb', line 55

def resolved
  @resolved
end

#resolved_byObject

If the user is marked as resolved, this will contain the unique identifier of the User who marked this comment as resolved



58
59
60
# File 'lib/flat_api/models/score_comment.rb', line 58

def resolved_by
  @resolved_by
end

#revisionObject

The unique identifier of revision the comment was posted



32
33
34
# File 'lib/flat_api/models/score_comment.rb', line 32

def revision
  @revision
end

#scoreObject

The unique identifier of the score where the comment was posted



29
30
31
# File 'lib/flat_api/models/score_comment.rb', line 29

def score
  @score
end

#spamObject

`true if the message has been detected as spam and hidden from other users



63
64
65
# File 'lib/flat_api/models/score_comment.rb', line 63

def spam
  @spam
end

#typeObject

The type of the comment



23
24
25
# File 'lib/flat_api/models/score_comment.rb', line 23

def type
  @type
end

#userObject

The author unique identifier



26
27
28
# File 'lib/flat_api/models/score_comment.rb', line 26

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



110
111
112
# File 'lib/flat_api/models/score_comment.rb', line 110

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



115
116
117
# File 'lib/flat_api/models/score_comment.rb', line 115

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/flat_api/models/score_comment.rb', line 88

def self.attribute_map
  {
    :'id' => :'id',
    :'type' => :'type',
    :'user' => :'user',
    :'score' => :'score',
    :'revision' => :'revision',
    :'reply_to' => :'replyTo',
    :'date' => :'date',
    :'modification_date' => :'modificationDate',
    :'comment' => :'comment',
    :'raw_comment' => :'rawComment',
    :'context' => :'context',
    :'mentions' => :'mentions',
    :'resolved' => :'resolved',
    :'resolved_by' => :'resolvedBy',
    :'moderation' => :'moderation',
    :'spam' => :'spam'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/flat_api/models/score_comment.rb', line 404

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



142
143
144
145
# File 'lib/flat_api/models/score_comment.rb', line 142

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/flat_api/models/score_comment.rb', line 120

def self.openapi_types
  {
    :'id' => :'String',
    :'type' => :'String',
    :'user' => :'String',
    :'score' => :'String',
    :'revision' => :'String',
    :'reply_to' => :'String',
    :'date' => :'Time',
    :'modification_date' => :'Time',
    :'comment' => :'String',
    :'raw_comment' => :'String',
    :'context' => :'ScoreCommentContext',
    :'mentions' => :'Array<String>',
    :'resolved' => :'Boolean',
    :'resolved_by' => :'String',
    :'moderation' => :'ScoreCommentModeration',
    :'spam' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/flat_api/models/score_comment.rb', line 368

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      type == o.type &&
      user == o.user &&
      score == o.score &&
      revision == o.revision &&
      reply_to == o.reply_to &&
      date == o.date &&
      modification_date == o.modification_date &&
      comment == o.comment &&
      raw_comment == o.raw_comment &&
      context == o.context &&
      mentions == o.mentions &&
      resolved == o.resolved &&
      resolved_by == o.resolved_by &&
      moderation == o.moderation &&
      spam == o.spam
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


391
392
393
# File 'lib/flat_api/models/score_comment.rb', line 391

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



397
398
399
# File 'lib/flat_api/models/score_comment.rb', line 397

def hash
  [id, type, user, score, revision, reply_to, date, modification_date, comment, raw_comment, context, mentions, resolved, resolved_by, moderation, spam].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/flat_api/models/score_comment.rb', line 246

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @user.nil?
    invalid_properties.push('invalid value for "user", user cannot be nil.')
  end

  if @score.nil?
    invalid_properties.push('invalid value for "score", score cannot be nil.')
  end

  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @comment.nil?
    invalid_properties.push('invalid value for "comment", comment cannot be nil.')
  end

  if @raw_comment.nil?
    invalid_properties.push('invalid value for "raw_comment", raw_comment cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/flat_api/models/score_comment.rb', line 426

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/flat_api/models/score_comment.rb', line 282

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["document", "inline"])
  return false unless type_validator.valid?(@type)
  return false if @user.nil?
  return false if @score.nil?
  return false if @date.nil?
  return false if @comment.nil?
  return false if @raw_comment.nil?
  true
end