Class: FlatApi::ScoreCreationBuilderData

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/score_creation_builder_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ScoreCreationBuilderData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreCreationBuilderData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreCreationBuilderData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'privacy')
    self.privacy = attributes[:'privacy']
  else
    self.privacy = 'private'
  end

  if attributes.key?(:'collection')
    self.collection = attributes[:'collection']
  end

  if attributes.key?(:'google_drive_folder')
    self.google_drive_folder = attributes[:'google_drive_folder']
  end

  if attributes.key?(:'builder_data')
    self.builder_data = attributes[:'builder_data']
  else
    self.builder_data = nil
  end
end

Instance Attribute Details

#builder_dataObject

Returns the value of attribute builder_data.



29
30
31
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 29

def builder_data
  @builder_data
end

#collectionObject

Unique identifier of a collection where the score will be created. If no collection identifier is provided, the score will not be added to any collection and will only be visible in the allScores virtual collection.



24
25
26
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 24

def collection
  @collection
end

#google_drive_folderObject

If the user uses Google Drive and this properties is specified, the file will be created in this directory. The currently user creating the file must be granted to write in this directory.



27
28
29
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 27

def google_drive_folder
  @google_drive_folder
end

#privacyObject

Returns the value of attribute privacy.



21
22
23
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 21

def privacy
  @privacy
end

#titleObject

The title of the new score. If the title is too long, the API may trim this one. If this title is not specified, the API will try to (in this order): - Use the title contained in the file (e.g. movement-title or credit-words for MusicXML files). - Use the name of the file for files from a specified source (e.g. Google Drive) or the one in the filename property - Set a default title (e.g. "New Music Score")



19
20
21
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 19

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 54

def self.attribute_map
  {
    :'title' => :'title',
    :'privacy' => :'privacy',
    :'collection' => :'collection',
    :'google_drive_folder' => :'googleDriveFolder',
    :'builder_data' => :'builderData'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



92
93
94
95
96
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 92

def self.openapi_all_of
  [
  :'ScoreCreationCommon'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 75

def self.openapi_types
  {
    :'title' => :'String',
    :'privacy' => :'ScorePrivacy',
    :'collection' => :'String',
    :'google_drive_folder' => :'String',
    :'builder_data' => :'ScoreCreationBuilderDataAllOfBuilderData'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      privacy == o.privacy &&
      collection == o.collection &&
      google_drive_folder == o.google_drive_folder &&
      builder_data == o.builder_data
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 189

def hash
  [title, privacy, collection, google_drive_folder, builder_data].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @builder_data.nil?
    invalid_properties.push('invalid value for "builder_data", builder_data cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
# File 'lib/flat_api/models/score_creation_builder_data.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @builder_data.nil?
  true
end