Class: FlatApi::ScoreCreationBuilderDataAllOfBuilderDataLayoutData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb

Overview

Control the appearance of the score. If missing, default values are used.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ScoreCreationBuilderDataAllOfBuilderDataLayoutData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 111

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreCreationBuilderDataAllOfBuilderDataLayoutData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreCreationBuilderDataAllOfBuilderDataLayoutData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'notes_spacing_coeff')
    self.notes_spacing_coeff = attributes[:'notes_spacing_coeff']
  end

  if attributes.key?(:'length_unit')
    self.length_unit = attributes[:'length_unit']
  else
    self.length_unit = 'cm'
  end

  if attributes.key?(:'page_height')
    self.page_height = attributes[:'page_height']
  end

  if attributes.key?(:'page_width')
    self.page_width = attributes[:'page_width']
  end

  if attributes.key?(:'page_margin_top')
    self.page_margin_top = attributes[:'page_margin_top']
  end

  if attributes.key?(:'page_margin_bottom')
    self.page_margin_bottom = attributes[:'page_margin_bottom']
  end

  if attributes.key?(:'page_margin_left')
    self.page_margin_left = attributes[:'page_margin_left']
  end

  if attributes.key?(:'page_margin_right')
    self.page_margin_right = attributes[:'page_margin_right']
  end
end

Instance Attribute Details

#length_unitObject

The unit to use for layout customizations



23
24
25
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 23

def length_unit
  @length_unit
end

#notes_spacing_coeffObject

A float value >= 1 that controls the spacing between notes.



20
21
22
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 20

def notes_spacing_coeff
  @notes_spacing_coeff
end

#page_heightObject

The height of the page in chosen unit (lengthUnit).



26
27
28
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 26

def page_height
  @page_height
end

#page_margin_bottomObject

The bottom margin of the page in chosen unit (lengthUnit).



35
36
37
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 35

def page_margin_bottom
  @page_margin_bottom
end

#page_margin_leftObject

The left margin of the page in chosen unit (lengthUnit).



38
39
40
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 38

def page_margin_left
  @page_margin_left
end

#page_margin_rightObject

The right margin of the page in chosen unit (lengthUnit).



41
42
43
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 41

def page_margin_right
  @page_margin_right
end

#page_margin_topObject

The top margin of the page in chosen unit (lengthUnit).



32
33
34
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 32

def page_margin_top
  @page_margin_top
end

#page_widthObject

The width of the page in chosen unit (lengthUnit).



29
30
31
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 29

def page_width
  @page_width
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 66

def self.attribute_map
  {
    :'notes_spacing_coeff' => :'notesSpacingCoeff',
    :'length_unit' => :'lengthUnit',
    :'page_height' => :'pageHeight',
    :'page_width' => :'pageWidth',
    :'page_margin_top' => :'pageMarginTop',
    :'page_margin_bottom' => :'pageMarginBottom',
    :'page_margin_left' => :'pageMarginLeft',
    :'page_margin_right' => :'pageMarginRight'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 104

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 90

def self.openapi_types
  {
    :'notes_spacing_coeff' => :'Float',
    :'length_unit' => :'String',
    :'page_height' => :'Float',
    :'page_width' => :'Float',
    :'page_margin_top' => :'Float',
    :'page_margin_bottom' => :'Float',
    :'page_margin_left' => :'Float',
    :'page_margin_right' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      notes_spacing_coeff == o.notes_spacing_coeff &&
      length_unit == o.length_unit &&
      page_height == o.page_height &&
      page_width == o.page_width &&
      page_margin_top == o.page_margin_top &&
      page_margin_bottom == o.page_margin_bottom &&
      page_margin_left == o.page_margin_left &&
      page_margin_right == o.page_margin_right
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 210

def hash
  [notes_spacing_coeff, length_unit, page_height, page_width, page_margin_top, page_margin_bottom, page_margin_left, page_margin_right].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
# File 'lib/flat_api/models/score_creation_builder_data_all_of_builder_data_layout_data.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  length_unit_validator = EnumAttributeValidator.new('String', ["cm", "inch"])
  return false unless length_unit_validator.valid?(@length_unit)
  true
end