Class: FlatApi::ScoreRevision

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/score_revision.rb

Overview

A score revision metadata

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ScoreRevision

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/flat_api/models/score_revision.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreRevision` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreRevision`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  else
    self.score = nil
  end

  if attributes.key?(:'collaborators')
    if (value = attributes[:'collaborators']).is_a?(Array)
      self.collaborators = value
    end
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'event')
    self.event = attributes[:'event']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'autosave')
    self.autosave = attributes[:'autosave']
  end

  if attributes.key?(:'statistics')
    self.statistics = attributes[:'statistics']
  end
end

Instance Attribute Details

#autosaveObject

True if this revision was automatically generated by Flat and not on purpose by the user.



40
41
42
# File 'lib/flat_api/models/score_revision.rb', line 40

def autosave
  @autosave
end

#collaboratorsObject

Returns the value of attribute collaborators.



28
29
30
# File 'lib/flat_api/models/score_revision.rb', line 28

def collaborators
  @collaborators
end

#dateObject

The date when this revision was created



31
32
33
# File 'lib/flat_api/models/score_revision.rb', line 31

def date
  @date
end

#descriptionObject

A description associated to the revision



37
38
39
# File 'lib/flat_api/models/score_revision.rb', line 37

def description
  @description
end

#eventObject

The last event (action id) of the revision



34
35
36
# File 'lib/flat_api/models/score_revision.rb', line 34

def event
  @event
end

#idObject

The unique identifier of the revision.



20
21
22
# File 'lib/flat_api/models/score_revision.rb', line 20

def id
  @id
end

#scoreObject

The score identifier



26
27
28
# File 'lib/flat_api/models/score_revision.rb', line 26

def score
  @score
end

#statisticsObject

Returns the value of attribute statistics.



42
43
44
# File 'lib/flat_api/models/score_revision.rb', line 42

def statistics
  @statistics
end

#userObject

The user identifier who created the revision



23
24
25
# File 'lib/flat_api/models/score_revision.rb', line 23

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/flat_api/models/score_revision.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/flat_api/models/score_revision.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/flat_api/models/score_revision.rb', line 45

def self.attribute_map
  {
    :'id' => :'id',
    :'user' => :'user',
    :'score' => :'score',
    :'collaborators' => :'collaborators',
    :'date' => :'date',
    :'event' => :'event',
    :'description' => :'description',
    :'autosave' => :'autosave',
    :'statistics' => :'statistics'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/flat_api/models/score_revision.rb', line 242

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/flat_api/models/score_revision.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/flat_api/models/score_revision.rb', line 70

def self.openapi_types
  {
    :'id' => :'String',
    :'user' => :'String',
    :'score' => :'String',
    :'collaborators' => :'Array<String>',
    :'date' => :'Time',
    :'event' => :'String',
    :'description' => :'String',
    :'autosave' => :'Boolean',
    :'statistics' => :'ScoreRevisionStatistics'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/flat_api/models/score_revision.rb', line 213

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      user == o.user &&
      score == o.score &&
      collaborators == o.collaborators &&
      date == o.date &&
      event == o.event &&
      description == o.description &&
      autosave == o.autosave &&
      statistics == o.statistics
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/flat_api/models/score_revision.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/flat_api/models/score_revision.rb', line 235

def hash
  [id, user, score, collaborators, date, event, description, autosave, statistics].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/flat_api/models/score_revision.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @score.nil?
    invalid_properties.push('invalid value for "score", score cannot be nil.')
  end

  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/flat_api/models/score_revision.rb', line 264

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
179
# File 'lib/flat_api/models/score_revision.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @score.nil?
  return false if @date.nil?
  true
end