Class: FlatApi::ScoreTrackCreation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ScoreTrackCreation
- Defined in:
- lib/flat_api/models/score_track_creation.rb
Overview
Creation of a new track. This one must contain the URL of the track or the corresponding file
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#default ⇒ Object
True if the track should be used as default audio source.
-
#purpose ⇒ Object
Returns the value of attribute purpose.
-
#state ⇒ Object
Returns the value of attribute state.
-
#synchronization_points ⇒ Object
Returns the value of attribute synchronization_points.
-
#title ⇒ Object
Title of the track.
-
#url ⇒ Object
The URL of the track.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScoreTrackCreation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScoreTrackCreation
Initializes the object
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/flat_api/models/score_track_creation.rb', line 98 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreTrackCreation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreTrackCreation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'default') self.default = attributes[:'default'] end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = 'draft' end if attributes.key?(:'purpose') self.purpose = attributes[:'purpose'] else self.purpose = 'common' end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'synchronization_points') if (value = attributes[:'synchronization_points']).is_a?(Array) self.synchronization_points = value end end end |
Instance Attribute Details
#default ⇒ Object
True if the track should be used as default audio source
23 24 25 |
# File 'lib/flat_api/models/score_track_creation.rb', line 23 def default @default end |
#purpose ⇒ Object
Returns the value of attribute purpose.
27 28 29 |
# File 'lib/flat_api/models/score_track_creation.rb', line 27 def purpose @purpose end |
#state ⇒ Object
Returns the value of attribute state.
25 26 27 |
# File 'lib/flat_api/models/score_track_creation.rb', line 25 def state @state end |
#synchronization_points ⇒ Object
Returns the value of attribute synchronization_points.
32 33 34 |
# File 'lib/flat_api/models/score_track_creation.rb', line 32 def synchronization_points @synchronization_points end |
#title ⇒ Object
Title of the track
20 21 22 |
# File 'lib/flat_api/models/score_track_creation.rb', line 20 def title @title end |
#url ⇒ Object
The URL of the track
30 31 32 |
# File 'lib/flat_api/models/score_track_creation.rb', line 30 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/flat_api/models/score_track_creation.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/flat_api/models/score_track_creation.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/flat_api/models/score_track_creation.rb', line 57 def self.attribute_map { :'title' => :'title', :'default' => :'default', :'state' => :'state', :'purpose' => :'purpose', :'url' => :'url', :'synchronization_points' => :'synchronizationPoints' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/flat_api/models/score_track_creation.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 |
# File 'lib/flat_api/models/score_track_creation.rb', line 91 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 |
# File 'lib/flat_api/models/score_track_creation.rb', line 79 def self.openapi_types { :'title' => :'String', :'default' => :'Boolean', :'state' => :'ScoreTrackState', :'purpose' => :'ScoreTrackPurpose', :'url' => :'String', :'synchronization_points' => :'Array<ScoreTrackPoint>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 169 |
# File 'lib/flat_api/models/score_track_creation.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && default == o.default && state == o.state && purpose == o.purpose && url == o.url && synchronization_points == o.synchronization_points end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/flat_api/models/score_track_creation.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/flat_api/models/score_track_creation.rb', line 179 def hash [title, default, state, purpose, url, synchronization_points].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/flat_api/models/score_track_creation.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/flat_api/models/score_track_creation.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 |
# File 'lib/flat_api/models/score_track_creation.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |