Class: FlatApi::ScoreTrackUpdate

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/score_track_update.rb

Overview

Update an existing track.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ScoreTrackUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/flat_api/models/score_track_update.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreTrackUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreTrackUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'default')
    self.default = attributes[:'default']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = 'draft'
  end

  if attributes.key?(:'purpose')
    self.purpose = attributes[:'purpose']
  else
    self.purpose = 'common'
  end

  if attributes.key?(:'synchronization_points')
    if (value = attributes[:'synchronization_points']).is_a?(Array)
      self.synchronization_points = value
    end
  end
end

Instance Attribute Details

#defaultObject

True if the track should be used as default audio source



23
24
25
# File 'lib/flat_api/models/score_track_update.rb', line 23

def default
  @default
end

#purposeObject

Returns the value of attribute purpose.



27
28
29
# File 'lib/flat_api/models/score_track_update.rb', line 27

def purpose
  @purpose
end

#stateObject

Returns the value of attribute state.



25
26
27
# File 'lib/flat_api/models/score_track_update.rb', line 25

def state
  @state
end

#synchronization_pointsObject

Returns the value of attribute synchronization_points.



29
30
31
# File 'lib/flat_api/models/score_track_update.rb', line 29

def synchronization_points
  @synchronization_points
end

#titleObject

Title of the track



20
21
22
# File 'lib/flat_api/models/score_track_update.rb', line 20

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/flat_api/models/score_track_update.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/flat_api/models/score_track_update.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
# File 'lib/flat_api/models/score_track_update.rb', line 54

def self.attribute_map
  {
    :'title' => :'title',
    :'default' => :'default',
    :'state' => :'state',
    :'purpose' => :'purpose',
    :'synchronization_points' => :'synchronizationPoints'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/flat_api/models/score_track_update.rb', line 176

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/flat_api/models/score_track_update.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
# File 'lib/flat_api/models/score_track_update.rb', line 75

def self.openapi_types
  {
    :'title' => :'String',
    :'default' => :'Boolean',
    :'state' => :'ScoreTrackState',
    :'purpose' => :'ScoreTrackPurpose',
    :'synchronization_points' => :'Array<ScoreTrackPoint>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



151
152
153
154
155
156
157
158
159
# File 'lib/flat_api/models/score_track_update.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      default == o.default &&
      state == o.state &&
      purpose == o.purpose &&
      synchronization_points == o.synchronization_points
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


163
164
165
# File 'lib/flat_api/models/score_track_update.rb', line 163

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



169
170
171
# File 'lib/flat_api/models/score_track_update.rb', line 169

def hash
  [title, default, state, purpose, synchronization_points].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
# File 'lib/flat_api/models/score_track_update.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/flat_api/models/score_track_update.rb', line 198

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
# File 'lib/flat_api/models/score_track_update.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end