Class: FlatApi::UserAdminUpdate

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/user_admin_update.rb

Overview

User update as an organization admin

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserAdminUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/flat_api/models/user_admin_update.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::UserAdminUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::UserAdminUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'organization_role')
    self.organization_role = attributes[:'organization_role']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end

  if attributes.key?(:'firstname')
    self.firstname = attributes[:'firstname']
  end

  if attributes.key?(:'lastname')
    self.lastname = attributes[:'lastname']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end
end

Instance Attribute Details

#emailObject

Email of the account



34
35
36
# File 'lib/flat_api/models/user_admin_update.rb', line 34

def email
  @email
end

#firstnameObject

First name of the user



28
29
30
# File 'lib/flat_api/models/user_admin_update.rb', line 28

def firstname
  @firstname
end

#lastnameObject

Last name of the user



31
32
33
# File 'lib/flat_api/models/user_admin_update.rb', line 31

def lastname
  @lastname
end

#organization_roleObject

Returns the value of attribute organization_role.



22
23
24
# File 'lib/flat_api/models/user_admin_update.rb', line 22

def organization_role
  @organization_role
end

#passwordObject

Password of the account



20
21
22
# File 'lib/flat_api/models/user_admin_update.rb', line 20

def password
  @password
end

#usernameObject

Username of the account



25
26
27
# File 'lib/flat_api/models/user_admin_update.rb', line 25

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/flat_api/models/user_admin_update.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/flat_api/models/user_admin_update.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/flat_api/models/user_admin_update.rb', line 59

def self.attribute_map
  {
    :'password' => :'password',
    :'organization_role' => :'organizationRole',
    :'username' => :'username',
    :'firstname' => :'firstname',
    :'lastname' => :'lastname',
    :'email' => :'email'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/flat_api/models/user_admin_update.rb', line 276

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/flat_api/models/user_admin_update.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/flat_api/models/user_admin_update.rb', line 81

def self.openapi_types
  {
    :'password' => :'String',
    :'organization_role' => :'OrganizationRoles',
    :'username' => :'String',
    :'firstname' => :'String',
    :'lastname' => :'String',
    :'email' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



250
251
252
253
254
255
256
257
258
259
# File 'lib/flat_api/models/user_admin_update.rb', line 250

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      password == o.password &&
      organization_role == o.organization_role &&
      username == o.username &&
      firstname == o.firstname &&
      lastname == o.lastname &&
      email == o.email
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


263
264
265
# File 'lib/flat_api/models/user_admin_update.rb', line 263

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



269
270
271
# File 'lib/flat_api/models/user_admin_update.rb', line 269

def hash
  [password, organization_role, username, firstname, lastname, email].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/flat_api/models/user_admin_update.rb', line 141

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if !@password.nil? && @password.to_s.length > 1000
    invalid_properties.push('invalid value for "password", the character length must be smaller than or equal to 1000.')
  end

  if !@password.nil? && @password.to_s.length < 6
    invalid_properties.push('invalid value for "password", the character length must be greater than or equal to 6.')
  end

  if !@username.nil? && @username.to_s.length > 30
    invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 30.')
  end

  if !@username.nil? && @username.to_s.length < 1
    invalid_properties.push('invalid value for "username", the character length must be greater than or equal to 1.')
  end

  if !@firstname.nil? && @firstname.to_s.length > 60
    invalid_properties.push('invalid value for "firstname", the character length must be smaller than or equal to 60.')
  end

  if !@lastname.nil? && @lastname.to_s.length > 60
    invalid_properties.push('invalid value for "lastname", the character length must be smaller than or equal to 60.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/flat_api/models/user_admin_update.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
179
180
181
182
# File 'lib/flat_api/models/user_admin_update.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@password.nil? && @password.to_s.length > 1000
  return false if !@password.nil? && @password.to_s.length < 6
  return false if !@username.nil? && @username.to_s.length > 30
  return false if !@username.nil? && @username.to_s.length < 1
  return false if !@firstname.nil? && @firstname.to_s.length > 60
  return false if !@lastname.nil? && @lastname.to_s.length > 60
  true
end