Class: FlatApi::UserApi

Inherits:
Object
  • Object
show all
Defined in:
lib/flat_api/api/user_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ UserApi

Returns a new instance of UserApi.



19
20
21
# File 'lib/flat_api/api/user_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/flat_api/api/user_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_user(user, opts = {}) ⇒ UserPublic

Get a public user profile Get a profile of a Flat or Flat for Education User.

Parameters:

  • user (String)

    This route parameter is the unique identifier of the user. You can specify an email instead of an unique identifier. If you are executing this request authenticated, you can use `me` as a value instead of the current User unique identifier to work on the current authenticated user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/flat_api/api/user_api.rb', line 27

def get_user(user, opts = {})
  data, _status_code, _headers = get_user_with_http_info(user, opts)
  data
end

#get_user_likes(user, opts = {}) ⇒ Array<ScoreDetails>

List liked scores

Parameters:

  • user (String)

    Unique identifier of a Flat user. If you authenticated, you can use `me` to refer to the current user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :_next (String)

    An opaque string cursor to fetch the next page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :previous (String)

    An opaque string cursor to fetch the previous page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :limit (Integer)

    This is the maximum number of objects that may be returned (default to 25)

  • :ids (Boolean)

    Return only the identifiers of the scores

Returns:



93
94
95
96
# File 'lib/flat_api/api/user_api.rb', line 93

def get_user_likes(user, opts = {})
  data, _status_code, _headers = get_user_likes_with_http_info(user, opts)
  data
end

#get_user_likes_with_http_info(user, opts = {}) ⇒ Array<(Array<ScoreDetails>, Integer, Hash)>

List liked scores

Parameters:

  • user (String)

    Unique identifier of a Flat user. If you authenticated, you can use `me` to refer to the current user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :_next (String)

    An opaque string cursor to fetch the next page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :previous (String)

    An opaque string cursor to fetch the previous page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :limit (Integer)

    This is the maximum number of objects that may be returned (default to 25)

  • :ids (Boolean)

    Return only the identifiers of the scores

Returns:

  • (Array<(Array<ScoreDetails>, Integer, Hash)>)

    Array data, response status code and response headers



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/flat_api/api/user_api.rb', line 106

def get_user_likes_with_http_info(user, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UserApi.get_user_likes ...'
  end
  # verify the required parameter 'user' is set
  if @api_client.config.client_side_validation && user.nil?
    fail ArgumentError, "Missing the required parameter 'user' when calling UserApi.get_user_likes"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling UserApi.get_user_likes, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling UserApi.get_user_likes, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/users/{user}/likes'.sub('{user}', CGI.escape(user.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil?
  query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'ids'] = opts[:'ids'] if !opts[:'ids'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<ScoreDetails>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"UserApi.get_user_likes",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserApi#get_user_likes\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_user_scores(user, opts = {}) ⇒ Array<ScoreDetails>

List user's scores Get the list of public scores owned by a User. If you want to access to private scores, please use the Collections API. For example GET /v2/collections/allScores/scores to list all recently updated scores.

Parameters:

  • user (String)

    Unique identifier of a Flat user. If you authenticated, you can use `me` to refer to the current user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :paginate (Boolean)

    When set to `true`, the API will return a paginated result. When set to `false` or unset, the API will return all the scores. If this parameter is unset or false, then limit/sort/direction/next/previous will be ignored. (default to false)

  • :sort (String)

    Sort

  • :direction (String)

    Sort direction

  • :limit (Integer)

    This is the maximum number of objects that may be returned (default to 25)

  • :_next (String)

    An opaque string cursor to fetch the next page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :previous (String)

    An opaque string cursor to fetch the previous page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

Returns:



177
178
179
180
# File 'lib/flat_api/api/user_api.rb', line 177

def get_user_scores(user, opts = {})
  data, _status_code, _headers = get_user_scores_with_http_info(user, opts)
  data
end

#get_user_scores_with_http_info(user, opts = {}) ⇒ Array<(Array<ScoreDetails>, Integer, Hash)>

List user's scores Get the list of public scores owned by a User. If you want to access to private scores, please use the Collections API. For example `GET /v2/collections/allScores/scores` to list all recently updated scores.

Parameters:

  • user (String)

    Unique identifier of a Flat user. If you authenticated, you can use `me` to refer to the current user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :paginate (Boolean)

    When set to `true`, the API will return a paginated result. When set to `false` or unset, the API will return all the scores. If this parameter is unset or false, then limit/sort/direction/next/previous will be ignored. (default to false)

  • :sort (String)

    Sort

  • :direction (String)

    Sort direction

  • :limit (Integer)

    This is the maximum number of objects that may be returned (default to 25)

  • :_next (String)

    An opaque string cursor to fetch the next page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

  • :previous (String)

    An opaque string cursor to fetch the previous page of data. The paginated API URLs are returned in the `Link` header when requesting the API. These URLs will contain a `next` and `previous` cursor based on the available data.

Returns:

  • (Array<(Array<ScoreDetails>, Integer, Hash)>)

    Array data, response status code and response headers



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/flat_api/api/user_api.rb', line 193

def get_user_scores_with_http_info(user, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UserApi.get_user_scores ...'
  end
  # verify the required parameter 'user' is set
  if @api_client.config.client_side_validation && user.nil?
    fail ArgumentError, "Missing the required parameter 'user' when calling UserApi.get_user_scores"
  end
  allowable_values = ["creationDate", "modificationDate", "title"]
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  allowable_values = ["asc", "desc"]
  if @api_client.config.client_side_validation && opts[:'direction'] && !allowable_values.include?(opts[:'direction'])
    fail ArgumentError, "invalid value for \"direction\", must be one of #{allowable_values}"
  end
  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling UserApi.get_user_scores, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1
    fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling UserApi.get_user_scores, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/users/{user}/scores'.sub('{user}', CGI.escape(user.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'paginate'] = opts[:'paginate'] if !opts[:'paginate'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'direction'] = opts[:'direction'] if !opts[:'direction'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'next'] = opts[:'_next'] if !opts[:'_next'].nil?
  query_params[:'previous'] = opts[:'previous'] if !opts[:'previous'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<ScoreDetails>'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"UserApi.get_user_scores",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserApi#get_user_scores\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_user_with_http_info(user, opts = {}) ⇒ Array<(UserPublic, Integer, Hash)>

Get a public user profile Get a profile of a Flat or Flat for Education User.

Parameters:

  • user (String)

    This route parameter is the unique identifier of the user. You can specify an email instead of an unique identifier. If you are executing this request authenticated, you can use `me` as a value instead of the current User unique identifier to work on the current authenticated user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UserPublic, Integer, Hash)>)

    UserPublic data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/flat_api/api/user_api.rb', line 37

def get_user_with_http_info(user, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UserApi.get_user ...'
  end
  # verify the required parameter 'user' is set
  if @api_client.config.client_side_validation && user.nil?
    fail ArgumentError, "Missing the required parameter 'user' when calling UserApi.get_user"
  end
  # resource path
  local_var_path = '/users/{user}'.sub('{user}', CGI.escape(user.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UserPublic'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['OAuth2']

  new_options = opts.merge(
    :operation => :"UserApi.get_user",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UserApi#get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end