Class: FlatApi::UserCommunityProfileLinks

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/user_community_profile_links.rb

Overview

Social networks links

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserCommunityProfileLinks

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/flat_api/models/user_community_profile_links.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::UserCommunityProfileLinks` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::UserCommunityProfileLinks`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'spotify_url')
    self.spotify_url = attributes[:'spotify_url']
  end

  if attributes.key?(:'youtube_url')
    self.youtube_url = attributes[:'youtube_url']
  end

  if attributes.key?(:'soundcloud_url')
    self.soundcloud_url = attributes[:'soundcloud_url']
  end

  if attributes.key?(:'tiktok_url')
    self.tiktok_url = attributes[:'tiktok_url']
  end

  if attributes.key?(:'instagram_url')
    self.instagram_url = attributes[:'instagram_url']
  end

  if attributes.key?(:'website_url')
    self.website_url = attributes[:'website_url']
  end
end

Instance Attribute Details

#instagram_urlObject

Instagram profile URL. For updates, also accepts Instagram usernames



32
33
34
# File 'lib/flat_api/models/user_community_profile_links.rb', line 32

def instagram_url
  @instagram_url
end

#soundcloud_urlObject

SoundCloud Profile URL



26
27
28
# File 'lib/flat_api/models/user_community_profile_links.rb', line 26

def soundcloud_url
  @soundcloud_url
end

#spotify_urlObject

Spotify Profile URL



20
21
22
# File 'lib/flat_api/models/user_community_profile_links.rb', line 20

def spotify_url
  @spotify_url
end

#tiktok_urlObject

TikTok profile URL. For updates, also accepts TikTok usernames



29
30
31
# File 'lib/flat_api/models/user_community_profile_links.rb', line 29

def tiktok_url
  @tiktok_url
end

#website_urlObject

Personnal website URL



35
36
37
# File 'lib/flat_api/models/user_community_profile_links.rb', line 35

def website_url
  @website_url
end

#youtube_urlObject

YouTube channel URL



23
24
25
# File 'lib/flat_api/models/user_community_profile_links.rb', line 23

def youtube_url
  @youtube_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/flat_api/models/user_community_profile_links.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/flat_api/models/user_community_profile_links.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/flat_api/models/user_community_profile_links.rb', line 38

def self.attribute_map
  {
    :'spotify_url' => :'spotifyUrl',
    :'youtube_url' => :'youtubeUrl',
    :'soundcloud_url' => :'soundcloudUrl',
    :'tiktok_url' => :'tiktokUrl',
    :'instagram_url' => :'instagramUrl',
    :'website_url' => :'websiteUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/flat_api/models/user_community_profile_links.rb', line 167

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
76
77
78
79
80
81
# File 'lib/flat_api/models/user_community_profile_links.rb', line 72

def self.openapi_nullable
  Set.new([
    :'spotify_url',
    :'youtube_url',
    :'soundcloud_url',
    :'tiktok_url',
    :'instagram_url',
    :'website_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/flat_api/models/user_community_profile_links.rb', line 60

def self.openapi_types
  {
    :'spotify_url' => :'String',
    :'youtube_url' => :'String',
    :'soundcloud_url' => :'String',
    :'tiktok_url' => :'String',
    :'instagram_url' => :'String',
    :'website_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
149
150
# File 'lib/flat_api/models/user_community_profile_links.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      spotify_url == o.spotify_url &&
      youtube_url == o.youtube_url &&
      soundcloud_url == o.soundcloud_url &&
      tiktok_url == o.tiktok_url &&
      instagram_url == o.instagram_url &&
      website_url == o.website_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/flat_api/models/user_community_profile_links.rb', line 154

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



160
161
162
# File 'lib/flat_api/models/user_community_profile_links.rb', line 160

def hash
  [spotify_url, youtube_url, soundcloud_url, tiktok_url, instagram_url, website_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
# File 'lib/flat_api/models/user_community_profile_links.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/flat_api/models/user_community_profile_links.rb', line 189

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
# File 'lib/flat_api/models/user_community_profile_links.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end