Class: FlatApi::UserCreation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::UserCreation
- Defined in:
- lib/flat_api/models/user_creation.rb
Overview
User creation
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#email ⇒ Object
Email of the new account.
-
#firstname ⇒ Object
First name of the user.
-
#lastname ⇒ Object
Last name of the user.
-
#locale ⇒ Object
User language.
-
#password ⇒ Object
Password of the new account.
-
#role ⇒ Object
Role of the new account.
-
#username ⇒ Object
Username of the new account.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserCreation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserCreation
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/flat_api/models/user_creation.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::UserCreation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::UserCreation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end if attributes.key?(:'firstname') self.firstname = attributes[:'firstname'] end if attributes.key?(:'lastname') self.lastname = attributes[:'lastname'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'password') self.password = attributes[:'password'] else self.password = nil end if attributes.key?(:'locale') self.locale = attributes[:'locale'] else self.locale = 'en' end if attributes.key?(:'role') self.role = attributes[:'role'] else self.role = 'user' end end |
Instance Attribute Details
#email ⇒ Object
Email of the new account
29 30 31 |
# File 'lib/flat_api/models/user_creation.rb', line 29 def email @email end |
#firstname ⇒ Object
First name of the user
23 24 25 |
# File 'lib/flat_api/models/user_creation.rb', line 23 def firstname @firstname end |
#lastname ⇒ Object
Last name of the user
26 27 28 |
# File 'lib/flat_api/models/user_creation.rb', line 26 def lastname @lastname end |
#locale ⇒ Object
User language. Input values will be automatically normalized to a supported locale code.
35 36 37 |
# File 'lib/flat_api/models/user_creation.rb', line 35 def locale @locale end |
#password ⇒ Object
Password of the new account
32 33 34 |
# File 'lib/flat_api/models/user_creation.rb', line 32 def password @password end |
#role ⇒ Object
Role of the new account
38 39 40 |
# File 'lib/flat_api/models/user_creation.rb', line 38 def role @role end |
#username ⇒ Object
Username of the new account
20 21 22 |
# File 'lib/flat_api/models/user_creation.rb', line 20 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
76 77 78 |
# File 'lib/flat_api/models/user_creation.rb', line 76 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/flat_api/models/user_creation.rb', line 81 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/flat_api/models/user_creation.rb', line 63 def self.attribute_map { :'username' => :'username', :'firstname' => :'firstname', :'lastname' => :'lastname', :'email' => :'email', :'password' => :'password', :'locale' => :'locale', :'role' => :'role' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/flat_api/models/user_creation.rb', line 317 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/flat_api/models/user_creation.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/flat_api/models/user_creation.rb', line 86 def self.openapi_types { :'username' => :'String', :'firstname' => :'String', :'lastname' => :'String', :'email' => :'String', :'password' => :'String', :'locale' => :'String', :'role' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/flat_api/models/user_creation.rb', line 290 def ==(o) return true if self.equal?(o) self.class == o.class && username == o.username && firstname == o.firstname && lastname == o.lastname && email == o.email && password == o.password && locale == o.locale && role == o.role end |
#eql?(o) ⇒ Boolean
304 305 306 |
# File 'lib/flat_api/models/user_creation.rb', line 304 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
310 311 312 |
# File 'lib/flat_api/models/user_creation.rb', line 310 def hash [username, firstname, lastname, email, password, locale, role].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/flat_api/models/user_creation.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end if @username.to_s.length > 30 invalid_properties.push('invalid value for "username", the character length must be smaller than or equal to 30.') end if @username.to_s.length < 1 invalid_properties.push('invalid value for "username", the character length must be greater than or equal to 1.') end if !@firstname.nil? && @firstname.to_s.length > 60 invalid_properties.push('invalid value for "firstname", the character length must be smaller than or equal to 60.') end if !@lastname.nil? && @lastname.to_s.length > 60 invalid_properties.push('invalid value for "lastname", the character length must be smaller than or equal to 60.') end if @password.nil? invalid_properties.push('invalid value for "password", password cannot be nil.') end if @password.to_s.length > 1000 invalid_properties.push('invalid value for "password", the character length must be smaller than or equal to 1000.') end if @password.to_s.length < 6 invalid_properties.push('invalid value for "password", the character length must be greater than or equal to 6.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/flat_api/models/user_creation.rb', line 339 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/flat_api/models/user_creation.rb', line 199 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @username.nil? return false if @username.to_s.length > 30 return false if @username.to_s.length < 1 return false if !@firstname.nil? && @firstname.to_s.length > 60 return false if !@lastname.nil? && @lastname.to_s.length > 60 return false if @password.nil? return false if @password.to_s.length > 1000 return false if @password.to_s.length < 6 role_validator = EnumAttributeValidator.new('String', ["user", "teacher", "admin", "accountAdmin"]) return false unless role_validator.valid?(@role) true end |