Class: FlatApi::UserDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::UserDetails
- Defined in:
- lib/flat_api/models/user_details.rb
Overview
User details
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#all_public_scores_count ⇒ Object
Total number of public scores the user participates in (owned + joined).
-
#azure_details ⇒ Object
Returns the value of attribute azure_details.
-
#badges ⇒ Object
List of badges for the user profile: -
power-staff-composerOfTheMonth-ambassador-challenge. -
#bio ⇒ Object
User's biography.
-
#class_role ⇒ Object
Returns the value of attribute class_role.
-
#cover_picture ⇒ Object
Cover picture (backgroud) for the profile.
-
#cover_picture_file ⇒ Object
The ID of the user profile cover picture.
-
#firstname ⇒ Object
Firstname of the user (for education users).
-
#followers_count ⇒ Object
Number of followers the user have.
-
#following_count ⇒ Object
Number of people the user follow.
-
#groups ⇒ Object
For Flat for Education accounts, list of Group identifiers the user is part of.
-
#html_url ⇒ Object
Link to user profile (for Indiv. users only).
-
#id ⇒ Object
The user unique identifier.
-
#is_email_verified ⇒ Object
Whether the user's email address has been verified.
-
#lastname ⇒ Object
Lastname of the user (for education users).
-
#liked_scores_count ⇒ Object
Number of the scores liked by the user.
-
#likes_count ⇒ Object
Number of likes on the user published scores.
-
#links ⇒ Object
Returns the value of attribute links.
-
#locale ⇒ Object
The user language.
-
#name ⇒ Object
A displayable name for the user (for consumer users).
-
#organization ⇒ Object
Organization ID (for Edu users only).
-
#organization_role ⇒ Object
Returns the value of attribute organization_role.
-
#owned_public_scores_count ⇒ Object
Number of public scores the user have.
-
#picture ⇒ Object
The URL of the picture to display.
-
#picture_file ⇒ Object
The ID of the user profile picture.
-
#plays_count ⇒ Object
Number of plays on the user published scores.
-
#printable_name ⇒ Object
The name that can be directly printed (name, firstname & lastname, or username).
-
#private_profile ⇒ Object
Tell either this user profile is private or not (individual accounts only).
-
#product ⇒ Object
Returns the value of attribute product.
-
#profile_theme ⇒ Object
Theme (background) for the profile.
-
#registration_date ⇒ Object
Date the user signed up.
-
#type ⇒ Object
The type of user account.
-
#username ⇒ Object
The user name (unique for the organization).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserDetails
Initializes the object
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/flat_api/models/user_details.rb', line 240 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::UserDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::UserDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'product') self.product = attributes[:'product'] else self.product = 'flat' end if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end if attributes.key?(:'printable_name') self.printable_name = attributes[:'printable_name'] end if attributes.key?(:'firstname') self.firstname = attributes[:'firstname'] end if attributes.key?(:'lastname') self.lastname = attributes[:'lastname'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'picture') self.picture = attributes[:'picture'] else self.picture = nil end if attributes.key?(:'badges') if (value = attributes[:'badges']).is_a?(Array) self.badges = value end end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end if attributes.key?(:'organization_role') self.organization_role = attributes[:'organization_role'] end if attributes.key?(:'class_role') self.class_role = attributes[:'class_role'] end if attributes.key?(:'html_url') self.html_url = attributes[:'html_url'] end if attributes.key?(:'bio') self.bio = attributes[:'bio'] end if attributes.key?(:'registration_date') self.registration_date = attributes[:'registration_date'] end if attributes.key?(:'liked_scores_count') self.liked_scores_count = attributes[:'liked_scores_count'] end if attributes.key?(:'followers_count') self.followers_count = attributes[:'followers_count'] end if attributes.key?(:'following_count') self.following_count = attributes[:'following_count'] end if attributes.key?(:'owned_public_scores_count') self.owned_public_scores_count = attributes[:'owned_public_scores_count'] end if attributes.key?(:'all_public_scores_count') self.all_public_scores_count = attributes[:'all_public_scores_count'] end if attributes.key?(:'likes_count') self.likes_count = attributes[:'likes_count'] end if attributes.key?(:'plays_count') self.plays_count = attributes[:'plays_count'] end if attributes.key?(:'cover_picture') self.cover_picture = attributes[:'cover_picture'] end if attributes.key?(:'profile_theme') self.profile_theme = attributes[:'profile_theme'] end if attributes.key?(:'links') self.links = attributes[:'links'] end if attributes.key?(:'is_email_verified') self.is_email_verified = attributes[:'is_email_verified'] end if attributes.key?(:'azure_details') self.azure_details = attributes[:'azure_details'] end if attributes.key?(:'private_profile') self.private_profile = attributes[:'private_profile'] end if attributes.key?(:'locale') self.locale = attributes[:'locale'] else self.locale = 'en' end if attributes.key?(:'groups') if (value = attributes[:'groups']).is_a?(Array) self.groups = value end end if attributes.key?(:'picture_file') self.picture_file = attributes[:'picture_file'] end if attributes.key?(:'cover_picture_file') self.cover_picture_file = attributes[:'cover_picture_file'] end end |
Instance Attribute Details
#all_public_scores_count ⇒ Object
Total number of public scores the user participates in (owned + joined)
77 78 79 |
# File 'lib/flat_api/models/user_details.rb', line 77 def all_public_scores_count @all_public_scores_count end |
#azure_details ⇒ Object
Returns the value of attribute azure_details.
96 97 98 |
# File 'lib/flat_api/models/user_details.rb', line 96 def azure_details @azure_details end |
#badges ⇒ Object
List of badges for the user profile: - power - staff - composerOfTheMonth - ambassador - challenge
46 47 48 |
# File 'lib/flat_api/models/user_details.rb', line 46 def badges @badges end |
#bio ⇒ Object
User's biography
59 60 61 |
# File 'lib/flat_api/models/user_details.rb', line 59 def bio @bio end |
#class_role ⇒ Object
Returns the value of attribute class_role.
53 54 55 |
# File 'lib/flat_api/models/user_details.rb', line 53 def class_role @class_role end |
#cover_picture ⇒ Object
Cover picture (backgroud) for the profile
86 87 88 |
# File 'lib/flat_api/models/user_details.rb', line 86 def cover_picture @cover_picture end |
#cover_picture_file ⇒ Object
The ID of the user profile cover picture
111 112 113 |
# File 'lib/flat_api/models/user_details.rb', line 111 def cover_picture_file @cover_picture_file end |
#firstname ⇒ Object
Firstname of the user (for education users)
34 35 36 |
# File 'lib/flat_api/models/user_details.rb', line 34 def firstname @firstname end |
#followers_count ⇒ Object
Number of followers the user have
68 69 70 |
# File 'lib/flat_api/models/user_details.rb', line 68 def followers_count @followers_count end |
#following_count ⇒ Object
Number of people the user follow
71 72 73 |
# File 'lib/flat_api/models/user_details.rb', line 71 def following_count @following_count end |
#groups ⇒ Object
For Flat for Education accounts, list of Group identifiers the user is part of.
105 106 107 |
# File 'lib/flat_api/models/user_details.rb', line 105 def groups @groups end |
#html_url ⇒ Object
Link to user profile (for Indiv. users only)
56 57 58 |
# File 'lib/flat_api/models/user_details.rb', line 56 def html_url @html_url end |
#id ⇒ Object
The user unique identifier
20 21 22 |
# File 'lib/flat_api/models/user_details.rb', line 20 def id @id end |
#is_email_verified ⇒ Object
Whether the user's email address has been verified
94 95 96 |
# File 'lib/flat_api/models/user_details.rb', line 94 def is_email_verified @is_email_verified end |
#lastname ⇒ Object
Lastname of the user (for education users)
37 38 39 |
# File 'lib/flat_api/models/user_details.rb', line 37 def lastname @lastname end |
#liked_scores_count ⇒ Object
Number of the scores liked by the user
65 66 67 |
# File 'lib/flat_api/models/user_details.rb', line 65 def liked_scores_count @liked_scores_count end |
#likes_count ⇒ Object
Number of likes on the user published scores
80 81 82 |
# File 'lib/flat_api/models/user_details.rb', line 80 def likes_count @likes_count end |
#links ⇒ Object
Returns the value of attribute links.
91 92 93 |
# File 'lib/flat_api/models/user_details.rb', line 91 def links @links end |
#locale ⇒ Object
The user language. Input values will be automatically normalized to a supported locale code. Unknown locales will default to en. Current supported locales include: da, de, en, en-GB, es, fi, fil, fr, fr-CA, hi, id, it, ja, ja-HIRA, ko, ms, nb, nl, pl, pt, pt-BR, ro, ru, sv, tr, zh-Hans, zh-HK, zh-TW
102 103 104 |
# File 'lib/flat_api/models/user_details.rb', line 102 def locale @locale end |
#name ⇒ Object
A displayable name for the user (for consumer users)
40 41 42 |
# File 'lib/flat_api/models/user_details.rb', line 40 def name @name end |
#organization ⇒ Object
Organization ID (for Edu users only)
49 50 51 |
# File 'lib/flat_api/models/user_details.rb', line 49 def organization @organization end |
#organization_role ⇒ Object
Returns the value of attribute organization_role.
51 52 53 |
# File 'lib/flat_api/models/user_details.rb', line 51 def organization_role @organization_role end |
#owned_public_scores_count ⇒ Object
Number of public scores the user have
74 75 76 |
# File 'lib/flat_api/models/user_details.rb', line 74 def owned_public_scores_count @owned_public_scores_count end |
#picture ⇒ Object
The URL of the picture to display
43 44 45 |
# File 'lib/flat_api/models/user_details.rb', line 43 def picture @picture end |
#picture_file ⇒ Object
The ID of the user profile picture
108 109 110 |
# File 'lib/flat_api/models/user_details.rb', line 108 def picture_file @picture_file end |
#plays_count ⇒ Object
Number of plays on the user published scores
83 84 85 |
# File 'lib/flat_api/models/user_details.rb', line 83 def plays_count @plays_count end |
#printable_name ⇒ Object
The name that can be directly printed (name, firstname & lastname, or username)
31 32 33 |
# File 'lib/flat_api/models/user_details.rb', line 31 def printable_name @printable_name end |
#private_profile ⇒ Object
Tell either this user profile is private or not (individual accounts only)
99 100 101 |
# File 'lib/flat_api/models/user_details.rb', line 99 def private_profile @private_profile end |
#product ⇒ Object
Returns the value of attribute product.
25 26 27 |
# File 'lib/flat_api/models/user_details.rb', line 25 def product @product end |
#profile_theme ⇒ Object
Theme (background) for the profile
89 90 91 |
# File 'lib/flat_api/models/user_details.rb', line 89 def profile_theme @profile_theme end |
#registration_date ⇒ Object
Date the user signed up
62 63 64 |
# File 'lib/flat_api/models/user_details.rb', line 62 def registration_date @registration_date end |
#type ⇒ Object
The type of user account
23 24 25 |
# File 'lib/flat_api/models/user_details.rb', line 23 def type @type end |
#username ⇒ Object
The user name (unique for the organization)
28 29 30 |
# File 'lib/flat_api/models/user_details.rb', line 28 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
175 176 177 |
# File 'lib/flat_api/models/user_details.rb', line 175 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
180 181 182 |
# File 'lib/flat_api/models/user_details.rb', line 180 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/flat_api/models/user_details.rb', line 136 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'product' => :'product', :'username' => :'username', :'printable_name' => :'printableName', :'firstname' => :'firstname', :'lastname' => :'lastname', :'name' => :'name', :'picture' => :'picture', :'badges' => :'badges', :'organization' => :'organization', :'organization_role' => :'organizationRole', :'class_role' => :'classRole', :'html_url' => :'htmlUrl', :'bio' => :'bio', :'registration_date' => :'registrationDate', :'liked_scores_count' => :'likedScoresCount', :'followers_count' => :'followersCount', :'following_count' => :'followingCount', :'owned_public_scores_count' => :'ownedPublicScoresCount', :'all_public_scores_count' => :'allPublicScoresCount', :'likes_count' => :'likesCount', :'plays_count' => :'playsCount', :'cover_picture' => :'coverPicture', :'profile_theme' => :'profileTheme', :'links' => :'links', :'is_email_verified' => :'isEmailVerified', :'azure_details' => :'azureDetails', :'private_profile' => :'privateProfile', :'locale' => :'locale', :'groups' => :'groups', :'picture_file' => :'pictureFile', :'cover_picture_file' => :'coverPictureFile' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/flat_api/models/user_details.rb', line 550 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
232 233 234 235 236 |
# File 'lib/flat_api/models/user_details.rb', line 232 def self.openapi_all_of [ :'UserPublic' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
224 225 226 227 228 229 |
# File 'lib/flat_api/models/user_details.rb', line 224 def self.openapi_nullable Set.new([ :'picture_file', :'cover_picture_file' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/flat_api/models/user_details.rb', line 185 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'product' => :'TutteoProduct', :'username' => :'String', :'printable_name' => :'String', :'firstname' => :'String', :'lastname' => :'String', :'name' => :'String', :'picture' => :'String', :'badges' => :'Array<String>', :'organization' => :'String', :'organization_role' => :'OrganizationRoles', :'class_role' => :'ClassRoles', :'html_url' => :'String', :'bio' => :'String', :'registration_date' => :'Time', :'liked_scores_count' => :'Integer', :'followers_count' => :'Integer', :'following_count' => :'Integer', :'owned_public_scores_count' => :'Integer', :'all_public_scores_count' => :'Integer', :'likes_count' => :'Integer', :'plays_count' => :'Integer', :'cover_picture' => :'String', :'profile_theme' => :'String', :'links' => :'UserCommunityProfileLinks', :'is_email_verified' => :'Boolean', :'azure_details' => :'UserAzureDetails', :'private_profile' => :'Boolean', :'locale' => :'String', :'groups' => :'Array<String>', :'picture_file' => :'String', :'cover_picture_file' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/flat_api/models/user_details.rb', line 497 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && product == o.product && username == o.username && printable_name == o.printable_name && firstname == o.firstname && lastname == o.lastname && name == o.name && picture == o.picture && badges == o.badges && organization == o.organization && organization_role == o.organization_role && class_role == o.class_role && html_url == o.html_url && bio == o.bio && registration_date == o.registration_date && liked_scores_count == o.liked_scores_count && followers_count == o.followers_count && following_count == o.following_count && owned_public_scores_count == o.owned_public_scores_count && all_public_scores_count == o.all_public_scores_count && likes_count == o.likes_count && plays_count == o.plays_count && cover_picture == o.cover_picture && profile_theme == o.profile_theme && links == o.links && is_email_verified == o.is_email_verified && azure_details == o.azure_details && private_profile == o.private_profile && locale == o.locale && groups == o.groups && picture_file == o.picture_file && cover_picture_file == o.cover_picture_file end |
#eql?(o) ⇒ Boolean
537 538 539 |
# File 'lib/flat_api/models/user_details.rb', line 537 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
543 544 545 |
# File 'lib/flat_api/models/user_details.rb', line 543 def hash [id, type, product, username, printable_name, firstname, lastname, name, picture, badges, organization, organization_role, class_role, html_url, bio, registration_date, liked_scores_count, followers_count, following_count, owned_public_scores_count, all_public_scores_count, likes_count, plays_count, cover_picture, profile_theme, links, is_email_verified, azure_details, private_profile, locale, groups, picture_file, cover_picture_file].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/flat_api/models/user_details.rb', line 405 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @product.nil? invalid_properties.push('invalid value for "product", product cannot be nil.') end if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end if @picture.nil? invalid_properties.push('invalid value for "picture", picture cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
572 573 574 575 576 577 578 579 580 581 582 583 584 |
# File 'lib/flat_api/models/user_details.rb', line 572 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
433 434 435 436 437 438 439 440 441 442 443 |
# File 'lib/flat_api/models/user_details.rb', line 433 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["user", "guest"]) return false unless type_validator.valid?(@type) return false if @product.nil? return false if @username.nil? return false if @picture.nil? true end |