Class: FlatApi::UserDetailsAdmin

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/user_details_admin.rb

Overview

User details (view for organization teacher / admin)

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserDetailsAdmin

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/flat_api/models/user_details_admin.rb', line 169

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::UserDetailsAdmin` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::UserDetailsAdmin`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'product')
    self.product = attributes[:'product']
  else
    self.product = 'flat'
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  else
    self.username = nil
  end

  if attributes.key?(:'printable_name')
    self.printable_name = attributes[:'printable_name']
  end

  if attributes.key?(:'firstname')
    self.firstname = attributes[:'firstname']
  end

  if attributes.key?(:'lastname')
    self.lastname = attributes[:'lastname']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'picture')
    self.picture = attributes[:'picture']
  else
    self.picture = nil
  end

  if attributes.key?(:'badges')
    if (value = attributes[:'badges']).is_a?(Array)
      self.badges = value
    end
  end

  if attributes.key?(:'organization')
    self.organization = attributes[:'organization']
  end

  if attributes.key?(:'organization_role')
    self.organization_role = attributes[:'organization_role']
  end

  if attributes.key?(:'class_role')
    self.class_role = attributes[:'class_role']
  end

  if attributes.key?(:'html_url')
    self.html_url = attributes[:'html_url']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'last_activity_date')
    self.last_activity_date = attributes[:'last_activity_date']
  end

  if attributes.key?(:'license')
    self.license = attributes[:'license']
  end

  if attributes.key?(:'groups')
    if (value = attributes[:'groups']).is_a?(Array)
      self.groups = value
    end
  end

  if attributes.key?(:'is_edu_testing_student')
    self.is_edu_testing_student = attributes[:'is_edu_testing_student']
  end
end

Instance Attribute Details

#badgesObject

List of badges for the user profile: - power - staff - composerOfTheMonth - ambassador - challenge



46
47
48
# File 'lib/flat_api/models/user_details_admin.rb', line 46

def badges
  @badges
end

#class_roleObject

Returns the value of attribute class_role.



53
54
55
# File 'lib/flat_api/models/user_details_admin.rb', line 53

def class_role
  @class_role
end

#emailObject

Email of the user



59
60
61
# File 'lib/flat_api/models/user_details_admin.rb', line 59

def email
  @email
end

#firstnameObject

Firstname of the user (for education users)



34
35
36
# File 'lib/flat_api/models/user_details_admin.rb', line 34

def firstname
  @firstname
end

#groupsObject

For Flat for Education accounts, list of Group identifiers the user is part of.



67
68
69
# File 'lib/flat_api/models/user_details_admin.rb', line 67

def groups
  @groups
end

#html_urlObject

Link to user profile (for Indiv. users only)



56
57
58
# File 'lib/flat_api/models/user_details_admin.rb', line 56

def html_url
  @html_url
end

#idObject

The user unique identifier



20
21
22
# File 'lib/flat_api/models/user_details_admin.rb', line 20

def id
  @id
end

#is_edu_testing_studentObject

Indicates if the user account is marked as a testing student account. Testing students are typically excluded from certain educational integrations and workflows. This field helps API clients distinguish between regular students and testing accounts.



70
71
72
# File 'lib/flat_api/models/user_details_admin.rb', line 70

def is_edu_testing_student
  @is_edu_testing_student
end

#last_activity_dateObject

Date of the last user activity



62
63
64
# File 'lib/flat_api/models/user_details_admin.rb', line 62

def last_activity_date
  @last_activity_date
end

#lastnameObject

Lastname of the user (for education users)



37
38
39
# File 'lib/flat_api/models/user_details_admin.rb', line 37

def lastname
  @lastname
end

#licenseObject

Returns the value of attribute license.



64
65
66
# File 'lib/flat_api/models/user_details_admin.rb', line 64

def license
  @license
end

#nameObject

A displayable name for the user (for consumer users)



40
41
42
# File 'lib/flat_api/models/user_details_admin.rb', line 40

def name
  @name
end

#organizationObject

Organization ID (for Edu users only)



49
50
51
# File 'lib/flat_api/models/user_details_admin.rb', line 49

def organization
  @organization
end

#organization_roleObject

Returns the value of attribute organization_role.



51
52
53
# File 'lib/flat_api/models/user_details_admin.rb', line 51

def organization_role
  @organization_role
end

#pictureObject

The URL of the picture to display



43
44
45
# File 'lib/flat_api/models/user_details_admin.rb', line 43

def picture
  @picture
end

#printable_nameObject

The name that can be directly printed (name, firstname & lastname, or username)



31
32
33
# File 'lib/flat_api/models/user_details_admin.rb', line 31

def printable_name
  @printable_name
end

#productObject

Returns the value of attribute product.



25
26
27
# File 'lib/flat_api/models/user_details_admin.rb', line 25

def product
  @product
end

#typeObject

The type of user account



23
24
25
# File 'lib/flat_api/models/user_details_admin.rb', line 23

def type
  @type
end

#usernameObject

The user name (unique for the organization)



28
29
30
# File 'lib/flat_api/models/user_details_admin.rb', line 28

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



120
121
122
# File 'lib/flat_api/models/user_details_admin.rb', line 120

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



125
126
127
# File 'lib/flat_api/models/user_details_admin.rb', line 125

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/flat_api/models/user_details_admin.rb', line 95

def self.attribute_map
  {
    :'id' => :'id',
    :'type' => :'type',
    :'product' => :'product',
    :'username' => :'username',
    :'printable_name' => :'printableName',
    :'firstname' => :'firstname',
    :'lastname' => :'lastname',
    :'name' => :'name',
    :'picture' => :'picture',
    :'badges' => :'badges',
    :'organization' => :'organization',
    :'organization_role' => :'organizationRole',
    :'class_role' => :'classRole',
    :'html_url' => :'htmlUrl',
    :'email' => :'email',
    :'last_activity_date' => :'lastActivityDate',
    :'license' => :'license',
    :'groups' => :'groups',
    :'is_edu_testing_student' => :'isEduTestingStudent'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/flat_api/models/user_details_admin.rb', line 407

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



161
162
163
164
165
# File 'lib/flat_api/models/user_details_admin.rb', line 161

def self.openapi_all_of
  [
  :'UserPublicSummary'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



155
156
157
158
# File 'lib/flat_api/models/user_details_admin.rb', line 155

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/flat_api/models/user_details_admin.rb', line 130

def self.openapi_types
  {
    :'id' => :'String',
    :'type' => :'String',
    :'product' => :'TutteoProduct',
    :'username' => :'String',
    :'printable_name' => :'String',
    :'firstname' => :'String',
    :'lastname' => :'String',
    :'name' => :'String',
    :'picture' => :'String',
    :'badges' => :'Array<String>',
    :'organization' => :'String',
    :'organization_role' => :'OrganizationRoles',
    :'class_role' => :'ClassRoles',
    :'html_url' => :'String',
    :'email' => :'String',
    :'last_activity_date' => :'Time',
    :'license' => :'UserDetailsAdminAllOfLicense',
    :'groups' => :'Array<String>',
    :'is_edu_testing_student' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/flat_api/models/user_details_admin.rb', line 368

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      type == o.type &&
      product == o.product &&
      username == o.username &&
      printable_name == o.printable_name &&
      firstname == o.firstname &&
      lastname == o.lastname &&
      name == o.name &&
      picture == o.picture &&
      badges == o.badges &&
      organization == o.organization &&
      organization_role == o.organization_role &&
      class_role == o.class_role &&
      html_url == o.html_url &&
      email == o.email &&
      last_activity_date == o.last_activity_date &&
      license == o.license &&
      groups == o.groups &&
      is_edu_testing_student == o.is_edu_testing_student
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


394
395
396
# File 'lib/flat_api/models/user_details_admin.rb', line 394

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



400
401
402
# File 'lib/flat_api/models/user_details_admin.rb', line 400

def hash
  [id, type, product, username, printable_name, firstname, lastname, name, picture, badges, organization, organization_role, class_role, html_url, email, last_activity_date, license, groups, is_edu_testing_student].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/flat_api/models/user_details_admin.rb', line 276

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @product.nil?
    invalid_properties.push('invalid value for "product", product cannot be nil.')
  end

  if @username.nil?
    invalid_properties.push('invalid value for "username", username cannot be nil.')
  end

  if @picture.nil?
    invalid_properties.push('invalid value for "picture", picture cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/flat_api/models/user_details_admin.rb', line 429

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



304
305
306
307
308
309
310
311
312
313
314
# File 'lib/flat_api/models/user_details_admin.rb', line 304

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["user", "guest"])
  return false unless type_validator.valid?(@type)
  return false if @product.nil?
  return false if @username.nil?
  return false if @picture.nil?
  true
end