Class: FlatApi::UserDetailsAdminAllOfLicense

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/user_details_admin_all_of_license.rb

Overview

Current active license of the user

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserDetailsAdminAllOfLicense

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::UserDetailsAdminAllOfLicense` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::UserDetailsAdminAllOfLicense`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'expiration_date')
    self.expiration_date = attributes[:'expiration_date']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  else
    self.source = 'order'
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  end
end

Instance Attribute Details

#activeObject

ID of the current license



30
31
32
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 30

def active
  @active
end

#expiration_dateObject

Date when the license expires



23
24
25
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 23

def expiration_date
  @expiration_date
end

#idObject

ID of the current license



20
21
22
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 20

def id
  @id
end

#modeObject

Returns the value of attribute mode.



27
28
29
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 27

def mode
  @mode
end

#sourceObject

Returns the value of attribute source.



25
26
27
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 25

def source
  @source
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 55

def self.attribute_map
  {
    :'id' => :'id',
    :'expiration_date' => :'expirationDate',
    :'source' => :'source',
    :'mode' => :'mode',
    :'active' => :'active'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 173

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 87

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 76

def self.openapi_types
  {
    :'id' => :'String',
    :'expiration_date' => :'Time',
    :'source' => :'LicenseSources',
    :'mode' => :'LicenseMode',
    :'active' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



148
149
150
151
152
153
154
155
156
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      expiration_date == o.expiration_date &&
      source == o.source &&
      mode == o.mode &&
      active == o.active
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 160

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



166
167
168
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 166

def hash
  [id, expiration_date, source, mode, active].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



133
134
135
136
137
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 133

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
# File 'lib/flat_api/models/user_details_admin_all_of_license.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end