Class: FlatApi::ClassDetailsClever
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ClassDetailsClever
- Defined in:
- lib/flat_api/models/class_details_clever.rb
Overview
Clever.com section-related information
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#creation_date ⇒ Object
The creation date of the section on clever.
-
#id ⇒ Object
Clever section unique identifier.
-
#modification_date ⇒ Object
The last modification date of the section on clever.
-
#subject ⇒ Object
Normalized subject of the course.
-
#term_end_date ⇒ Object
End date of the term.
-
#term_name ⇒ Object
Name of the term when this course happens.
-
#term_start_date ⇒ Object
Beginning date of the term.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClassDetailsClever
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClassDetailsClever
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/flat_api/models/class_details_clever.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ClassDetailsClever` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ClassDetailsClever`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'modification_date') self.modification_date = attributes[:'modification_date'] end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'term_name') self.term_name = attributes[:'term_name'] end if attributes.key?(:'term_start_date') self.term_start_date = attributes[:'term_start_date'] end if attributes.key?(:'term_end_date') self.term_end_date = attributes[:'term_end_date'] end end |
Instance Attribute Details
#creation_date ⇒ Object
The creation date of the section on clever
23 24 25 |
# File 'lib/flat_api/models/class_details_clever.rb', line 23 def creation_date @creation_date end |
#id ⇒ Object
Clever section unique identifier
20 21 22 |
# File 'lib/flat_api/models/class_details_clever.rb', line 20 def id @id end |
#modification_date ⇒ Object
The last modification date of the section on clever
26 27 28 |
# File 'lib/flat_api/models/class_details_clever.rb', line 26 def modification_date @modification_date end |
#subject ⇒ Object
Normalized subject of the course
29 30 31 |
# File 'lib/flat_api/models/class_details_clever.rb', line 29 def subject @subject end |
#term_end_date ⇒ Object
End date of the term
38 39 40 |
# File 'lib/flat_api/models/class_details_clever.rb', line 38 def term_end_date @term_end_date end |
#term_name ⇒ Object
Name of the term when this course happens
32 33 34 |
# File 'lib/flat_api/models/class_details_clever.rb', line 32 def term_name @term_name end |
#term_start_date ⇒ Object
Beginning date of the term
35 36 37 |
# File 'lib/flat_api/models/class_details_clever.rb', line 35 def term_start_date @term_start_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
76 77 78 |
# File 'lib/flat_api/models/class_details_clever.rb', line 76 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/flat_api/models/class_details_clever.rb', line 81 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/flat_api/models/class_details_clever.rb', line 63 def self.attribute_map { :'id' => :'id', :'creation_date' => :'creationDate', :'modification_date' => :'modificationDate', :'subject' => :'subject', :'term_name' => :'termName', :'term_start_date' => :'termStartDate', :'term_end_date' => :'termEndDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/flat_api/models/class_details_clever.rb', line 205 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/flat_api/models/class_details_clever.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/flat_api/models/class_details_clever.rb', line 86 def self.openapi_types { :'id' => :'String', :'creation_date' => :'Time', :'modification_date' => :'Time', :'subject' => :'String', :'term_name' => :'String', :'term_start_date' => :'Time', :'term_end_date' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/flat_api/models/class_details_clever.rb', line 178 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && creation_date == o.creation_date && modification_date == o.modification_date && subject == o.subject && term_name == o.term_name && term_start_date == o.term_start_date && term_end_date == o.term_end_date end |
#eql?(o) ⇒ Boolean
192 193 194 |
# File 'lib/flat_api/models/class_details_clever.rb', line 192 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
198 199 200 |
# File 'lib/flat_api/models/class_details_clever.rb', line 198 def hash [id, creation_date, modification_date, subject, term_name, term_start_date, term_end_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 |
# File 'lib/flat_api/models/class_details_clever.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/flat_api/models/class_details_clever.rb', line 227 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
159 160 161 162 163 164 |
# File 'lib/flat_api/models/class_details_clever.rb', line 159 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' subject_validator = EnumAttributeValidator.new('String', ["english/language arts", "math", "science", "social studies", "language", "homeroom/advisory", "interventions/online learning", "technology and engineering", "PE and health", "arts and music", "other"]) return false unless subject_validator.valid?(@subject) true end |