Class: FlatApi::ClassUpdate
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ClassUpdate
- Defined in:
- lib/flat_api/models/class_update.rb
Overview
Update of a classroom
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#level ⇒ Object
Returns the value of attribute level.
-
#name ⇒ Object
The name of the class.
-
#section ⇒ Object
The section of the class.
-
#size ⇒ Object
Number of students in the classroom.
-
#skills_focused ⇒ Object
Specific skills that will be focused in classroom.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClassUpdate
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClassUpdate
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/flat_api/models/class_update.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ClassUpdate` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ClassUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'section') self.section = attributes[:'section'] end if attributes.key?(:'level') self.level = attributes[:'level'] end if attributes.key?(:'skills_focused') if (value = attributes[:'skills_focused']).is_a?(Array) self.skills_focused = value end end if attributes.key?(:'size') self.size = attributes[:'size'] end end |
Instance Attribute Details
#level ⇒ Object
Returns the value of attribute level.
25 26 27 |
# File 'lib/flat_api/models/class_update.rb', line 25 def level @level end |
#name ⇒ Object
The name of the class
20 21 22 |
# File 'lib/flat_api/models/class_update.rb', line 20 def name @name end |
#section ⇒ Object
The section of the class
23 24 25 |
# File 'lib/flat_api/models/class_update.rb', line 23 def section @section end |
#size ⇒ Object
Number of students in the classroom
31 32 33 |
# File 'lib/flat_api/models/class_update.rb', line 31 def size @size end |
#skills_focused ⇒ Object
Specific skills that will be focused in classroom
28 29 30 |
# File 'lib/flat_api/models/class_update.rb', line 28 def skills_focused @skills_focused end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/flat_api/models/class_update.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/flat_api/models/class_update.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/flat_api/models/class_update.rb', line 56 def self.attribute_map { :'name' => :'name', :'section' => :'section', :'level' => :'level', :'skills_focused' => :'skillsFocused', :'size' => :'size' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/flat_api/models/class_update.rb', line 228 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 92 |
# File 'lib/flat_api/models/class_update.rb', line 88 def self.openapi_nullable Set.new([ :'size' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/flat_api/models/class_update.rb', line 77 def self.openapi_types { :'name' => :'String', :'section' => :'String', :'level' => :'ClassGradeLevel', :'skills_focused' => :'Array<String>', :'size' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 |
# File 'lib/flat_api/models/class_update.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && section == o.section && level == o.level && skills_focused == o.skills_focused && size == o.size end |
#eql?(o) ⇒ Boolean
215 216 217 |
# File 'lib/flat_api/models/class_update.rb', line 215 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/flat_api/models/class_update.rb', line 221 def hash [name, section, level, skills_focused, size].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/flat_api/models/class_update.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 255 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 255.') end if !@section.nil? && @section.to_s.length > 255 invalid_properties.push('invalid value for "section", the character length must be smaller than or equal to 255.') end if !@size.nil? && @size < 0 invalid_properties.push('invalid value for "size", must be greater than or equal to 0.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/flat_api/models/class_update.rb', line 250 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 159 160 161 |
# File 'lib/flat_api/models/class_update.rb', line 155 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 255 return false if !@section.nil? && @section.to_s.length > 255 return false if !@size.nil? && @size < 0 true end |