Class: FlatApi::EduResource
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::EduResource
- Defined in:
- lib/flat_api/models/edu_resource.rb
Overview
A Flat for Education resource contained in a resources library
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
Returns the value of attribute capabilities.
-
#creation_date ⇒ Object
The date when the resource was created.
-
#creator ⇒ Object
The User identifier of the resource creator.
-
#grades ⇒ Object
The grades of this resource, or the grades of the resources included in the folder.
-
#id ⇒ Object
Resource unique identifier.
-
#parent ⇒ Object
Identifier of the parent resource, e.g.
-
#privacy ⇒ Object
Returns the value of attribute privacy.
-
#resource ⇒ Object
Returns the value of attribute resource.
-
#sharing_description ⇒ Object
Sharing description of this resource.
-
#sharing_description_html ⇒ Object
HTML version of sharing description with rich text formatting.
-
#subjects ⇒ Object
The subjects of this resource, or the subjects of the resources included in the folder.
-
#tags ⇒ Object
Specific attributes for the resource (e.g. sample resources with custom design).
-
#title ⇒ Object
Title of the resource.
-
#type ⇒ Object
Returns the value of attribute type.
-
#update_date ⇒ Object
The date when the resource was updated.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EduResource
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EduResource
Initializes the object
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/flat_api/models/edu_resource.rb', line 142 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::EduResource` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::EduResource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'creator') self.creator = attributes[:'creator'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'privacy') self.privacy = attributes[:'privacy'] else self.privacy = 'private' end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'parent') self.parent = attributes[:'parent'] end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'sharing_description') self.sharing_description = attributes[:'sharing_description'] end if attributes.key?(:'sharing_description_html') self.sharing_description_html = attributes[:'sharing_description_html'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'update_date') self.update_date = attributes[:'update_date'] end if attributes.key?(:'resource') self.resource = attributes[:'resource'] end if attributes.key?(:'capabilities') self.capabilities = attributes[:'capabilities'] else self.capabilities = nil end if attributes.key?(:'subjects') if (value = attributes[:'subjects']).is_a?(Array) self.subjects = value end end if attributes.key?(:'grades') if (value = attributes[:'grades']).is_a?(Array) self.grades = value end end end |
Instance Attribute Details
#capabilities ⇒ Object
Returns the value of attribute capabilities.
52 53 54 |
# File 'lib/flat_api/models/edu_resource.rb', line 52 def capabilities @capabilities end |
#creation_date ⇒ Object
The date when the resource was created
45 46 47 |
# File 'lib/flat_api/models/edu_resource.rb', line 45 def creation_date @creation_date end |
#creator ⇒ Object
The User identifier of the resource creator
23 24 25 |
# File 'lib/flat_api/models/edu_resource.rb', line 23 def creator @creator end |
#grades ⇒ Object
The grades of this resource, or the grades of the resources included in the folder.
58 59 60 |
# File 'lib/flat_api/models/edu_resource.rb', line 58 def grades @grades end |
#id ⇒ Object
Resource unique identifier
20 21 22 |
# File 'lib/flat_api/models/edu_resource.rb', line 20 def id @id end |
#parent ⇒ Object
Identifier of the parent resource, e.g. a folder or root
33 34 35 |
# File 'lib/flat_api/models/edu_resource.rb', line 33 def parent @parent end |
#privacy ⇒ Object
Returns the value of attribute privacy.
27 28 29 |
# File 'lib/flat_api/models/edu_resource.rb', line 27 def privacy @privacy end |
#resource ⇒ Object
Returns the value of attribute resource.
50 51 52 |
# File 'lib/flat_api/models/edu_resource.rb', line 50 def resource @resource end |
#sharing_description ⇒ Object
Sharing description of this resource
39 40 41 |
# File 'lib/flat_api/models/edu_resource.rb', line 39 def sharing_description @sharing_description end |
#sharing_description_html ⇒ Object
HTML version of sharing description with rich text formatting. Supports safe HTML tags: p, br, strong, b, em, i, u, a.
42 43 44 |
# File 'lib/flat_api/models/edu_resource.rb', line 42 def sharing_description_html @sharing_description_html end |
#subjects ⇒ Object
The subjects of this resource, or the subjects of the resources included in the folder
55 56 57 |
# File 'lib/flat_api/models/edu_resource.rb', line 55 def subjects @subjects end |
#tags ⇒ Object
Specific attributes for the resource (e.g. sample resources with custom design)
30 31 32 |
# File 'lib/flat_api/models/edu_resource.rb', line 30 def @tags end |
#title ⇒ Object
Title of the resource
36 37 38 |
# File 'lib/flat_api/models/edu_resource.rb', line 36 def title @title end |
#type ⇒ Object
Returns the value of attribute type.
25 26 27 |
# File 'lib/flat_api/models/edu_resource.rb', line 25 def type @type end |
#update_date ⇒ Object
The date when the resource was updated
48 49 50 |
# File 'lib/flat_api/models/edu_resource.rb', line 48 def update_date @update_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
104 105 106 |
# File 'lib/flat_api/models/edu_resource.rb', line 104 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
109 110 111 |
# File 'lib/flat_api/models/edu_resource.rb', line 109 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/flat_api/models/edu_resource.rb', line 83 def self.attribute_map { :'id' => :'id', :'creator' => :'creator', :'type' => :'type', :'privacy' => :'privacy', :'tags' => :'tags', :'parent' => :'parent', :'title' => :'title', :'sharing_description' => :'sharingDescription', :'sharing_description_html' => :'sharingDescriptionHtml', :'creation_date' => :'creationDate', :'update_date' => :'updateDate', :'resource' => :'resource', :'capabilities' => :'capabilities', :'subjects' => :'subjects', :'grades' => :'grades' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/flat_api/models/edu_resource.rb', line 345 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
135 136 137 138 |
# File 'lib/flat_api/models/edu_resource.rb', line 135 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/flat_api/models/edu_resource.rb', line 114 def self.openapi_types { :'id' => :'String', :'creator' => :'String', :'type' => :'EduResourceType', :'privacy' => :'EduResourcePrivacy', :'tags' => :'Array<String>', :'parent' => :'String', :'title' => :'String', :'sharing_description' => :'String', :'sharing_description_html' => :'String', :'creation_date' => :'Time', :'update_date' => :'Time', :'resource' => :'EduResourceResource', :'capabilities' => :'EduResourceCapabilities', :'subjects' => :'Array<TeachingTheme>', :'grades' => :'Array<Grade>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/flat_api/models/edu_resource.rb', line 310 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && creator == o.creator && type == o.type && privacy == o.privacy && == o. && parent == o.parent && title == o.title && sharing_description == o.sharing_description && sharing_description_html == o.sharing_description_html && creation_date == o.creation_date && update_date == o.update_date && resource == o.resource && capabilities == o.capabilities && subjects == o.subjects && grades == o.grades end |
#eql?(o) ⇒ Boolean
332 333 334 |
# File 'lib/flat_api/models/edu_resource.rb', line 332 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
338 339 340 |
# File 'lib/flat_api/models/edu_resource.rb', line 338 def hash [id, creator, type, privacy, , parent, title, sharing_description, sharing_description_html, creation_date, update_date, resource, capabilities, subjects, grades].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/flat_api/models/edu_resource.rb', line 235 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @capabilities.nil? invalid_properties.push('invalid value for "capabilities", capabilities cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/flat_api/models/edu_resource.rb', line 367 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
259 260 261 262 263 264 265 266 |
# File 'lib/flat_api/models/edu_resource.rb', line 259 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? return false if @title.nil? return false if @capabilities.nil? true end |