Class: FlatApi::GroupDetails
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::GroupDetails
- Defined in:
- lib/flat_api/models/group_details.rb
Overview
The details of a group
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#assignment ⇒ Object
The unique identifier of the assignment owning the group.
-
#classroom ⇒ Object
The unique identifier of the classroom owning the group.
-
#creation_date ⇒ Object
The date when the group was create.
-
#id ⇒ Object
The unique identifier of the group.
-
#name ⇒ Object
The displayable name of the group.
-
#organization ⇒ Object
The unique identifier of the Organization owning the group.
-
#parent ⇒ Object
The unique identifier of the parent class group.
-
#read_only ⇒ Object
trueif the properties and members of this group are in in read-only. -
#tags ⇒ Object
Tags for categorizing groups.
-
#type ⇒ Object
Returns the value of attribute type.
-
#users_count ⇒ Object
The number of students in this group.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GroupDetails
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GroupDetails
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/flat_api/models/group_details.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::GroupDetails` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::GroupDetails`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end if attributes.key?(:'classroom') self.classroom = attributes[:'classroom'] end if attributes.key?(:'assignment') self.assignment = attributes[:'assignment'] end if attributes.key?(:'parent') self.parent = attributes[:'parent'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] else self.creation_date = nil end if attributes.key?(:'users_count') self.users_count = attributes[:'users_count'] else self.users_count = nil end if attributes.key?(:'read_only') self.read_only = attributes[:'read_only'] else self.read_only = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end else self. = nil end end |
Instance Attribute Details
#assignment ⇒ Object
The unique identifier of the assignment owning the group. Only available for groups of type 'assignmentStudentsSubGroup'.
34 35 36 |
# File 'lib/flat_api/models/group_details.rb', line 34 def assignment @assignment end |
#classroom ⇒ Object
The unique identifier of the classroom owning the group. Only available for groups of type 'classromStudentsSubGroup' or 'assignmentStudentsSubGroup'
31 32 33 |
# File 'lib/flat_api/models/group_details.rb', line 31 def classroom @classroom end |
#creation_date ⇒ Object
The date when the group was create
40 41 42 |
# File 'lib/flat_api/models/group_details.rb', line 40 def creation_date @creation_date end |
#id ⇒ Object
The unique identifier of the group
20 21 22 |
# File 'lib/flat_api/models/group_details.rb', line 20 def id @id end |
#name ⇒ Object
The displayable name of the group
23 24 25 |
# File 'lib/flat_api/models/group_details.rb', line 23 def name @name end |
#organization ⇒ Object
The unique identifier of the Organization owning the group
28 29 30 |
# File 'lib/flat_api/models/group_details.rb', line 28 def organization @organization end |
#parent ⇒ Object
The unique identifier of the parent class group. Only available for groups of type 'assignmentStudentsSubGroup'. May be null if the parent class group was deleted.
37 38 39 |
# File 'lib/flat_api/models/group_details.rb', line 37 def parent @parent end |
#read_only ⇒ Object
true if the properties and members of this group are in in read-only
46 47 48 |
# File 'lib/flat_api/models/group_details.rb', line 46 def read_only @read_only end |
#tags ⇒ Object
Tags for categorizing groups. * edu:testing-students: Marks this group as containing test student accounts
49 50 51 |
# File 'lib/flat_api/models/group_details.rb', line 49 def end |
#type ⇒ Object
Returns the value of attribute type.
25 26 27 |
# File 'lib/flat_api/models/group_details.rb', line 25 def type @type end |
#users_count ⇒ Object
The number of students in this group
43 44 45 |
# File 'lib/flat_api/models/group_details.rb', line 43 def users_count @users_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/flat_api/models/group_details.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/flat_api/models/group_details.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/flat_api/models/group_details.rb', line 74 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'type' => :'type', :'organization' => :'organization', :'classroom' => :'classroom', :'assignment' => :'assignment', :'parent' => :'parent', :'creation_date' => :'creationDate', :'users_count' => :'usersCount', :'read_only' => :'readOnly', :'tags' => :'tags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/flat_api/models/group_details.rb', line 353 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/flat_api/models/group_details.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/flat_api/models/group_details.rb', line 101 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'type' => :'GroupType', :'organization' => :'String', :'classroom' => :'String', :'assignment' => :'String', :'parent' => :'String', :'creation_date' => :'Time', :'users_count' => :'Float', :'read_only' => :'Boolean', :'tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/flat_api/models/group_details.rb', line 322 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && type == o.type && organization == o.organization && classroom == o.classroom && assignment == o.assignment && parent == o.parent && creation_date == o.creation_date && users_count == o.users_count && read_only == o.read_only && == o. end |
#eql?(o) ⇒ Boolean
340 341 342 |
# File 'lib/flat_api/models/group_details.rb', line 340 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
346 347 348 |
# File 'lib/flat_api/models/group_details.rb', line 346 def hash [id, name, type, organization, classroom, assignment, parent, creation_date, users_count, read_only, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/flat_api/models/group_details.rb', line 202 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end if @users_count.nil? invalid_properties.push('invalid value for "users_count", users_count cannot be nil.') end if @read_only.nil? invalid_properties.push('invalid value for "read_only", read_only cannot be nil.') end if .nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/flat_api/models/group_details.rb', line 375 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/flat_api/models/group_details.rb', line 238 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @type.nil? return false if @creation_date.nil? return false if @users_count.nil? return false if @read_only.nil? return false if .nil? true end |