Class: FlatApi::LtiConfiguration1p3BaseTool
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::LtiConfiguration1p3BaseTool
- Defined in:
- lib/flat_api/models/lti_configuration1p3_base_tool.rb
Overview
Platform/tool product information
Instance Attribute Summary collapse
-
#instance_contact ⇒ Object
Contact email or handle for the instance.
-
#instance_domain ⇒ Object
Instance root domain.
-
#instance_guid ⇒ Object
Unique instance identifier.
-
#instance_name ⇒ Object
Instance name (e.g., 'My University Canvas').
-
#product ⇒ Object
Product family code (e.g., canvas, moodle, schoology).
-
#version ⇒ Object
Platform version string.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LtiConfiguration1p3BaseTool
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LtiConfiguration1p3BaseTool
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::LtiConfiguration1p3BaseTool` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::LtiConfiguration1p3BaseTool`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'product') self.product = attributes[:'product'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'instance_name') self.instance_name = attributes[:'instance_name'] end if attributes.key?(:'instance_guid') self.instance_guid = attributes[:'instance_guid'] end if attributes.key?(:'instance_contact') self.instance_contact = attributes[:'instance_contact'] end if attributes.key?(:'instance_domain') self.instance_domain = attributes[:'instance_domain'] end end |
Instance Attribute Details
#instance_contact ⇒ Object
Contact email or handle for the instance
32 33 34 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 32 def instance_contact @instance_contact end |
#instance_domain ⇒ Object
Instance root domain
35 36 37 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 35 def instance_domain @instance_domain end |
#instance_guid ⇒ Object
Unique instance identifier
29 30 31 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 29 def instance_guid @instance_guid end |
#instance_name ⇒ Object
Instance name (e.g., 'My University Canvas')
26 27 28 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 26 def instance_name @instance_name end |
#product ⇒ Object
Product family code (e.g., canvas, moodle, schoology)
20 21 22 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 20 def product @product end |
#version ⇒ Object
Platform version string
23 24 25 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 23 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 38 def self.attribute_map { :'product' => :'product', :'version' => :'version', :'instance_name' => :'instanceName', :'instance_guid' => :'instanceGuid', :'instance_contact' => :'instanceContact', :'instance_domain' => :'instanceDomain' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 161 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
72 73 74 75 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 72 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 60 def self.openapi_types { :'product' => :'String', :'version' => :'String', :'instance_name' => :'String', :'instance_guid' => :'String', :'instance_contact' => :'String', :'instance_domain' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
135 136 137 138 139 140 141 142 143 144 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 135 def ==(o) return true if self.equal?(o) self.class == o.class && product == o.product && version == o.version && instance_name == o.instance_name && instance_guid == o.instance_guid && instance_contact == o.instance_contact && instance_domain == o.instance_domain end |
#eql?(o) ⇒ Boolean
148 149 150 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 148 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
154 155 156 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 154 def hash [product, version, instance_name, instance_guid, instance_contact, instance_domain].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 183 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
128 129 130 131 |
# File 'lib/flat_api/models/lti_configuration1p3_base_tool.rb', line 128 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |