Class: FlatApi::ResourceCollaborator
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ResourceCollaborator
- Defined in:
- lib/flat_api/models/resource_collaborator.rb
Overview
A collaborator of a score. The userEmail and group are only available if the requesting user is a collaborator of the related score (in this case these permissions will eventualy not be listed and exposed publicly).
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#acl_admin ⇒ Object
Trueif the current user can manage the current document (i.e. share, delete) If this is a right of a Collection, the capabilities of the associated user can be lower than this permission, check out thecapabilitiesproperty as the end-user to have the complete possibilities with the collection. -
#acl_read ⇒ Object
Trueif the current user can read the current document. -
#acl_write ⇒ Object
Trueif the current user can modify the current document. -
#collaborator_type ⇒ Object
The type of the collaborator for the resource.
-
#collection ⇒ Object
If this object is a permission of a collection, this property will contain the unique identifier of the collection.
-
#date ⇒ Object
The date when the permission was added.
-
#group ⇒ Object
Returns the value of attribute group.
-
#id ⇒ Object
The unique identifier of the permission.
-
#invited ⇒ Object
If this property is
true, this is still a pending invitation. -
#is_collaborator ⇒ Object
Trueif the current user is a collaborator of the current document (direct or via group). -
#score ⇒ Object
If this object is a permission of a score, this property will contain the unique identifier of the score.
-
#user ⇒ Object
Returns the value of attribute user.
-
#user_email ⇒ Object
If the collaborator is not a user of Flat yet, this field will contain their email.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceCollaborator
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ResourceCollaborator
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ResourceCollaborator` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ResourceCollaborator`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'acl_read') self.acl_read = attributes[:'acl_read'] else self.acl_read = false end if attributes.key?(:'acl_write') self.acl_write = attributes[:'acl_write'] else self.acl_write = false end if attributes.key?(:'acl_admin') self.acl_admin = attributes[:'acl_admin'] else self.acl_admin = false end if attributes.key?(:'is_collaborator') self.is_collaborator = attributes[:'is_collaborator'] else self.is_collaborator = false end if attributes.key?(:'collaborator_type') self.collaborator_type = attributes[:'collaborator_type'] end if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'date') self.date = attributes[:'date'] end if attributes.key?(:'score') self.score = attributes[:'score'] end if attributes.key?(:'collection') self.collection = attributes[:'collection'] end if attributes.key?(:'user') self.user = attributes[:'user'] end if attributes.key?(:'group') self.group = attributes[:'group'] end if attributes.key?(:'user_email') self.user_email = attributes[:'user_email'] end if attributes.key?(:'invited') self.invited = attributes[:'invited'] end end |
Instance Attribute Details
#acl_admin ⇒ Object
True if the current user can manage the current document (i.e. share, delete) If this is a right of a Collection, the capabilities of the associated user can be lower than this permission, check out the capabilities property as the end-user to have the complete possibilities with the collection.
26 27 28 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 26 def acl_admin @acl_admin end |
#acl_read ⇒ Object
True if the current user can read the current document
20 21 22 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 20 def acl_read @acl_read end |
#acl_write ⇒ Object
True if the current user can modify the current document. If this is a right of a Collection, the capabilities of the associated user can be lower than this permission, check out the capabilities property as the end-user to have the complete possibilities with the collection.
23 24 25 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 23 def acl_write @acl_write end |
#collaborator_type ⇒ Object
The type of the collaborator for the resource
32 33 34 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 32 def collaborator_type @collaborator_type end |
#collection ⇒ Object
If this object is a permission of a collection, this property will contain the unique identifier of the collection
44 45 46 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 44 def collection @collection end |
#date ⇒ Object
The date when the permission was added
38 39 40 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 38 def date @date end |
#group ⇒ Object
Returns the value of attribute group.
48 49 50 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 48 def group @group end |
#id ⇒ Object
The unique identifier of the permission
35 36 37 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 35 def id @id end |
#invited ⇒ Object
If this property is true, this is still a pending invitation
54 55 56 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 54 def invited @invited end |
#is_collaborator ⇒ Object
True if the current user is a collaborator of the current document (direct or via group).
29 30 31 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 29 def is_collaborator @is_collaborator end |
#score ⇒ Object
If this object is a permission of a score, this property will contain the unique identifier of the score
41 42 43 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 41 def score @score end |
#user ⇒ Object
Returns the value of attribute user.
46 47 48 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 46 def user @user end |
#user_email ⇒ Object
If the collaborator is not a user of Flat yet, this field will contain their email.
51 52 53 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 51 def user_email @user_email end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
98 99 100 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 98 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
103 104 105 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 103 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 79 def self.attribute_map { :'acl_read' => :'aclRead', :'acl_write' => :'aclWrite', :'acl_admin' => :'aclAdmin', :'is_collaborator' => :'isCollaborator', :'collaborator_type' => :'collaboratorType', :'id' => :'id', :'date' => :'date', :'score' => :'score', :'collection' => :'collection', :'user' => :'user', :'group' => :'group', :'user_email' => :'userEmail', :'invited' => :'invited' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 323 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
133 134 135 136 137 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 133 def self.openapi_all_of [ :'ResourceRights' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
127 128 129 130 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 127 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 108 def self.openapi_types { :'acl_read' => :'Boolean', :'acl_write' => :'Boolean', :'acl_admin' => :'Boolean', :'is_collaborator' => :'Boolean', :'collaborator_type' => :'String', :'id' => :'String', :'date' => :'Time', :'score' => :'String', :'collection' => :'String', :'user' => :'UserPublic', :'group' => :'Group', :'user_email' => :'String', :'invited' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 290 def ==(o) return true if self.equal?(o) self.class == o.class && acl_read == o.acl_read && acl_write == o.acl_write && acl_admin == o.acl_admin && is_collaborator == o.is_collaborator && collaborator_type == o.collaborator_type && id == o.id && date == o.date && score == o.score && collection == o.collection && user == o.user && group == o.group && user_email == o.user_email && invited == o.invited end |
#eql?(o) ⇒ Boolean
310 311 312 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 310 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
316 317 318 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 316 def hash [acl_read, acl_write, acl_admin, is_collaborator, collaborator_type, id, date, score, collection, user, group, user_email, invited].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 218 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @acl_read.nil? invalid_properties.push('invalid value for "acl_read", acl_read cannot be nil.') end if @acl_write.nil? invalid_properties.push('invalid value for "acl_write", acl_write cannot be nil.') end if @acl_admin.nil? invalid_properties.push('invalid value for "acl_admin", acl_admin cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 345 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
238 239 240 241 242 243 244 245 246 |
# File 'lib/flat_api/models/resource_collaborator.rb', line 238 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @acl_read.nil? return false if @acl_write.nil? return false if @acl_admin.nil? collaborator_type_validator = EnumAttributeValidator.new('String', ["owner", "user", "group"]) return false unless collaborator_type_validator.valid?(@collaborator_type) true end |