Class: FlatApi::ResourceCollaboratorCreation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ResourceCollaboratorCreation
- Defined in:
- lib/flat_api/models/resource_collaborator_creation.rb
Overview
Add a collaborator to a resource.
Instance Attribute Summary collapse
-
#acl_admin ⇒ Object
Trueif the related user can can manage the current document, i.e. -
#acl_read ⇒ Object
Trueif the related user can read the score. -
#acl_write ⇒ Object
Trueif the related user can modify the score. -
#group ⇒ Object
The unique identifier of a Flat group.
-
#user ⇒ Object
The unique identifier of a Flat user.
-
#user_email ⇒ Object
Fill this field to invite an individual user by email.
-
#user_token ⇒ Object
Token received in an invitation to join the score.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceCollaboratorCreation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ResourceCollaboratorCreation
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ResourceCollaboratorCreation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ResourceCollaboratorCreation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'user') self.user = attributes[:'user'] end if attributes.key?(:'group') self.group = attributes[:'group'] end if attributes.key?(:'user_email') self.user_email = attributes[:'user_email'] end if attributes.key?(:'user_token') self.user_token = attributes[:'user_token'] end if attributes.key?(:'acl_read') self.acl_read = attributes[:'acl_read'] else self.acl_read = true end if attributes.key?(:'acl_write') self.acl_write = attributes[:'acl_write'] else self.acl_write = false end if attributes.key?(:'acl_admin') self.acl_admin = attributes[:'acl_admin'] else self.acl_admin = false end end |
Instance Attribute Details
#acl_admin ⇒ Object
True if the related user can can manage the current document, i.e. changing the document permissions and deleting the document
38 39 40 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 38 def acl_admin @acl_admin end |
#acl_read ⇒ Object
True if the related user can read the score. (probably true if the user has a permission on the document).
32 33 34 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 32 def acl_read @acl_read end |
#acl_write ⇒ Object
True if the related user can modify the score.
35 36 37 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 35 def acl_write @acl_write end |
#group ⇒ Object
The unique identifier of a Flat group
23 24 25 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 23 def group @group end |
#user ⇒ Object
The unique identifier of a Flat user
20 21 22 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 20 def user @user end |
#user_email ⇒ Object
Fill this field to invite an individual user by email.
26 27 28 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 26 def user_email @user_email end |
#user_token ⇒ Object
Token received in an invitation to join the score.
29 30 31 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 29 def user_token @user_token end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 41 def self.attribute_map { :'user' => :'user', :'group' => :'group', :'user_email' => :'userEmail', :'user_token' => :'userToken', :'acl_read' => :'aclRead', :'acl_write' => :'aclWrite', :'acl_admin' => :'aclAdmin' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 177 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 64 def self.openapi_types { :'user' => :'String', :'group' => :'String', :'user_email' => :'String', :'user_token' => :'String', :'acl_read' => :'Boolean', :'acl_write' => :'Boolean', :'acl_admin' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && user == o.user && group == o.group && user_email == o.user_email && user_token == o.user_token && acl_read == o.acl_read && acl_write == o.acl_write && acl_admin == o.acl_admin end |
#eql?(o) ⇒ Boolean
164 165 166 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 164 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 170 def hash [user, group, user_email, user_token, acl_read, acl_write, acl_admin].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 |
# File 'lib/flat_api/models/resource_collaborator_creation.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |