Class: FlatApi::ResourceRights
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ResourceRights
- Defined in:
- lib/flat_api/models/resource_rights.rb
Overview
The rights of the current user on a score or collection
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#acl_admin ⇒ Object
Trueif the current user can manage the current document (i.e. share, delete) If this is a right of a Collection, the capabilities of the associated user can be lower than this permission, check out thecapabilitiesproperty as the end-user to have the complete possibilities with the collection. -
#acl_read ⇒ Object
Trueif the current user can read the current document. -
#acl_write ⇒ Object
Trueif the current user can modify the current document. -
#collaborator_type ⇒ Object
The type of the collaborator for the resource.
-
#is_collaborator ⇒ Object
Trueif the current user is a collaborator of the current document (direct or via group).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ResourceRights
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ResourceRights
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/flat_api/models/resource_rights.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ResourceRights` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ResourceRights`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'acl_read') self.acl_read = attributes[:'acl_read'] else self.acl_read = false end if attributes.key?(:'acl_write') self.acl_write = attributes[:'acl_write'] else self.acl_write = false end if attributes.key?(:'acl_admin') self.acl_admin = attributes[:'acl_admin'] else self.acl_admin = false end if attributes.key?(:'is_collaborator') self.is_collaborator = attributes[:'is_collaborator'] else self.is_collaborator = false end if attributes.key?(:'collaborator_type') self.collaborator_type = attributes[:'collaborator_type'] end end |
Instance Attribute Details
#acl_admin ⇒ Object
True if the current user can manage the current document (i.e. share, delete) If this is a right of a Collection, the capabilities of the associated user can be lower than this permission, check out the capabilities property as the end-user to have the complete possibilities with the collection.
26 27 28 |
# File 'lib/flat_api/models/resource_rights.rb', line 26 def acl_admin @acl_admin end |
#acl_read ⇒ Object
True if the current user can read the current document
20 21 22 |
# File 'lib/flat_api/models/resource_rights.rb', line 20 def acl_read @acl_read end |
#acl_write ⇒ Object
True if the current user can modify the current document. If this is a right of a Collection, the capabilities of the associated user can be lower than this permission, check out the capabilities property as the end-user to have the complete possibilities with the collection.
23 24 25 |
# File 'lib/flat_api/models/resource_rights.rb', line 23 def acl_write @acl_write end |
#collaborator_type ⇒ Object
The type of the collaborator for the resource
32 33 34 |
# File 'lib/flat_api/models/resource_rights.rb', line 32 def collaborator_type @collaborator_type end |
#is_collaborator ⇒ Object
True if the current user is a collaborator of the current document (direct or via group).
29 30 31 |
# File 'lib/flat_api/models/resource_rights.rb', line 29 def is_collaborator @is_collaborator end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/flat_api/models/resource_rights.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/flat_api/models/resource_rights.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/flat_api/models/resource_rights.rb', line 57 def self.attribute_map { :'acl_read' => :'aclRead', :'acl_write' => :'aclWrite', :'acl_admin' => :'aclAdmin', :'is_collaborator' => :'isCollaborator', :'collaborator_type' => :'collaboratorType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/flat_api/models/resource_rights.rb', line 238 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/flat_api/models/resource_rights.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/flat_api/models/resource_rights.rb', line 78 def self.openapi_types { :'acl_read' => :'Boolean', :'acl_write' => :'Boolean', :'acl_admin' => :'Boolean', :'is_collaborator' => :'Boolean', :'collaborator_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 |
# File 'lib/flat_api/models/resource_rights.rb', line 213 def ==(o) return true if self.equal?(o) self.class == o.class && acl_read == o.acl_read && acl_write == o.acl_write && acl_admin == o.acl_admin && is_collaborator == o.is_collaborator && collaborator_type == o.collaborator_type end |
#eql?(o) ⇒ Boolean
225 226 227 |
# File 'lib/flat_api/models/resource_rights.rb', line 225 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/flat_api/models/resource_rights.rb', line 231 def hash [acl_read, acl_write, acl_admin, is_collaborator, collaborator_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/flat_api/models/resource_rights.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @acl_read.nil? invalid_properties.push('invalid value for "acl_read", acl_read cannot be nil.') end if @acl_write.nil? invalid_properties.push('invalid value for "acl_write", acl_write cannot be nil.') end if @acl_admin.nil? invalid_properties.push('invalid value for "acl_admin", acl_admin cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/flat_api/models/resource_rights.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
161 162 163 164 165 166 167 168 169 |
# File 'lib/flat_api/models/resource_rights.rb', line 161 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @acl_read.nil? return false if @acl_write.nil? return false if @acl_admin.nil? collaborator_type_validator = EnumAttributeValidator.new('String', ["owner", "user", "group"]) return false unless collaborator_type_validator.valid?(@collaborator_type) true end |