Class: FlatApi::ScoreCommentContext
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ScoreCommentContext
- Defined in:
- lib/flat_api/models/score_comment_context.rb
Overview
The context of the comment (for inline/contextualized comments). A context will include all the information related to the location of the comment (i.e. score parts, range of measure, time position).
Instance Attribute Summary collapse
-
#measure_uuids ⇒ Object
The list of measure UUIds.
-
#part_uuid ⇒ Object
The unique identifier (UUID) of the score part.
-
#staff_idx ⇒ Object
(Deprecated, use
staffUuid) The identififer of the staff. -
#staff_uuid ⇒ Object
The unique identififer (UUID) of the staff.
-
#start_dpq ⇒ Object
Returns the value of attribute start_dpq.
-
#start_time_pos ⇒ Object
Returns the value of attribute start_time_pos.
-
#stop_dpq ⇒ Object
Returns the value of attribute stop_dpq.
-
#stop_time_pos ⇒ Object
Returns the value of attribute stop_time_pos.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScoreCommentContext
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScoreCommentContext
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/flat_api/models/score_comment_context.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreCommentContext` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreCommentContext`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'part_uuid') self.part_uuid = attributes[:'part_uuid'] else self.part_uuid = nil end if attributes.key?(:'staff_idx') self.staff_idx = attributes[:'staff_idx'] end if attributes.key?(:'staff_uuid') self.staff_uuid = attributes[:'staff_uuid'] end if attributes.key?(:'measure_uuids') if (value = attributes[:'measure_uuids']).is_a?(Array) self.measure_uuids = value end else self.measure_uuids = nil end if attributes.key?(:'start_time_pos') self.start_time_pos = attributes[:'start_time_pos'] else self.start_time_pos = nil end if attributes.key?(:'stop_time_pos') self.stop_time_pos = attributes[:'stop_time_pos'] else self.stop_time_pos = nil end if attributes.key?(:'start_dpq') self.start_dpq = attributes[:'start_dpq'] else self.start_dpq = nil end if attributes.key?(:'stop_dpq') self.stop_dpq = attributes[:'stop_dpq'] else self.stop_dpq = nil end end |
Instance Attribute Details
#measure_uuids ⇒ Object
The list of measure UUIds
29 30 31 |
# File 'lib/flat_api/models/score_comment_context.rb', line 29 def measure_uuids @measure_uuids end |
#part_uuid ⇒ Object
The unique identifier (UUID) of the score part
20 21 22 |
# File 'lib/flat_api/models/score_comment_context.rb', line 20 def part_uuid @part_uuid end |
#staff_idx ⇒ Object
(Deprecated, use staffUuid) The identififer of the staff
23 24 25 |
# File 'lib/flat_api/models/score_comment_context.rb', line 23 def staff_idx @staff_idx end |
#staff_uuid ⇒ Object
The unique identififer (UUID) of the staff
26 27 28 |
# File 'lib/flat_api/models/score_comment_context.rb', line 26 def staff_uuid @staff_uuid end |
#start_dpq ⇒ Object
Returns the value of attribute start_dpq.
35 36 37 |
# File 'lib/flat_api/models/score_comment_context.rb', line 35 def start_dpq @start_dpq end |
#start_time_pos ⇒ Object
Returns the value of attribute start_time_pos.
31 32 33 |
# File 'lib/flat_api/models/score_comment_context.rb', line 31 def start_time_pos @start_time_pos end |
#stop_dpq ⇒ Object
Returns the value of attribute stop_dpq.
37 38 39 |
# File 'lib/flat_api/models/score_comment_context.rb', line 37 def stop_dpq @stop_dpq end |
#stop_time_pos ⇒ Object
Returns the value of attribute stop_time_pos.
33 34 35 |
# File 'lib/flat_api/models/score_comment_context.rb', line 33 def stop_time_pos @stop_time_pos end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/flat_api/models/score_comment_context.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/flat_api/models/score_comment_context.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/flat_api/models/score_comment_context.rb', line 40 def self.attribute_map { :'part_uuid' => :'partUuid', :'staff_idx' => :'staffIdx', :'staff_uuid' => :'staffUuid', :'measure_uuids' => :'measureUuids', :'start_time_pos' => :'startTimePos', :'stop_time_pos' => :'stopTimePos', :'start_dpq' => :'startDpq', :'stop_dpq' => :'stopDpq' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/flat_api/models/score_comment_context.rb', line 281 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/flat_api/models/score_comment_context.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/flat_api/models/score_comment_context.rb', line 64 def self.openapi_types { :'part_uuid' => :'String', :'staff_idx' => :'Float', :'staff_uuid' => :'String', :'measure_uuids' => :'Array<String>', :'start_time_pos' => :'Float', :'stop_time_pos' => :'Float', :'start_dpq' => :'Float', :'stop_dpq' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/flat_api/models/score_comment_context.rb', line 253 def ==(o) return true if self.equal?(o) self.class == o.class && part_uuid == o.part_uuid && staff_idx == o.staff_idx && staff_uuid == o.staff_uuid && measure_uuids == o.measure_uuids && start_time_pos == o.start_time_pos && stop_time_pos == o.stop_time_pos && start_dpq == o.start_dpq && stop_dpq == o.stop_dpq end |
#eql?(o) ⇒ Boolean
268 269 270 |
# File 'lib/flat_api/models/score_comment_context.rb', line 268 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
274 275 276 |
# File 'lib/flat_api/models/score_comment_context.rb', line 274 def hash [part_uuid, staff_idx, staff_uuid, measure_uuids, start_time_pos, stop_time_pos, start_dpq, stop_dpq].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/flat_api/models/score_comment_context.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @part_uuid.nil? invalid_properties.push('invalid value for "part_uuid", part_uuid cannot be nil.') end if @measure_uuids.nil? invalid_properties.push('invalid value for "measure_uuids", measure_uuids cannot be nil.') end if @start_time_pos.nil? invalid_properties.push('invalid value for "start_time_pos", start_time_pos cannot be nil.') end if @stop_time_pos.nil? invalid_properties.push('invalid value for "stop_time_pos", stop_time_pos cannot be nil.') end if @start_dpq.nil? invalid_properties.push('invalid value for "start_dpq", start_dpq cannot be nil.') end if @stop_dpq.nil? invalid_properties.push('invalid value for "stop_dpq", stop_dpq cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/flat_api/models/score_comment_context.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/flat_api/models/score_comment_context.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @part_uuid.nil? return false if @measure_uuids.nil? return false if @start_time_pos.nil? return false if @stop_time_pos.nil? return false if @start_dpq.nil? return false if @stop_dpq.nil? true end |