Class: FlatApi::ScoreCreationFileImport
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ScoreCreationFileImport
- Defined in:
- lib/flat_api/models/score_creation_file_import.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#collection ⇒ Object
Unique identifier of a collection where the score will be created.
-
#data ⇒ Object
The data of the score file.
-
#data_encoding ⇒ Object
The optional encoding of the score data.
-
#filename ⇒ Object
If this is an imported file, its filename.
-
#google_drive_folder ⇒ Object
If the user uses Google Drive and this properties is specified, the file will be created in this directory.
-
#privacy ⇒ Object
Returns the value of attribute privacy.
-
#supports_tasks ⇒ Object
Set this to
trueif the client supports asynchronous task flows. -
#title ⇒ Object
The title of the new score.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScoreCreationFileImport
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScoreCreationFileImport
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreCreationFileImport` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreCreationFileImport`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'privacy') self.privacy = attributes[:'privacy'] else self.privacy = 'private' end if attributes.key?(:'collection') self.collection = attributes[:'collection'] end if attributes.key?(:'google_drive_folder') self.google_drive_folder = attributes[:'google_drive_folder'] end if attributes.key?(:'filename') self.filename = attributes[:'filename'] end if attributes.key?(:'data') self.data = attributes[:'data'] else self.data = nil end if attributes.key?(:'data_encoding') self.data_encoding = attributes[:'data_encoding'] end if attributes.key?(:'supports_tasks') self.supports_tasks = attributes[:'supports_tasks'] end end |
Instance Attribute Details
#collection ⇒ Object
Unique identifier of a collection where the score will be created. If no collection identifier is provided, the score will not be added to any collection and will only be visible in the allScores virtual collection.
24 25 26 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 24 def collection @collection end |
#data ⇒ Object
The data of the score file. See the POST /scores endpoint description for the full list of supported formats. Binary payloads (e.g. compressed MusicXML, MIDI, Guitar Pro) can be encoded in Base64, in this case the dataEncoding property must match the encoding used for the API request.
33 34 35 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 33 def data @data end |
#data_encoding ⇒ Object
The optional encoding of the score data. This property must match the encoding used for the data property.
36 37 38 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 36 def data_encoding @data_encoding end |
#filename ⇒ Object
If this is an imported file, its filename
30 31 32 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 30 def filename @filename end |
#google_drive_folder ⇒ Object
If the user uses Google Drive and this properties is specified, the file will be created in this directory. The currently user creating the file must be granted to write in this directory.
27 28 29 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 27 def google_drive_folder @google_drive_folder end |
#privacy ⇒ Object
Returns the value of attribute privacy.
21 22 23 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 21 def privacy @privacy end |
#supports_tasks ⇒ Object
Set this to true if the client supports asynchronous task flows. When importing a score that requires OMR processing (a PDF or a page image), the API will return a 202 Accepted response along with a task reference. The client can then check the task status using the endpoint GET /v2/tasks/{task}.
39 40 41 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 39 def supports_tasks @supports_tasks end |
#title ⇒ Object
The title of the new score. If the title is too long, the API may trim this one. If this title is not specified, the API will try to (in this order): - Use the title contained in the file (e.g. movement-title or credit-words for MusicXML files). - Use the name of the file for files from a specified source (e.g. Google Drive) or the one in the filename property - Set a default title (e.g. "New Music Score")
19 20 21 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 19 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 64 def self.attribute_map { :'title' => :'title', :'privacy' => :'privacy', :'collection' => :'collection', :'google_drive_folder' => :'googleDriveFolder', :'filename' => :'filename', :'data' => :'data', :'data_encoding' => :'dataEncoding', :'supports_tasks' => :'supportsTasks' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 239 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
108 109 110 111 112 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 108 def self.openapi_all_of [ :'ScoreCreationCommon' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 102 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 88 def self.openapi_types { :'title' => :'String', :'privacy' => :'ScorePrivacy', :'collection' => :'String', :'google_drive_folder' => :'String', :'filename' => :'String', :'data' => :'String', :'data_encoding' => :'String', :'supports_tasks' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 211 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && privacy == o.privacy && collection == o.collection && google_drive_folder == o.google_drive_folder && filename == o.filename && data == o.data && data_encoding == o.data_encoding && supports_tasks == o.supports_tasks end |
#eql?(o) ⇒ Boolean
226 227 228 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 226 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
232 233 234 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 232 def hash [title, privacy, collection, google_drive_folder, filename, data, data_encoding, supports_tasks].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @data.nil? invalid_properties.push('invalid value for "data", data cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 261 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
181 182 183 184 185 186 187 |
# File 'lib/flat_api/models/score_creation_file_import.rb', line 181 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @data.nil? data_encoding_validator = EnumAttributeValidator.new('String', ["base64"]) return false unless data_encoding_validator.valid?(@data_encoding) true end |