Method: FlatApi::ScoreDetails#instruments
- Defined in:
- lib/flat_api/models/score_details.rb
#instruments ⇒ Object
An array of the instrument identifiers used in the last version of the score. This is mainly used to display a list of the instruments in the Flat’s UI or instruments icons. The format of the strings is ‘instrument-group.instrument-id`.
96 97 98 |
# File 'lib/flat_api/models/score_details.rb', line 96 def instruments @instruments end |