Class: FlatApi::ScoreModification
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ScoreModification
- Defined in:
- lib/flat_api/models/score_modification.rb
Overview
Edit the score metadata
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#arranger ⇒ Object
The arranger of the score.
-
#composer ⇒ Object
The composer of the score.
-
#creation_type ⇒ Object
Returns the value of attribute creation_type.
-
#description ⇒ Object
Description of the creation.
-
#license ⇒ Object
Returns the value of attribute license.
-
#license_text ⇒ Object
The rights info written on the score.
-
#lyricist ⇒ Object
The lyricist of the score.
-
#privacy ⇒ Object
Returns the value of attribute privacy.
-
#sharing_key ⇒ Object
When using the
privacymodeprivateLink, this property can be used to set a custom sharing key, otherwise a new key will be generated. -
#subtitle ⇒ Object
The subtitle of the score.
-
#tags ⇒ Object
Tags describing the score.
-
#title ⇒ Object
The title of the score.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScoreModification
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScoreModification
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/flat_api/models/score_modification.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreModification` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreModification`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'subtitle') self.subtitle = attributes[:'subtitle'] end if attributes.key?(:'composer') self.composer = attributes[:'composer'] end if attributes.key?(:'lyricist') self.lyricist = attributes[:'lyricist'] end if attributes.key?(:'arranger') self.arranger = attributes[:'arranger'] end if attributes.key?(:'privacy') self.privacy = attributes[:'privacy'] else self.privacy = 'private' end if attributes.key?(:'sharing_key') self.sharing_key = attributes[:'sharing_key'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'creation_type') self.creation_type = attributes[:'creation_type'] end if attributes.key?(:'license') self.license = attributes[:'license'] end if attributes.key?(:'license_text') self.license_text = attributes[:'license_text'] end end |
Instance Attribute Details
#arranger ⇒ Object
The arranger of the score
32 33 34 |
# File 'lib/flat_api/models/score_modification.rb', line 32 def arranger @arranger end |
#composer ⇒ Object
The composer of the score
26 27 28 |
# File 'lib/flat_api/models/score_modification.rb', line 26 def composer @composer end |
#creation_type ⇒ Object
Returns the value of attribute creation_type.
45 46 47 |
# File 'lib/flat_api/models/score_modification.rb', line 45 def creation_type @creation_type end |
#description ⇒ Object
Description of the creation
40 41 42 |
# File 'lib/flat_api/models/score_modification.rb', line 40 def description @description end |
#license ⇒ Object
Returns the value of attribute license.
47 48 49 |
# File 'lib/flat_api/models/score_modification.rb', line 47 def license @license end |
#license_text ⇒ Object
The rights info written on the score
50 51 52 |
# File 'lib/flat_api/models/score_modification.rb', line 50 def license_text @license_text end |
#lyricist ⇒ Object
The lyricist of the score
29 30 31 |
# File 'lib/flat_api/models/score_modification.rb', line 29 def lyricist @lyricist end |
#privacy ⇒ Object
Returns the value of attribute privacy.
34 35 36 |
# File 'lib/flat_api/models/score_modification.rb', line 34 def privacy @privacy end |
#sharing_key ⇒ Object
When using the privacy mode privateLink, this property can be used to set a custom sharing key, otherwise a new key will be generated.
37 38 39 |
# File 'lib/flat_api/models/score_modification.rb', line 37 def sharing_key @sharing_key end |
#subtitle ⇒ Object
The subtitle of the score
23 24 25 |
# File 'lib/flat_api/models/score_modification.rb', line 23 def subtitle @subtitle end |
#tags ⇒ Object
Tags describing the score
43 44 45 |
# File 'lib/flat_api/models/score_modification.rb', line 43 def @tags end |
#title ⇒ Object
The title of the score
20 21 22 |
# File 'lib/flat_api/models/score_modification.rb', line 20 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
93 94 95 |
# File 'lib/flat_api/models/score_modification.rb', line 93 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/flat_api/models/score_modification.rb', line 98 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/flat_api/models/score_modification.rb', line 75 def self.attribute_map { :'title' => :'title', :'subtitle' => :'subtitle', :'composer' => :'composer', :'lyricist' => :'lyricist', :'arranger' => :'arranger', :'privacy' => :'privacy', :'sharing_key' => :'sharingKey', :'description' => :'description', :'tags' => :'tags', :'creation_type' => :'creationType', :'license' => :'license', :'license_text' => :'licenseText' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 |
# File 'lib/flat_api/models/score_modification.rb', line 288 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/flat_api/models/score_modification.rb', line 121 def self.openapi_nullable Set.new([ :'subtitle', :'composer', :'lyricist', :'arranger', :'description', :'creation_type', :'license', :'license_text' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/flat_api/models/score_modification.rb', line 103 def self.openapi_types { :'title' => :'String', :'subtitle' => :'String', :'composer' => :'String', :'lyricist' => :'String', :'arranger' => :'String', :'privacy' => :'ScorePrivacy', :'sharing_key' => :'String', :'description' => :'String', :'tags' => :'Array<String>', :'creation_type' => :'ScoreCreationType', :'license' => :'ScoreLicense', :'license_text' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/flat_api/models/score_modification.rb', line 256 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && subtitle == o.subtitle && composer == o.composer && lyricist == o.lyricist && arranger == o.arranger && privacy == o.privacy && sharing_key == o.sharing_key && description == o.description && == o. && creation_type == o.creation_type && license == o.license && license_text == o.license_text end |
#eql?(o) ⇒ Boolean
275 276 277 |
# File 'lib/flat_api/models/score_modification.rb', line 275 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
281 282 283 |
# File 'lib/flat_api/models/score_modification.rb', line 281 def hash [title, subtitle, composer, lyricist, arranger, privacy, sharing_key, description, , creation_type, license, license_text].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/flat_api/models/score_modification.rb', line 205 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^[a-f0-9]{128}$/) if !@sharing_key.nil? && @sharing_key !~ pattern invalid_properties.push("invalid value for \"sharing_key\", must conform to the pattern #{pattern}.") end if !@description.nil? && @description.to_s.length > 2000 invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 2000.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/flat_api/models/score_modification.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
222 223 224 225 226 227 |
# File 'lib/flat_api/models/score_modification.rb', line 222 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@sharing_key.nil? && @sharing_key !~ Regexp.new(/^[a-f0-9]{128}$/) return false if !@description.nil? && @description.to_s.length > 2000 true end |