Class: FlatApi::ScoreTrack
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::ScoreTrack
- Defined in:
- lib/flat_api/models/score_track.rb
Overview
An audio track for a score
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#creation_date ⇒ Object
The creation date of the track.
-
#creator ⇒ Object
The unique identifier of the track creator.
-
#default ⇒ Object
True if the track should be used as default audio source.
-
#id ⇒ Object
The unique identifier of the score track.
-
#media_id ⇒ Object
The unique identifier of the track when hosted on an external service.
-
#modification_date ⇒ Object
The modification date of the track.
-
#purpose ⇒ Object
Returns the value of attribute purpose.
-
#score ⇒ Object
The unique identifier of the score.
-
#state ⇒ Object
Returns the value of attribute state.
-
#synchronization_points ⇒ Object
Returns the value of attribute synchronization_points.
-
#title ⇒ Object
Title of the track.
-
#type ⇒ Object
Returns the value of attribute type.
-
#url ⇒ Object
The URL of the track.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ScoreTrack
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ScoreTrack
Initializes the object
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/flat_api/models/score_track.rb', line 132 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::ScoreTrack` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::ScoreTrack`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'score') self.score = attributes[:'score'] end if attributes.key?(:'creator') self.creator = attributes[:'creator'] else self.creator = nil end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] else self.creation_date = nil end if attributes.key?(:'modification_date') self.modification_date = attributes[:'modification_date'] else self.modification_date = nil end if attributes.key?(:'default') self.default = attributes[:'default'] else self.default = nil end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = 'draft' end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'purpose') self.purpose = attributes[:'purpose'] else self.purpose = 'common' end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'media_id') self.media_id = attributes[:'media_id'] end if attributes.key?(:'synchronization_points') if (value = attributes[:'synchronization_points']).is_a?(Array) self.synchronization_points = value end end end |
Instance Attribute Details
#creation_date ⇒ Object
The creation date of the track
32 33 34 |
# File 'lib/flat_api/models/score_track.rb', line 32 def creation_date @creation_date end |
#creator ⇒ Object
The unique identifier of the track creator
29 30 31 |
# File 'lib/flat_api/models/score_track.rb', line 29 def creator @creator end |
#default ⇒ Object
True if the track should be used as default audio source
38 39 40 |
# File 'lib/flat_api/models/score_track.rb', line 38 def default @default end |
#id ⇒ Object
The unique identifier of the score track
20 21 22 |
# File 'lib/flat_api/models/score_track.rb', line 20 def id @id end |
#media_id ⇒ Object
The unique identifier of the track when hosted on an external service. For example, if the url is https://www.youtube.com/watch?v=dQw4w9WgXcQ, mediaId will be dQw4w9WgXcQ
50 51 52 |
# File 'lib/flat_api/models/score_track.rb', line 50 def media_id @media_id end |
#modification_date ⇒ Object
The modification date of the track
35 36 37 |
# File 'lib/flat_api/models/score_track.rb', line 35 def modification_date @modification_date end |
#purpose ⇒ Object
Returns the value of attribute purpose.
44 45 46 |
# File 'lib/flat_api/models/score_track.rb', line 44 def purpose @purpose end |
#score ⇒ Object
The unique identifier of the score. Absent for Free Record performance submissions, which are recorded without an attached score.
26 27 28 |
# File 'lib/flat_api/models/score_track.rb', line 26 def score @score end |
#state ⇒ Object
Returns the value of attribute state.
40 41 42 |
# File 'lib/flat_api/models/score_track.rb', line 40 def state @state end |
#synchronization_points ⇒ Object
Returns the value of attribute synchronization_points.
52 53 54 |
# File 'lib/flat_api/models/score_track.rb', line 52 def synchronization_points @synchronization_points end |
#title ⇒ Object
Title of the track
23 24 25 |
# File 'lib/flat_api/models/score_track.rb', line 23 def title @title end |
#type ⇒ Object
Returns the value of attribute type.
42 43 44 |
# File 'lib/flat_api/models/score_track.rb', line 42 def type @type end |
#url ⇒ Object
The URL of the track
47 48 49 |
# File 'lib/flat_api/models/score_track.rb', line 47 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
96 97 98 |
# File 'lib/flat_api/models/score_track.rb', line 96 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
101 102 103 |
# File 'lib/flat_api/models/score_track.rb', line 101 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/flat_api/models/score_track.rb', line 77 def self.attribute_map { :'id' => :'id', :'title' => :'title', :'score' => :'score', :'creator' => :'creator', :'creation_date' => :'creationDate', :'modification_date' => :'modificationDate', :'default' => :'default', :'state' => :'state', :'type' => :'type', :'purpose' => :'purpose', :'url' => :'url', :'media_id' => :'mediaId', :'synchronization_points' => :'synchronizationPoints' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/flat_api/models/score_track.rb', line 387 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
125 126 127 128 |
# File 'lib/flat_api/models/score_track.rb', line 125 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/flat_api/models/score_track.rb', line 106 def self.openapi_types { :'id' => :'String', :'title' => :'String', :'score' => :'String', :'creator' => :'String', :'creation_date' => :'Time', :'modification_date' => :'Time', :'default' => :'Boolean', :'state' => :'ScoreTrackState', :'type' => :'ScoreTrackType', :'purpose' => :'ScoreTrackPurpose', :'url' => :'String', :'media_id' => :'String', :'synchronization_points' => :'Array<ScoreTrackPoint>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/flat_api/models/score_track.rb', line 354 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && title == o.title && score == o.score && creator == o.creator && creation_date == o.creation_date && modification_date == o.modification_date && default == o.default && state == o.state && type == o.type && purpose == o.purpose && url == o.url && media_id == o.media_id && synchronization_points == o.synchronization_points end |
#eql?(o) ⇒ Boolean
374 375 376 |
# File 'lib/flat_api/models/score_track.rb', line 374 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
380 381 382 |
# File 'lib/flat_api/models/score_track.rb', line 380 def hash [id, title, score, creator, creation_date, modification_date, default, state, type, purpose, url, media_id, synchronization_points].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/flat_api/models/score_track.rb', line 219 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @creator.nil? invalid_properties.push('invalid value for "creator", creator cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end if @modification_date.nil? invalid_properties.push('invalid value for "modification_date", modification_date cannot be nil.') end if @default.nil? invalid_properties.push('invalid value for "default", default cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @purpose.nil? invalid_properties.push('invalid value for "purpose", purpose cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/flat_api/models/score_track.rb', line 409 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/flat_api/models/score_track.rb', line 259 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @creator.nil? return false if @creation_date.nil? return false if @modification_date.nil? return false if @default.nil? return false if @state.nil? return false if @type.nil? return false if @purpose.nil? true end |