Class: FlatApi::Task

Inherits:
ApiModelBase show all
Defined in:
lib/flat_api/models/task.rb

Overview

An asynchronous task

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Task

Initializes the object



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/flat_api/models/task.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::Task` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::Task`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end

  if attributes.key?(:'score')
    self.score = attributes[:'score']
  end

  if attributes.key?(:'revision')
    self.revision = attributes[:'revision']
  end

  if attributes.key?(:'progress')
    self.progress = attributes[:'progress']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'modification_date')
    self.modification_date = attributes[:'modification_date']
  end

  if attributes.key?(:'done_date')
    self.done_date = attributes[:'done_date']
  end

  if attributes.key?(:'result')
    self.result = attributes[:'result']
  end

  if attributes.key?(:'error_history')
    if (value = attributes[:'error_history']).is_a?(Array)
      self.error_history = value
    end
  end

  if attributes.key?(:'is_cancellable')
    self.is_cancellable = attributes[:'is_cancellable']
  end

  if attributes.key?(:'children')
    if (value = attributes[:'children']).is_a?(Array)
      self.children = value
    end
  end
end

Instance Attribute Details

#childrenObject

Child tasks for hierarchical task structures (e.g., conversion subtasks)



57
58
59
# File 'lib/flat_api/models/task.rb', line 57

def children
  @children
end

#creation_dateObject

The creation date of the task



40
41
42
# File 'lib/flat_api/models/task.rb', line 40

def creation_date
  @creation_date
end

#done_dateObject

The date when the task has been completed



46
47
48
# File 'lib/flat_api/models/task.rb', line 46

def done_date
  @done_date
end

#error_historyObject

If any errors happened when processing this task, the list of errors identifiers



51
52
53
# File 'lib/flat_api/models/task.rb', line 51

def error_history
  @error_history
end

#formatObject

For files processing, the file format (e.g. mp3, wav)



29
30
31
# File 'lib/flat_api/models/task.rb', line 29

def format
  @format
end

#idObject

Unique identifier of the task



20
21
22
# File 'lib/flat_api/models/task.rb', line 20

def id
  @id
end

#is_cancellableObject

Whether the task can be canceled by the user. Only true when the task is in created state (waiting to be processed).



54
55
56
# File 'lib/flat_api/models/task.rb', line 54

def is_cancellable
  @is_cancellable
end

#modification_dateObject

The last modification date of the task



43
44
45
# File 'lib/flat_api/models/task.rb', line 43

def modification_date
  @modification_date
end

#progressObject

Returns the value of attribute progress.



37
38
39
# File 'lib/flat_api/models/task.rb', line 37

def progress
  @progress
end

#resultObject

Returns the value of attribute result.



48
49
50
# File 'lib/flat_api/models/task.rb', line 48

def result
  @result
end

#revisionObject

The score revision identifier for tasks related to scores



35
36
37
# File 'lib/flat_api/models/task.rb', line 35

def revision
  @revision
end

#scoreObject

The score unique identifier for tasks related to scores



32
33
34
# File 'lib/flat_api/models/task.rb', line 32

def score
  @score
end

#stateObject

State of the Task



26
27
28
# File 'lib/flat_api/models/task.rb', line 26

def state
  @state
end

#typeObject

Type of the task: * audio-export: Exports a score to audio format (MP3, WAV) * score-save: Saves or updates a score document * import-omr: Processes a PDF through OMR (Optical Music Recognition) and imports it as a score



23
24
25
# File 'lib/flat_api/models/task.rb', line 23

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



102
103
104
# File 'lib/flat_api/models/task.rb', line 102

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



107
108
109
# File 'lib/flat_api/models/task.rb', line 107

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/flat_api/models/task.rb', line 82

def self.attribute_map
  {
    :'id' => :'id',
    :'type' => :'type',
    :'state' => :'state',
    :'format' => :'format',
    :'score' => :'score',
    :'revision' => :'revision',
    :'progress' => :'progress',
    :'creation_date' => :'creationDate',
    :'modification_date' => :'modificationDate',
    :'done_date' => :'doneDate',
    :'result' => :'result',
    :'error_history' => :'errorHistory',
    :'is_cancellable' => :'isCancellable',
    :'children' => :'children'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/flat_api/models/task.rb', line 301

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



132
133
134
135
# File 'lib/flat_api/models/task.rb', line 132

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/flat_api/models/task.rb', line 112

def self.openapi_types
  {
    :'id' => :'String',
    :'type' => :'String',
    :'state' => :'String',
    :'format' => :'String',
    :'score' => :'String',
    :'revision' => :'String',
    :'progress' => :'TaskProgress',
    :'creation_date' => :'Time',
    :'modification_date' => :'Time',
    :'done_date' => :'Time',
    :'result' => :'TaskResult',
    :'error_history' => :'Array<String>',
    :'is_cancellable' => :'Boolean',
    :'children' => :'Array<Task>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/flat_api/models/task.rb', line 267

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      type == o.type &&
      state == o.state &&
      format == o.format &&
      score == o.score &&
      revision == o.revision &&
      progress == o.progress &&
      creation_date == o.creation_date &&
      modification_date == o.modification_date &&
      done_date == o.done_date &&
      result == o.result &&
      error_history == o.error_history &&
      is_cancellable == o.is_cancellable &&
      children == o.children
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


288
289
290
# File 'lib/flat_api/models/task.rb', line 288

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



294
295
296
# File 'lib/flat_api/models/task.rb', line 294

def hash
  [id, type, state, format, score, revision, progress, creation_date, modification_date, done_date, result, error_history, is_cancellable, children].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/flat_api/models/task.rb', line 220

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/flat_api/models/task.rb', line 323

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



236
237
238
239
240
241
242
243
# File 'lib/flat_api/models/task.rb', line 236

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["created", "blocked", "doing", "done", "canceled", "error"])
  return false unless state_validator.valid?(@state)
  true
end