Class: FlatApi::UserBasics
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::UserBasics
- Defined in:
- lib/flat_api/models/user_basics.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#badges ⇒ Object
List of badges for the user profile: -
power-staff-composerOfTheMonth-ambassador-challenge. -
#firstname ⇒ Object
Firstname of the user (for education users).
-
#id ⇒ Object
The user unique identifier.
-
#lastname ⇒ Object
Lastname of the user (for education users).
-
#name ⇒ Object
A displayable name for the user (for consumer users).
-
#picture ⇒ Object
The URL of the picture to display.
-
#printable_name ⇒ Object
The name that can be directly printed (name, firstname & lastname, or username).
-
#product ⇒ Object
Returns the value of attribute product.
-
#type ⇒ Object
The type of user account.
-
#username ⇒ Object
The user name (unique for the organization).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserBasics
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserBasics
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/flat_api/models/user_basics.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::UserBasics` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::UserBasics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'product') self.product = attributes[:'product'] else self.product = 'flat' end if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end if attributes.key?(:'printable_name') self.printable_name = attributes[:'printable_name'] end if attributes.key?(:'firstname') self.firstname = attributes[:'firstname'] end if attributes.key?(:'lastname') self.lastname = attributes[:'lastname'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'picture') self.picture = attributes[:'picture'] else self.picture = nil end if attributes.key?(:'badges') if (value = attributes[:'badges']).is_a?(Array) self.badges = value end end end |
Instance Attribute Details
#badges ⇒ Object
List of badges for the user profile: - power - staff - composerOfTheMonth - ambassador - challenge
45 46 47 |
# File 'lib/flat_api/models/user_basics.rb', line 45 def badges @badges end |
#firstname ⇒ Object
Firstname of the user (for education users)
33 34 35 |
# File 'lib/flat_api/models/user_basics.rb', line 33 def firstname @firstname end |
#id ⇒ Object
The user unique identifier
19 20 21 |
# File 'lib/flat_api/models/user_basics.rb', line 19 def id @id end |
#lastname ⇒ Object
Lastname of the user (for education users)
36 37 38 |
# File 'lib/flat_api/models/user_basics.rb', line 36 def lastname @lastname end |
#name ⇒ Object
A displayable name for the user (for consumer users)
39 40 41 |
# File 'lib/flat_api/models/user_basics.rb', line 39 def name @name end |
#picture ⇒ Object
The URL of the picture to display
42 43 44 |
# File 'lib/flat_api/models/user_basics.rb', line 42 def picture @picture end |
#printable_name ⇒ Object
The name that can be directly printed (name, firstname & lastname, or username)
30 31 32 |
# File 'lib/flat_api/models/user_basics.rb', line 30 def printable_name @printable_name end |
#product ⇒ Object
Returns the value of attribute product.
24 25 26 |
# File 'lib/flat_api/models/user_basics.rb', line 24 def product @product end |
#type ⇒ Object
The type of user account
22 23 24 |
# File 'lib/flat_api/models/user_basics.rb', line 22 def type @type end |
#username ⇒ Object
The user name (unique for the organization)
27 28 29 |
# File 'lib/flat_api/models/user_basics.rb', line 27 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/flat_api/models/user_basics.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/flat_api/models/user_basics.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/flat_api/models/user_basics.rb', line 70 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'product' => :'product', :'username' => :'username', :'printable_name' => :'printableName', :'firstname' => :'firstname', :'lastname' => :'lastname', :'name' => :'name', :'picture' => :'picture', :'badges' => :'badges' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/flat_api/models/user_basics.rb', line 296 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 116 |
# File 'lib/flat_api/models/user_basics.rb', line 112 def self.openapi_nullable Set.new([ :'picture', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/flat_api/models/user_basics.rb', line 96 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'product' => :'TutteoProduct', :'username' => :'String', :'printable_name' => :'String', :'firstname' => :'String', :'lastname' => :'String', :'name' => :'String', :'picture' => :'String', :'badges' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/flat_api/models/user_basics.rb', line 266 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && product == o.product && username == o.username && printable_name == o.printable_name && firstname == o.firstname && lastname == o.lastname && name == o.name && picture == o.picture && badges == o.badges end |
#eql?(o) ⇒ Boolean
283 284 285 |
# File 'lib/flat_api/models/user_basics.rb', line 283 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
289 290 291 |
# File 'lib/flat_api/models/user_basics.rb', line 289 def hash [id, type, product, username, printable_name, firstname, lastname, name, picture, badges].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/flat_api/models/user_basics.rb', line 189 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @product.nil? invalid_properties.push('invalid value for "product", product cannot be nil.') end if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/flat_api/models/user_basics.rb', line 318 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 217 218 219 220 221 222 |
# File 'lib/flat_api/models/user_basics.rb', line 213 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["user", "guest"]) return false unless type_validator.valid?(@type) return false if @product.nil? return false if @username.nil? true end |