Class: FlatApi::UserPublicSummary
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FlatApi::UserPublicSummary
- Defined in:
- lib/flat_api/models/user_public_summary.rb
Overview
Public User details summary
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#badges ⇒ Object
List of badges for the user profile: -
power-staff-composerOfTheMonth-ambassador-challenge. -
#class_role ⇒ Object
Returns the value of attribute class_role.
-
#firstname ⇒ Object
Firstname of the user (for education users).
-
#html_url ⇒ Object
Link to user profile (for Indiv. users only).
-
#id ⇒ Object
The user unique identifier.
-
#lastname ⇒ Object
Lastname of the user (for education users).
-
#name ⇒ Object
A displayable name for the user (for consumer users).
-
#organization ⇒ Object
Organization ID (for Edu users only).
-
#organization_role ⇒ Object
Returns the value of attribute organization_role.
-
#picture ⇒ Object
The URL of the picture to display.
-
#printable_name ⇒ Object
The name that can be directly printed (name, firstname & lastname, or username).
-
#product ⇒ Object
Returns the value of attribute product.
-
#type ⇒ Object
The type of user account.
-
#username ⇒ Object
The user name (unique for the organization).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UserPublicSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UserPublicSummary
Initializes the object
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/flat_api/models/user_public_summary.rb', line 145 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FlatApi::UserPublicSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FlatApi::UserPublicSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'product') self.product = attributes[:'product'] else self.product = 'flat' end if attributes.key?(:'username') self.username = attributes[:'username'] else self.username = nil end if attributes.key?(:'printable_name') self.printable_name = attributes[:'printable_name'] end if attributes.key?(:'firstname') self.firstname = attributes[:'firstname'] end if attributes.key?(:'lastname') self.lastname = attributes[:'lastname'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'picture') self.picture = attributes[:'picture'] else self.picture = nil end if attributes.key?(:'badges') if (value = attributes[:'badges']).is_a?(Array) self.badges = value end end if attributes.key?(:'organization') self.organization = attributes[:'organization'] end if attributes.key?(:'organization_role') self.organization_role = attributes[:'organization_role'] end if attributes.key?(:'class_role') self.class_role = attributes[:'class_role'] end if attributes.key?(:'html_url') self.html_url = attributes[:'html_url'] end end |
Instance Attribute Details
#badges ⇒ Object
List of badges for the user profile: - power - staff - composerOfTheMonth - ambassador - challenge
46 47 48 |
# File 'lib/flat_api/models/user_public_summary.rb', line 46 def badges @badges end |
#class_role ⇒ Object
Returns the value of attribute class_role.
53 54 55 |
# File 'lib/flat_api/models/user_public_summary.rb', line 53 def class_role @class_role end |
#firstname ⇒ Object
Firstname of the user (for education users)
34 35 36 |
# File 'lib/flat_api/models/user_public_summary.rb', line 34 def firstname @firstname end |
#html_url ⇒ Object
Link to user profile (for Indiv. users only)
56 57 58 |
# File 'lib/flat_api/models/user_public_summary.rb', line 56 def html_url @html_url end |
#id ⇒ Object
The user unique identifier
20 21 22 |
# File 'lib/flat_api/models/user_public_summary.rb', line 20 def id @id end |
#lastname ⇒ Object
Lastname of the user (for education users)
37 38 39 |
# File 'lib/flat_api/models/user_public_summary.rb', line 37 def lastname @lastname end |
#name ⇒ Object
A displayable name for the user (for consumer users)
40 41 42 |
# File 'lib/flat_api/models/user_public_summary.rb', line 40 def name @name end |
#organization ⇒ Object
Organization ID (for Edu users only)
49 50 51 |
# File 'lib/flat_api/models/user_public_summary.rb', line 49 def organization @organization end |
#organization_role ⇒ Object
Returns the value of attribute organization_role.
51 52 53 |
# File 'lib/flat_api/models/user_public_summary.rb', line 51 def organization_role @organization_role end |
#picture ⇒ Object
The URL of the picture to display
43 44 45 |
# File 'lib/flat_api/models/user_public_summary.rb', line 43 def picture @picture end |
#printable_name ⇒ Object
The name that can be directly printed (name, firstname & lastname, or username)
31 32 33 |
# File 'lib/flat_api/models/user_public_summary.rb', line 31 def printable_name @printable_name end |
#product ⇒ Object
Returns the value of attribute product.
25 26 27 |
# File 'lib/flat_api/models/user_public_summary.rb', line 25 def product @product end |
#type ⇒ Object
The type of user account
23 24 25 |
# File 'lib/flat_api/models/user_public_summary.rb', line 23 def type @type end |
#username ⇒ Object
The user name (unique for the organization)
28 29 30 |
# File 'lib/flat_api/models/user_public_summary.rb', line 28 def username @username end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
101 102 103 |
# File 'lib/flat_api/models/user_public_summary.rb', line 101 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
106 107 108 |
# File 'lib/flat_api/models/user_public_summary.rb', line 106 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/flat_api/models/user_public_summary.rb', line 81 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'product' => :'product', :'username' => :'username', :'printable_name' => :'printableName', :'firstname' => :'firstname', :'lastname' => :'lastname', :'name' => :'name', :'picture' => :'picture', :'badges' => :'badges', :'organization' => :'organization', :'organization_role' => :'organizationRole', :'class_role' => :'classRole', :'html_url' => :'htmlUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/flat_api/models/user_public_summary.rb', line 356 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
137 138 139 140 141 |
# File 'lib/flat_api/models/user_public_summary.rb', line 137 def self.openapi_all_of [ :'UserBasics' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
131 132 133 134 |
# File 'lib/flat_api/models/user_public_summary.rb', line 131 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/flat_api/models/user_public_summary.rb', line 111 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'product' => :'TutteoProduct', :'username' => :'String', :'printable_name' => :'String', :'firstname' => :'String', :'lastname' => :'String', :'name' => :'String', :'picture' => :'String', :'badges' => :'Array<String>', :'organization' => :'String', :'organization_role' => :'OrganizationRoles', :'class_role' => :'ClassRoles', :'html_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/flat_api/models/user_public_summary.rb', line 322 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && product == o.product && username == o.username && printable_name == o.printable_name && firstname == o.firstname && lastname == o.lastname && name == o.name && picture == o.picture && badges == o.badges && organization == o.organization && organization_role == o.organization_role && class_role == o.class_role && html_url == o.html_url end |
#eql?(o) ⇒ Boolean
343 344 345 |
# File 'lib/flat_api/models/user_public_summary.rb', line 343 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
349 350 351 |
# File 'lib/flat_api/models/user_public_summary.rb', line 349 def hash [id, type, product, username, printable_name, firstname, lastname, name, picture, badges, organization, organization_role, class_role, html_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/flat_api/models/user_public_summary.rb', line 230 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @product.nil? invalid_properties.push('invalid value for "product", product cannot be nil.') end if @username.nil? invalid_properties.push('invalid value for "username", username cannot be nil.') end if @picture.nil? invalid_properties.push('invalid value for "picture", picture cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/flat_api/models/user_public_summary.rb', line 378 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/flat_api/models/user_public_summary.rb', line 258 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["user", "guest"]) return false unless type_validator.valid?(@type) return false if @product.nil? return false if @username.nil? return false if @picture.nil? true end |